/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 06542
 |                              NYS WAVE VII
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\06542-0001-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE y7_1ffff  1='(1) Face to Face Interview' 2='(2) Telephone Interview'
                  3='(3) Telephone Interview' 4='(4) Face to Face Interview' ;
  VALUE y7_2ffff  1='(1) Male' 2='(2) Female' ;
  VALUE y7_3ffff  1='(1) Anglo' 2='(2) Black' 3='(3) Hispanic' 4='(4) American Indian'
                  5='(5) Asian' 6='(6) Other' ;
  VALUE y7_8ffff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_9ffff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_10fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_11fff  1='(1) Army' 2='(2) Navy' 3='(3) Air Force' 4='(4) Marines' 5='(5) Coast Guard'
                  6='(6) Inactive' ;
  VALUE y7_12fff  1='(1) Single' 2='(2) Married' 3='(3) Divorced' 4='(4) Separated'
                  5='(5) Widowed' ;
  VALUE y7_13fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_14fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_15fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_16fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_17fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_18fff  1='(1) Jan' 2='(2) Feb' 3='(3) Mar' 4='(4) Apr' 5='(5) May' 6='(6) Jun' 7='(7) Jul'
                  8='(8) Aug' 9='(9) Sept' 10='(10) Oct' 11='(11) Nov' 12='(12) Dec' ;
  VALUE y7_19fff  13='(13) Winter' 14='(14) Spring' 15='(15) Summer' 16='(16) Fall' 17='(17) All Year'
                  84='(84) 1984' 85='(85) 1985' 86='(86) 1986' 99='(99) Dont Know' ;
  VALUE y7_20fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_21fff  1='(1) Jan' 2='(2) Feb' 3='(3) Mar' 4='(4) Apr' 5='(5) May' 6='(6) Jun' 7='(7) Jul'
                  8='(8) Aug' 9='(9) Sept' 10='(10) Oct' 11='(11) Nov' 12='(12) Dec' ;
  VALUE y7_22fff  13='(13) Winter' 14='(14) Spring' 15='(15) Summer' 16='(16) Fall' 17='(17) All Year'
                  84='(84) 1984' 85='(85) 1985' 86='(86) 1986' 99='(99) Dont Know' ;
  VALUE y7_23fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_24fff  1='(1) Jan84' 2='(2) Feb84' 3='(3) Mar84' 4='(4) Apr84' 5='(5) May84' 6='(6) Jun84'
                  7='(7) Jul84' 8='(8) Aug84' 9='(9) Sept84' 10='(10) Oct84' 11='(11) Nov84'
                  12='(12) Dec84' ;
  VALUE y7_25fff  1='(1) Jan85' 2='(2) Feb85' 3='(3) Mar85' 4='(4) Apr85' 5='(5) May85' 6='(6) Jun85'
                  7='(7) Jul85' 8='(8) Aug85' 9='(9) Sept85' 10='(10) Oct85' 11='(11) Nov85'
                  12='(12) Dec85' ;
  VALUE y7_26fff  1='(1) Jan86' 2='(2) Feb86' 3='(3) Mar86' 4='(4) Apr86' 5='(5) May86' 6='(6) Jun86'
                  7='(7) Jul86' 8='(8) Aug86' 9='(9) Sept86' 10='(10) Oct86' 11='(11) Nov86'
                  12='(12) Dec86' ;
  VALUE y7_27fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_28fff  1='(1) Jan' 2='(2) Feb' 3='(3) Mar' 4='(4) Apr' 5='(5) May' 6='(6) Jun' 7='(7) Jul'
                  8='(8) Aug' 9='(9) Sept' 10='(10) Oct' 11='(11) Nov' 12='(12) Dec' ;
  VALUE y7_29fff  84='(84) 1984' 85='(85) 1985' 86='(86) 1986' ;
  VALUE y7_30fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_31fff  1='(1) Jan' 2='(2) Feb' 3='(3) Mar' 4='(4) Apr' 5='(5) May' 6='(6) Jun' 7='(7) Jul'
                  8='(8) Aug' 9='(9) Sept' 10='(10) Oct' 11='(11) Nov' 12='(12) Dec' ;
  VALUE y7_32fff  84='(84) 1984' 85='(85) 1985' 86='(86) 1986' ;
  VALUE y7_33fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_34fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_35fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_36fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_37fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_38fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_39fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_40fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_41fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_42fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_43fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_44fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_45fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_46fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_47fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_48fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_49fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_50fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_51fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_52fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_53fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_54fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_55fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_56fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_57fff  1='(1) Mother and Father' 2='(2) Mother only' 3='(3) Father only'
                  4='(4) Mother/Stepfather' 5='(5) Father/Stepmother' 6='(6) Spouse'
                  7='(7) Roommate' 8='(8) Bfriend/gfriend' 9='(9) Alone' 10='(10) Military'
                  11='(11) Other' 12='(12) Mother/other (reltd or not)'
                  13='(13) Father/other (reltd or not)' 14='(14) Mother/father/other'
                  15='(15) Relatives (not parents)' 16='(16) In-laws'
                  17='(17) Spouse and in-laws' 18='(18) Prison' 19='(19) Spouse and parents'
                  20='(20) Boyfr/girlfr/parents' 21='(21) Boyfr/girlfr/in-laws'
                  22='(22) Boyfr/girlfr' 23='(23) Alone w/own children' ;
  VALUE y7_58fff  1='(1) Mother and Father' 2='(2) Mother only' 3='(3) Father only'
                  4='(4) Mother/Stepfather' 5='(5) Father/Stepmother' 6='(6) Spouse'
                  7='(7) Roommate' 8='(8) Bfriend/gfriend' 9='(9) Alone' 10='(10) Military'
                  11='(11) Other' 12='(12) Mother/other (reltd or not)'
                  13='(13) Father/other (reltd or not)' 14='(14) Mother/father/other'
                  15='(15) Relatives (not parents)' 16='(16) In-laws'
                  17='(17) Spouse and in-laws' 18='(18) Prison' 19='(19) Spouse and parents'
                  20='(20) Boyfr/girlfr/parents' 21='(21) Boyfr/girlfr/in-laws'
                  22='(22) Boyfr/girlfr' 23='(23) Alone w/own children' ;
  VALUE y7_59fff  1='(1) Mother and Father' 2='(2) Mother only' 3='(3) Father only'
                  4='(4) Mother/Stepfather' 5='(5) Father/Stepmother' 6='(6) Spouse'
                  7='(7) Roommate' 8='(8) Bfriend/gfriend' 9='(9) Alone' 10='(10) Military'
                  11='(11) Other' 12='(12) Mother/other (reltd or not)'
                  13='(13) Father/other (reltd or not)' 14='(14) Mother/father/other'
                  15='(15) Relatives (not parents)' 16='(16) In-laws'
                  17='(17) Spouse and in-laws' 18='(18) Prison' 19='(19) Spouse and parents'
                  20='(20) Boyfr/girlfr/parents' 21='(21) Boyfr/girlfr/in-laws'
                  22='(22) Boyfr/girlfr' 23='(23) Alone w/own children' ;
  VALUE y7_60fff  1='(1) Not a problem' 2='(2) Somewhat of a problem' 3='(3) Big problem' ;
  VALUE y7_61fff  1='(1) Not a problem' 2='(2) Somewhat of a problem' 3='(3) Big problem' ;
  VALUE y7_62fff  1='(1) Not a problem' 2='(2) Somewhat of a problem' 3='(3) Big problem' ;
  VALUE y7_63fff  1='(1) Not a problem' 2='(2) Somewhat of a problem' 3='(3) Big problem' ;
  VALUE y7_64fff  1='(1) Not a problem' 2='(2) Somewhat of a problem' 3='(3) Big problem' ;
  VALUE y7_65fff  1='(1) Not a problem' 2='(2) Somewhat of a problem' 3='(3) Big problem' ;
  VALUE y7_66fff  1='(1) Not a problem' 2='(2) Somewhat of a problem' 3='(3) Big problem' ;
  VALUE y7_67fff  1='(1) Not a problem' 2='(2) Somewhat of a problem' 3='(3) Big problem' ;
  VALUE y7_68fff  1='(1) Not a problem' 2='(2) Somewhat of a problem' 3='(3) Big problem' ;
  VALUE y7_69fff  1='(1) Not a problem' 2='(2) Somewhat of a problem' 3='(3) Big problem' ;
  VALUE y7_70fff  1='(1) Not a problem' 2='(2) Somewhat of a problem' 3='(3) Big problem' ;
  VALUE y7_71fff  1='(1) Not a problem' 2='(2) Somewhat of a problem' 3='(3) Big problem' ;
  VALUE y7_72fff  1='(1) Not a problem' 2='(2) Somewhat of a problem' 3='(3) Big problem' ;
  VALUE y7_73fff  1='(1) Not a problem' 2='(2) Somewhat of a problem' 3='(3) Big problem' ;
  VALUE y7_74fff  1='(1) Not a problem' 2='(2) Somewhat of a problem' 3='(3) Big problem' ;
  VALUE y7_75fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_76fff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_77fff  1='(1) Not important at all' 2='(2) Not too important'
                  3='(3) Somewhat important' 4='(4) Pretty important'
                  5='(5) Very important' ;
  VALUE y7_78fff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_79fff  0='(0) > than once aftn/weekday' 1='(1) one aftn/weekday'
                  2='(2) two aftn/weekday' 3='(3) three aftn/weekday'
                  4='(4) four aftn/weekday' 5='(5) five aftn/weekday' ;
  VALUE y7_80fff  0='(0) > than once even/weekday' 1='(1) 1 evenings/weekday'
                  2='(2) 2 evenings/weekday' 3='(3) three evenings/weekday'
                  4='(4) four evenings/weekday' 5='(5) five evenings/weekday' ;
  VALUE y7_81fff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_83fff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_84fff  1='(1) Not at all' 2='(2) In a few ways' 3='(3) In some ways'
                  4='(4) In most ways' 5='(5) In all ways' ;
  VALUE y7_85fff  1='(1) Not important at all' 2='(2) Not too important'
                  3='(3) Somewhat important' 4='(4) Pretty important'
                  5='(5) Very important' ;
  VALUE y7_86fff  1='(1) very dissatisfied' 2='(2) Somewhat dissatisfied' 3='(3) Neither'
                  4='(4) Somewhat satisfied' 5='(5) Very satisfied' ;
  VALUE y7_87fff  1='(1) None' 2='(2) A few' 3='(3) Some' 4='(4) Most' 5='(5) All' ;
  VALUE y7_88fff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_89fff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_90fff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_91fff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_92fff  1='(1) Academic Program' 2='(2) Business/Vocational School'
                  3='(3) Other' 4='(4) No' ;
  VALUE y7_93fff  5='(5) 5th grade' 6='(6) 6th grade' 7='(7) 7th grade' 8='(8) 8th grade'
                  9='(9) 9th grade' 10='(10) 10th grade' 11='(11) 11th grade'
                  12='(12) 12th grade' 13='(13) 1st college' 14='(14) 2nd college'
                  15='(15) 3rd college' 16='(16) 4th college' 17='(17) 1st grad sch' ;
  VALUE y7_94fff  74='(74) 1974' 75='(75) 1975' 76='(76) 1976' 77='(77) 1977' 78='(78) 1978' 79='(79) 1979'
                  80='(80) 1980' 81='(81) 1981' 82='(82) 1982' 83='(83) 1983' 84='(84) 1984' 85='(85) 1985'
                  99='(99) Dont Remember' ;
  VALUE y7_95fff  1='(1) Very dissatisfied' 2='(2) Somewhat dissatisfied' 3='(3) Neither'
                  4='(4) Somewhat satisfied' 5='(5) Very satisfied' ;
  VALUE y7_96fff  1='(1) Not important at all' 2='(2) Not too important'
                  3='(3) Somewhat important' 4='(4) Pretty important'
                  5='(5) Very important' ;
  VALUE y7_97fff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_98fff  5='(5) 5th grade' 6='(6) 6th grade' 7='(7) 7th grade' 8='(8) 8th grade'
                  9='(9) 9th grade' 10='(10) 10th grade' 11='(11) 11th grade'
                  12='(12) 12th grade' 13='(13) 1st college' 14='(14) 2nd college'
                  15='(15) 3rd college' 16='(16) 4th college' 17='(17) Graduate School' ;
  VALUE y7_99fff  1='(1) Fs Mostly' 2='(2) Ds Mostly' 3='(3) Cs Mostly' 4='(4) Bs Mostly'
                  5='(5) As Mostly' ;
  VALUE y7_100ff  0='(0) > than once aftn/weekday' 1='(1) one aftn/weekday'
                  2='(2) two aftn/weekday' 3='(3) three aftn/weekday'
                  4='(4) four aftn/weekday' 5='(5) five aftn/weekday' ;
  VALUE y7_101ff  0='(0) > than once even/weekday' 1='(1) 1 evenings/weekday'
                  2='(2) 2 evenings/weekday' 3='(3) three evenings/weekday'
                  4='(4) four evenings/weekday' 5='(5) five evenings/weekday' ;
  VALUE y7_102ff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_103ff  99='(99) 99 hours or more' ;
  VALUE y7_104ff  1='(1) Not important at all' 2='(2) Not too important'
                  3='(3) Somewhat important' 4='(4) Pretty important'
                  5='(5) Very important' ;
  VALUE y7_105ff  1='(1) Very dissatisfied' 2='(2) Somewhat dissatisfied' 3='(3) Neither'
                  4='(4) Somewhat satisfied' 5='(5) Very satisfied' ;
  VALUE y7_106ff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_107ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_108ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_109ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_110ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_111ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_112ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_113ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_114ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_115ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_116ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_117ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_118ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_119ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_121ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_122ff  1='(1) Not important at all' 2='(2) Not too important'
                  3='(3) Somewhat important' 4='(4) Pretty important'
                  5='(5) Very important' ;
  VALUE y7_123ff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_124ff  1='(1) 1 job' 2='(2) 2 jobs' 3='(3) 3 jobs' 4='(4) 4 jobs' 5='(5) 5 jobs'
                  6='(6) 6 jobs' 7='(7) 7 jobs' 8='(8) 8 jobs' 9='(9) 9 jobs' 10='(10) 10 jobs' ;
  VALUE y7_149ff  1='(1) Not important at all' 2='(2) Not too important'
                  3='(3) Somewhat important' 4='(4) Pretty important'
                  5='(5) Very important' ;
  VALUE y7_150ff  1='(1) Very dissatisfied' 2='(2) Somewhat dissatisfied' 3='(3) Neither'
                  4='(4) Somewhat satisfied' 5='(5) Very satisfied' ;
  VALUE y7_151ff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_152ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_153ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_154ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_155ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_156ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_157ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_158ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_159ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_160ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_161ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_162ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_163ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_165ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_166ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_167ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_168ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_169ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_170ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_171ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_172ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_173ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_174ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_175ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_176ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_177ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_178ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_179ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_180ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_181ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_182ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_183ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_184ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_185ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_187ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_188ff  1='(1) 1 job' 2='(2) 2 jobs' 3='(3) 3 jobs' 4='(4) 4 jobs' 5='(5) 5 jobs'
                  6='(6) 6 jobs' 7='(7) 7 jobs' 8='(8) 8 jobs' 9='(9) 9 jobs' 10='(10) 10 jobs' ;
  VALUE y7_210ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_211ff  1='(1) 1 job' 2='(2) 2 jobs' 3='(3) 3 jobs' 4='(4) 4 jobs' 5='(5) 5 jobs'
                  6='(6) 6 jobs' 7='(7) 7 jobs' 8='(8) 8 jobs' 9='(9) 9 jobs' 10='(10) 10 jobs' ;
  VALUE y7_233ff  1='(1) Spouse' 2='(2) Girlfr/boyfr (opposite sex)'
                  3='(3) Girlfr/boyfr (same sex)' ;
  VALUE y7_234ff  1='(1) (>1 month' 2='(2) 2 months' 3='(3) 3 months' 4='(4) 4 months'
                  5='(5) 5 months' 6='(6) 6 months' 7='(7) 7 months' 8='(8) 8 months'
                  9='(9) 9 months' 10='(10) 10 months' 11='(11) 11 months' 12='(12) 12 months' ;
  VALUE y7_235ff  1='(1) Not important at all' 2='(2) Not too important'
                  3='(3) Somewhat important' 4='(4) Pretty important'
                  5='(5) Very important' ;
  VALUE y7_236ff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_237ff  1='(1) Not at all' 2='(2) In a few ways' 3='(3) In some ways'
                  4='(4) In most ways' 5='(5) In all ways' ;
  VALUE y7_238ff  1='(1) very dissatisfied' 2='(2) Somewhat dissatisfied' 3='(3) Neither'
                  4='(4) Somewhat satisfied' 5='(5) Very satisfied' ;
  VALUE y7_239ff  1='(1) None' 2='(2) A few' 3='(3) Some' 4='(4) Most' 5='(5) All' ;
  VALUE y7_240ff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_241ff  1='(1) very dissatisfied' 2='(2) Somewhat dissatisfied' 3='(3) Neither'
                  4='(4) Somewhat satisfied' 5='(5) Very satisfied' ;
  VALUE y7_242ff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_243ff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_244ff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_245ff  0='(0) No' 1='(1) Once' 2='(2) Two or three times'
                  3='(3) Four or more times' ;
  VALUE y7_246ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_247ff  1='(1) 1 job' 2='(2) 2 jobs' 3='(3) 3 jobs' 4='(4) 4 jobs' 5='(5) 5 jobs'
                  6='(6) 6 jobs' 7='(7) 7 jobs' 8='(8) 8 jobs' 9='(9) 9 jobs' 10='(10) 10 jobs' ;
  VALUE y7_261ff  6='(6) 6th grade' 7='(7) 7th grade' 8='(8) 8th grade' 9='(9) 9th grade'
                  10='(10) 10th grade' 11='(11) 11th grade' 12='(12) 12th grade'
                  13='(13) 1st college' 14='(14) 2nd college' 15='(15) 3rd college'
                  16='(16) Bachelors degree' 17='(17) Graduate degrees' 99='(99) Dont Know' ;
  VALUE y7_263ff  1='(1) Amount given is only a guess' ;
  VALUE y7_264ff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times' 4='(4) Monthly'
                  5='(5) Weekly (or more often)' ;
  VALUE y7_265ff  0='(0) >1 month' 1='(1) 1 month' 2='(2) 2 months' 3='(3) 3 months'
                  4='(4) 4 months' 5='(5) 5 months' 6='(6) 6 months' 7='(7) 7 months'
                  8='(8) 8 months' 9='(9) 9 months' 10='(10) 10 months' 11='(11) 11 months'
                  12='(12) 12 months' ;
  VALUE y7_266ff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times' 4='(4) Monthly'
                  5='(5) Weekly (or more often)' ;
  VALUE y7_267ff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_268ff  1='(1) Not important at all' 2='(2) Not too important'
                  3='(3) Somewhat important' 4='(4) Pretty important'
                  5='(5) Very important' ;
  VALUE y7_269ff  1='(1) very dissatisfied' 2='(2) Somewhat dissatisfied' 3='(3) Neither'
                  4='(4) Somewhat satisfied' 5='(5) Very satisfied' ;
  VALUE y7_270ff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_271ff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times' 4='(4) Monthly'
                  5='(5) Weekly (or more often)' ;
  VALUE y7_272ff  0='(0) >1 month' 1='(1) 1 month' 2='(2) 2 months' 3='(3) 3 months'
                  4='(4) 4 months' 5='(5) 5 months' 6='(6) 6 months' 7='(7) 7 months'
                  8='(8) 8 months' 9='(9) 9 months' 10='(10) 10 months' ;
  VALUE y7_273ff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times' 4='(4) Monthly'
                  5='(5) Weekly (or more often)' ;
  VALUE y7_274ff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_275ff  1='(1) Not important at all' 2='(2) Not too important'
                  3='(3) Somewhat important' 4='(4) Pretty important'
                  5='(5) Very important' ;
  VALUE y7_276ff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_277ff  1='(1) Very dissatisfied' 2='(2) Somewhat dissatisfied' 3='(3) Neither'
                  4='(4) Somewhat satisfied' 5='(5) Very satisfied' ;
  VALUE y7_278ff  0='(0) >No wkday aftn with fam' 1='(1) 1 Wkday aftn with fam'
                  2='(2) 2 Wkday aftn with fam' 3='(3) 3 Wkday aftn with fam'
                  4='(4) 4 Wkday aftn with fam' 5='(5) 5 Wkday aftn with fam' ;
  VALUE y7_279ff  0='(0) >No wkday even with fam' 1='(1) 1 Wkday even with fam'
                  2='(2) 2 Wkday even with fam' 3='(3) 3 Wkday even with fam'
                  4='(4) 4 Wkday even with fam' 5='(5) 5 Wkday even with fam' ;
  VALUE y7_280ff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_281ff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times' 4='(4) Monthly'
                  5='(5) Weekly (or more often)' ;
  VALUE y7_282ff  0='(0) >1 month' 1='(1) 1 month' 2='(2) 2 months' 3='(3) 3 months'
                  4='(4) 4 months' 5='(5) 5 months' 6='(6) 6 months' 7='(7) 7 months'
                  8='(8) 8 months' 9='(9) 9 months' 10='(10) 10 months' 11='(11) 11 months'
                  12='(12) 12 months' ;
  VALUE y7_283ff  1='(1) Never' 2='(2) Once or twice' 3='(3) 3 or 4 times' 4='(4) Monthly'
                  5='(5) Weekly (or more often)' ;
  VALUE y7_284ff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_285ff  1='(1) Not important at all' 2='(2) Not too important'
                  3='(3) Somewhat important' 4='(4) Pretty important'
                  5='(5) Very important' ;
  VALUE y7_286ff  1='(1) very dissatisfied' 2='(2) Somewhat dissatisfied' 3='(3) Neither'
                  4='(4) Somewhat satisfied' 5='(5) Very satisfied' ;
  VALUE y7_287ff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_288ff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_289ff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_290ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_291ff  1='(1) Jan' 2='(2) Feb' 3='(3) Mar' 4='(4) Apr' 5='(5) May' 6='(6) Jun' 7='(7) Jul'
                  8='(8) Aug' 9='(9) Sept' 10='(10) Oct' 11='(11) Nov' 12='(12) Dec' 99='(99) Dont know' ;
  VALUE y7_292ff  70='(70) 1970' 71='(71) 1971' 72='(72) 1972' 73='(73) 1973' 74='(74) 1974' 75='(75) 1975'
                  76='(76) 1976' 77='(77) 1977' 78='(78) 1978' 79='(79) 1979' 80='(80) 1980' 81='(81) 1981'
                  82='(82) 1982' 83='(83) 1983' 84='(84) 1984' 85='(85) 1985' 86='(86) 1986' 87='(87) 1987' ;
  VALUE y7_293ff  1='(1) Boy' 2='(2) Girl' ;
  VALUE y7_294ff  1='(1) Yes' 2='(2) No' ;
  VALUE y7_295ff  1='(1) No' 2='(2) Yes' 9='(9) Dont Know' ;
  VALUE y7_296ff  1='(1) Jan' 2='(2) Feb' 3='(3) Mar' 4='(4) Apr' 5='(5) May' 6='(6) Jun' 7='(7) Jul'
                  8='(8) Aug' 9='(9) Sept' 10='(10) Oct' 11='(11) Nov' 12='(12) Dec' ;
  VALUE y7_297ff  70='(70) 1970' 71='(71) 1971' 72='(72) 1972' 73='(73) 1973' 74='(74) 1974' 75='(75) 1975'
                  76='(76) 1976' 77='(77) 1977' 78='(78) 1978' 79='(79) 1979' 80='(80) 1980' 81='(81) 1981'
                  82='(82) 1982' 83='(83) 1983' 84='(84) 1984' 85='(85) 1985' 86='(86) 1986' 87='(87) 1987' ;
  VALUE y7_298ff  1='(1) Boy' 2='(2) Girl' ;
  VALUE y7_299ff  1='(1) Yes' 2='(2) No' ;
  VALUE y7_300ff  1='(1) No' 2='(2) Yes' 9='(9) Dont Know' ;
  VALUE y7_301ff  1='(1) Jan' 2='(2) Feb' 3='(3) Mar' 4='(4) Apr' 5='(5) May' 6='(6) Jun' 7='(7) Jul'
                  8='(8) Aug' 9='(9) Sept' 10='(10) Oct' 11='(11) Nov' 12='(12) Dec' ;
  VALUE y7_302ff  70='(70) 1970' 71='(71) 1971' 72='(72) 1972' 73='(73) 1973' 74='(74) 1974' 75='(75) 1975'
                  76='(76) 1976' 77='(77) 1977' 78='(78) 1978' 79='(79) 1979' 80='(80) 1980' 81='(81) 1981'
                  82='(82) 1982' 83='(83) 1983' 84='(84) 1984' 85='(85) 1985' 86='(86) 1986' 87='(87) 1987' ;
  VALUE y7_303ff  1='(1) Boy' 2='(2) Girl' ;
  VALUE y7_304ff  1='(1) Yes' 2='(2) No' ;
  VALUE y7_305ff  1='(1) No' 2='(2) Yes' 9='(9) Dont Know' ;
  VALUE y7_306ff  1='(1) Jan' 2='(2) Feb' 3='(3) Mar' 4='(4) Apr' 5='(5) May' 6='(6) Jun' 7='(7) Jul'
                  8='(8) Aug' 9='(9) Sept' 10='(10) Oct' 11='(11) Nov' 12='(12) Dec' ;
  VALUE y7_307ff  70='(70) 1970' 71='(71) 1971' 72='(72) 1972' 73='(73) 1973' 74='(74) 1974' 75='(75) 1975'
                  76='(76) 1976' 77='(77) 1977' 78='(78) 1978' 79='(79) 1979' 80='(80) 1980' 81='(81) 1981'
                  82='(82) 1982' 83='(83) 1983' 84='(84) 1984' 85='(85) 1985' 86='(86) 1986' 87='(87) 1987' ;
  VALUE y7_308ff  1='(1) Boy' 2='(2) Girl' ;
  VALUE y7_309ff  1='(1) Yes' 2='(2) No' ;
  VALUE y7_310ff  1='(1) No' 2='(2) Yes' 9='(9) Dont Know' ;
  VALUE y7_311ff  1='(1) Jan' 2='(2) Feb' 3='(3) Mar' 4='(4) Apr' 5='(5) May' 6='(6) Jun' 7='(7) Jul'
                  8='(8) Aug' 9='(9) Sept' 10='(10) Oct' 11='(11) Nov' 12='(12) Dec' ;
  VALUE y7_312ff  70='(70) 1970' 71='(71) 1971' 72='(72) 1972' 73='(73) 1973' 74='(74) 1974' 75='(75) 1975'
                  76='(76) 1976' 77='(77) 1977' 78='(78) 1978' 79='(79) 1979' 80='(80) 1980' 81='(81) 1981'
                  82='(82) 1982' 83='(83) 1983' 84='(84) 1984' 85='(85) 1985' 86='(86) 1986' 87='(87) 1987' ;
  VALUE y7_313ff  1='(1) Boy' 2='(2) Girl' ;
  VALUE y7_314ff  1='(1) Yes' 2='(2) No' ;
  VALUE y7_315ff  1='(1) No' 2='(2) Yes' 9='(9) Dont Know' ;
  VALUE y7_316ff  1='(1) Jan' 2='(2) Feb' 3='(3) Mar' 4='(4) Apr' 5='(5) May' 6='(6) Jun' 7='(7) Jul'
                  8='(8) Aug' 9='(9) Sept' 10='(10) Oct' 11='(11) Nov' 12='(12) Dec' ;
  VALUE y7_317ff  70='(70) 1970' 71='(71) 1971' 72='(72) 1972' 73='(73) 1973' 74='(74) 1974' 75='(75) 1975'
                  76='(76) 1976' 77='(77) 1977' 78='(78) 1978' 79='(79) 1979' 80='(80) 1980' 81='(81) 1981'
                  82='(82) 1982' 83='(83) 1983' 84='(84) 1984' 85='(85) 1985' 86='(86) 1986' 87='(87) 1987' ;
  VALUE y7_318ff  1='(1) Boy' 2='(2) Girl' ;
  VALUE y7_319ff  1='(1) Yes' 2='(2) No' ;
  VALUE y7_320ff  1='(1) No' 2='(2) Yes' 9='(9) Dont Know' ;
  VALUE y7_322ff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_323ff  1='(1) very dissatisfied' 2='(2) Somewhat dissatisfied' 3='(3) Neither'
                  4='(4) Somewhat satisfied' 5='(5) Very satisfied' ;
  VALUE y7_324ff  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_325ff  1='(1) Never (Once or twice)' 2='(2) Several times a year'
                  3='(3) Once or twice a month' 4='(4) Once a week'
                  5='(5) Several times a week' ;
  VALUE y7_326ff  1='(1) Not important at all' 2='(2) Not too important'
                  3='(3) Somewhat important' 4='(4) Pretty important'
                  5='(5) Very important' ;
  VALUE y7_327ff  1='(1) Not important at all' 3='(3) Somewhat important'
                  5='(5) Very important' ;
  VALUE y7_328ff  1='(1) Poor' 3='(3) Fair' 5='(5) Good' 8='(8) Already achieved' ;
  VALUE y7_329ff  1='(1) Not important at all' 3='(3) Somewhat important'
                  5='(5) Very important' ;
  VALUE y7_330ff  1='(1) Poor' 3='(3) Fair' 5='(5) Good' 8='(8) Already achieved' ;
  VALUE y7_331ff  1='(1) Not important at all' 3='(3) Somewhat important'
                  5='(5) Very important' ;
  VALUE y7_332ff  1='(1) Poor' 3='(3) Fair' 5='(5) Good' 8='(8) Already achieved' ;
  VALUE y7_333ff  1='(1) Not important at all' 3='(3) Somewhat important'
                  5='(5) Very important' ;
  VALUE y7_334ff  1='(1) Poor' 3='(3) Fair' 5='(5) Good' 8='(8) Already achieved' ;
  VALUE y7_335ff  1='(1) Not important at all' 3='(3) Somewhat important'
                  5='(5) Very important' ;
  VALUE y7_336ff  1='(1) Poor' 3='(3) Fair' 5='(5) Good' 8='(8) Already achieved' ;
  VALUE y7_337ff  1='(1) Not important at all' 3='(3) Somewhat important'
                  5='(5) Very important' ;
  VALUE y7_338ff  1='(1) Poor' 3='(3) Fair' 5='(5) Good' 8='(8) Already achieved' ;
  VALUE y7_339ff  1='(1) Not important at all' 3='(3) Somewhat important'
                  5='(5) Very important' ;
  VALUE y7_340ff  1='(1) Poor' 3='(3) Fair' 5='(5) Good' 8='(8) Already achieved' ;
  VALUE y7_341ff  1='(1) Not important at all' 3='(3) Somewhat important'
                  5='(5) Very important' ;
  VALUE y7_342ff  1='(1) Poor' 3='(3) Fair' 5='(5) Good' 8='(8) Already achieved' ;
  VALUE y7_343ff  1='(1) Not important at all' 3='(3) Somewhat important'
                  5='(5) Very important' ;
  VALUE y7_344ff  1='(1) Poor' 3='(3) Fair' 5='(5) Good' 8='(8) Already achieved' ;
  VALUE y7_345ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_346ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_347ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_348ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_349ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_350ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_351ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_352ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_353ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_354ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_355ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_356ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_357ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_358ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_359ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_360ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_361ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_362ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_363ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_364ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_365ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_366ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_367ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_368ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_369ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_370ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_371ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_372ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_373ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_374ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_375ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_376ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_377ff  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_378ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_379ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_380ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_381ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_382ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_383ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_384ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_385ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_386ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_387ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_388ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_389ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_390ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_391ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_392ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_393ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_394ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_395ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_396ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_397ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_398ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_399ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_400ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_401ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_402ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_403ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_404ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_405ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_406ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_407ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_408ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_409ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_410ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_411ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_412ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_413ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_414ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_415ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_416ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_417ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_418ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_419ff  1='(1) Strongly approve' 2='(2) Approve'
                  3='(3) Neither approve nor disapprove' 4='(4) Disapprove'
                  5='(5) Strongly disapprove' ;
  VALUE y7_420ff  1='(1) Not wrong at all' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE y7_421ff  1='(1) Not wrong at all' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE y7_422ff  1='(1) Not wrong at all' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE y7_423ff  1='(1) Not wrong at all' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE y7_424ff  1='(1) Not wrong at all' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE y7_425ff  1='(1) Not wrong at all' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE y7_426ff  1='(1) Not wrong at all' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE y7_427ff  1='(1) Not wrong at all' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE y7_428ff  1='(1) Not wrong at all' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE y7_429ff  1='(1) Not wrong at all' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE y7_430ff  1='(1) Not wrong at all' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE y7_431ff  1='(1) Not wrong at all' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE y7_432ff  1='(1) Not wrong at all' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE y7_433ff  1='(1) Not wrong at all' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE y7_434ff  1='(1) Not wrong at all' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE y7_435ff  1='(1) Not wrong at all' 2='(2) A little bit wrong' 3='(3) Wrong'
                  4='(4) Very wrong' ;
  VALUE y7_436ff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE y7_437ff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE y7_438ff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE y7_439ff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE y7_440ff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE y7_441ff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE y7_442ff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE y7_443ff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE y7_444ff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE y7_445ff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE y7_446ff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE y7_447ff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE y7_448ff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE y7_449ff  1='(1) None of them' 2='(2) Very few of them' 3='(3) Some of them'
                  4='(4) Most of them' 5='(5) All of them' ;
  VALUE y7_451ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_453ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_455ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_457ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_459ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_461ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_463ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_465ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_467ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_469ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_471ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_473ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_475ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_477ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_479ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_481ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_483ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_485ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_487ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_489ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_491ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_493ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_495ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_497ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_499ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_501ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_503ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_505ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_507ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_509ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_511ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_513ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_515ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_517ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_519ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_521ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_523ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_525ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_526ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_527ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_528ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_529ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_530ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_531ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_532ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_533ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_534ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_535ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_536ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_537ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_538ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_539ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_540ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_541ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_542ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_543ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_544ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_545ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_546ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_547ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_548ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_549ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_550ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_551ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_552ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_553ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_554ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_555ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_556ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_557ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_558ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_559ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_560ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_561ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_562ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_563ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_564ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_565ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_566ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_567ff  1='(1) Inappropriate' 2='(2) Appropriate but trivial'
                  3='(3) Appropriate and nontrivial' ;
  VALUE y7_569ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_570ff  0='(0) No' ;
  VALUE y7_571ff  0='(0) No' ;
  VALUE y7_573ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_578ff  0='(0) No' ;
  VALUE y7_579ff  0='(0) No' ;
  VALUE y7_580ff  1='(1) Car' 2='(2) Truck' 3='(3) Motorcycle' 4='(4) Other' ;
  VALUE y7_581ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_582ff  1='(1) Family member' 2='(2) Friend' 3='(3) Other' ;
  VALUE y7_583ff  1='(1) Had keys' 2='(2) Hot wired' 3='(3) Keys in ignition' 4='(4) Other' ;
  VALUE y7_584ff  1='(1) Resping' 2='(2) Keep' 3='(3) Keep parts' 4='(4) Sell' 5='(5) Sell parts'
                  6='(6) Other' ;
  VALUE y7_585ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_586ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_587ff  0='(0) No' ;
  VALUE y7_588ff  0='(0) No' ;
  VALUE y7_589ff  1='(1) Car' 2='(2) Truck' 3='(3) Motorcycle' 4='(4) Other' ;
  VALUE y7_590ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_591ff  1='(1) Family member' 2='(2) Friend' 3='(3) Other' ;
  VALUE y7_592ff  1='(1) Had keys' 2='(2) Hot wired' 3='(3) Keys in ignition' 4='(4) Other' ;
  VALUE y7_593ff  1='(1) Resping' 2='(2) Keep' 3='(3) Keep parts' 4='(4) Sell' 5='(5) Sell parts'
                  6='(6) Other' ;
  VALUE y7_594ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_595ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_596ff  0='(0) No' ;
  VALUE y7_597ff  0='(0) No' ;
  VALUE y7_598ff  1='(1) Car' 2='(2) Truck' 3='(3) Motorcycle' 4='(4) Other' ;
  VALUE y7_599ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_600ff  1='(1) Family member' 2='(2) Friend' 3='(3) Other' ;
  VALUE y7_601ff  1='(1) Had keys' 2='(2) Hot wired' 3='(3) Keys in ignition' 4='(4) Other' ;
  VALUE y7_602ff  1='(1) Riding' 2='(2) Keep' 3='(3) Keep parts' 4='(4) Sell' 5='(5) Sell parts'
                  6='(6) Other' ;
  VALUE y7_603ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_604ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_605ff  0='(0) No' ;
  VALUE y7_606ff  0='(0) No' ;
  VALUE y7_608ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_609ff  1='(1) Retail store' 2='(2) Private home' 3='(3) Auto' 4='(4) Work place'
                  5='(5) College/school' 6='(6) Construction site' 7='(7) Warehouse'
                  8='(8) Other' ;
  VALUE y7_610ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_611ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_612ff  0='(0) No' ;
  VALUE y7_613ff  0='(0) No' ;
  VALUE y7_615ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_616ff  1='(1) Retail store' 2='(2) Private home' 3='(3) Auto' 4='(4) Work place'
                  5='(5) College/school' 6='(6) Construction site' 7='(7) Warehouse'
                  8='(8) Other' ;
  VALUE y7_617ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_618ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_619ff  0='(0) No' ;
  VALUE y7_620ff  0='(0) No' ;
  VALUE y7_622ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_623ff  1='(1) Retail store' 2='(2) Private home' 3='(3) Auto' 4='(4) Work place'
                  5='(5) College/school' 6='(6) Construction site' 7='(7) Warehouse'
                  8='(8) Other' ;
  VALUE y7_624ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_625ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_626ff  0='(0) No' ;
  VALUE y7_627ff  0='(0) No' ;
  VALUE y7_628ff  1='(1) Try to buy' 2='(2) Try to sell' 3='(3) Try to hold' 4='(4) Buy'
                  5='(5) Sell' 6='(6) Hold' 7='(7) Other' ;
  VALUE y7_630ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_631ff  0='(0) No' ;
  VALUE y7_632ff  0='(0) No' ;
  VALUE y7_633ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_634ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_635ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_636ff  0='(0) No' ;
  VALUE y7_637ff  0='(0) No' ;
  VALUE y7_638ff  1='(1) Knife, cutting/stabbing thing'
                  2='(2) Chain, bat/hitting thing' 3='(3) Hard knuckles/numchucks'
                  4='(4) Gun and other firearm' 5='(5) Other'
                  6='(6) Mixed weapons excluding gun'
                  7='(7) Mixed weapons including gun'
                  8='(8) Mixed weapons-no gun or knife types' ;
  VALUE y7_639ff  0='(0) $0' 1='(1) $1' 2='(2) $2' 3='(3) $3' 4='(4) $4' 5='(5) $5' 6='(6) $6' 7='(7) $7'
                  8='(8) $8' 9='(9) $9' ;
  VALUE y7_640ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_641ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_642ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_643ff  0='(0) No' ;
  VALUE y7_644ff  0='(0) No' ;
  VALUE y7_645ff  1='(1) Hit' 2='(2) Beat/choked' 3='(3) Attacked with weapon' 4='(4) Other' ;
  VALUE y7_646ff  0='(0) No injury' 1='(1) Knocked down' 2='(2) Bruised' 3='(3) Cut/bleeding'
                  4='(4) Unconscious' 5='(5) Hospitalized'
                  6='(6) Required medical treatment' 7='(7) Other' ;
  VALUE y7_647ff  1='(1) A stranger' 2='(2) An acquaintance' 3='(3) A friend'
                  4='(4) Family member' 5='(5) Other' ;
  VALUE y7_648ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_649ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_650ff  0='(0) No' ;
  VALUE y7_651ff  0='(0) No' ;
  VALUE y7_652ff  1='(1) Hit' 2='(2) Beat/choked' 3='(3) Attacked with weapon' 4='(4) Other' ;
  VALUE y7_653ff  0='(0) No injury' 1='(1) Knocked down' 2='(2) Bruised' 3='(3) Cut/bleeding'
                  4='(4) Unconscious' 5='(5) Hospitalized'
                  6='(6) Required medical treatment' 7='(7) Other' ;
  VALUE y7_654ff  1='(1) A stranger' 2='(2) An acquaintance' 3='(3) A friend'
                  4='(4) Family member' 5='(5) Other' ;
  VALUE y7_655ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_656ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_657ff  0='(0) No' ;
  VALUE y7_658ff  0='(0) No' ;
  VALUE y7_659ff  1='(1) Hit' 2='(2) Beat/choked' 3='(3) Attacked with weapon' 4='(4) Other' ;
  VALUE y7_660ff  0='(0) No injury' 1='(1) Knocked down' 2='(2) Bruised' 3='(3) Cut/bleeding'
                  4='(4) Unconscious' 5='(5) Hospitalized'
                  6='(6) Required medical treatment' 7='(7) Other' ;
  VALUE y7_661ff  1='(1) A stranger' 2='(2) An acquaintance' 3='(3) A friend'
                  4='(4) Family member' 5='(5) Other' ;
  VALUE y7_662ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_663ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_664ff  0='(0) No' ;
  VALUE y7_665ff  0='(0) No' ;
  VALUE y7_666ff  1='(1) l-2 people' 2='(2) 3-5' 3='(3) More than 5 people' ;
  VALUE y7_667ff  1='(1) l-2 people' 2='(2) 3-5' 3='(3) More than 5 people' ;
  VALUE y7_668ff  0='(0) No weapons' 1='(1) Knives, cutting/stabbing things'
                  2='(2) Chains, bats/hitting things' 3='(3) Hard knuckles/numchucks'
                  4='(4) Guns and other firearms' 5='(5) Other'
                  6='(6) Mixed weapons excluding guns'
                  7='(7) Mixed weapons including guns'
                  8='(8) Mixed weapons-no gun or knife types' ;
  VALUE y7_669ff  0='(0) No injury' 1='(1) Knocked down' 2='(2) Bruised' 3='(3) Cut/bleeding'
                  4='(4) Unconscious' 5='(5) Hospitalized'
                  6='(6) Required medical treatment' 7='(7) Other' ;
  VALUE y7_670ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_671ff  0='(0) No' ;
  VALUE y7_672ff  0='(0) No' ;
  VALUE y7_673ff  1='(1) l-2 people' 2='(2) 3-5' 3='(3) More than 5 people' ;
  VALUE y7_674ff  1='(1) l-2 people' 2='(2) 3-5' 3='(3) More than 5 people' ;
  VALUE y7_675ff  0='(0) No weapons' 1='(1) Knives, cutting/stabbing things'
                  2='(2) Chains, bats/hitting things' 3='(3) Hard knuckles/numchucks'
                  4='(4) Guns and other firearms' 5='(5) Other'
                  6='(6) Mixed weapons excluding guns'
                  7='(7) Mixed weapons including guns'
                  8='(8) Mixed weapons-no gun or knife types' ;
  VALUE y7_676ff  0='(0) No injury' 1='(1) Knocked down' 2='(2) Bruised' 3='(3) Cut/bleeding'
                  4='(4) Unconscious' 5='(5) Hospitalized'
                  6='(6) Required medical treatment' 7='(7) Other' ;
  VALUE y7_677ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_678ff  0='(0) No' ;
  VALUE y7_679ff  0='(0) No' ;
  VALUE y7_680ff  1='(1) l-2 people' 2='(2) 3-5' 3='(3) More than 5 people' ;
  VALUE y7_681ff  1='(1) l-2 people' 2='(2) 3-5' 3='(3) More than 5 people' ;
  VALUE y7_682ff  0='(0) No weapons' 1='(1) Knives, cutting/stabbing things'
                  2='(2) Chains, bats/hitting things' 3='(3) Hard knuckles/numchucks'
                  4='(4) Guns and other firearms' 5='(5) Other'
                  6='(6) Mixed weapons excluding guns'
                  7='(7) Mixed weapons including guns'
                  8='(8) Mixed weapons-no gun or knife types' ;
  VALUE y7_683ff  0='(0) No injury' 1='(1) Knocked down' 2='(2) Bruised' 3='(3) Cut/bleeding'
                  4='(4) Unconscious' 5='(5) Hospitalized'
                  6='(6) Required medical treatment' 7='(7) Other' ;
  VALUE y7_684ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_685ff  0='(0) No' ;
  VALUE y7_686ff  0='(0) No' ;
  VALUE y7_687ff  1='(1) Overdraft' 2='(2) Forged check' 3='(3) Cashed someones check'
                  4='(4) Counterfeit money' 5='(5) Other' ;
  VALUE y7_689ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_690ff  0='(0) No' ;
  VALUE y7_691ff  0='(0) No' ;
  VALUE y7_694ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_695ff  0='(0) No' ;
  VALUE y7_696ff  0='(0) No' ;
  VALUE y7_697ff  1='(1) Money' 2='(2) Other' 3='(3) Both' ;
  VALUE y7_700ff  1='(1) Use it yourself' 2='(2) Give it away' 3='(3) Sell it' 4='(4) Other' ;
  VALUE y7_701ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_702ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_703ff  0='(0) No' ;
  VALUE y7_704ff  0='(0) No' ;
  VALUE y7_705ff  1='(1) Money' 2='(2) Other' 3='(3) Both' ;
  VALUE y7_708ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_709ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_710ff  0='(0) No' ;
  VALUE y7_711ff  0='(0) No' ;
  VALUE y7_712ff  1='(1) Actually forced' 2='(2) Tried but didnt succeed' ;
  VALUE y7_713ff  1='(1) Verbal threats of injury' 2='(2) Mild roughness'
                  3='(3) Physical beating/choking' 4='(4) Threat of weapon'
                  5='(5) Used a weapon' 6='(6) Other' ;
  VALUE y7_714ff  0='(0) No injury' 1='(1) Knocked down' 2='(2) Bruised' 3='(3) Cut/bleeding'
                  4='(4) Unconscious' 5='(5) Hospitalized'
                  6='(6) Required medical treatment' 7='(7) Other' ;
  VALUE y7_715ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_716ff  1='(1) A stranger' 2='(2) An acquaintance' 3='(3) A friend'
                  4='(4) Family member' 5='(5) Other' ;
  VALUE y7_717ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_718ff  0='(0) No' ;
  VALUE y7_719ff  0='(0) No' ;
  VALUE y7_720ff  1='(1) Actually forced' 2='(2) Tried but didnt succeed' ;
  VALUE y7_721ff  1='(1) Verbal threats of injury' 2='(2) Mild roughness'
                  3='(3) Physical beating/choking' 4='(4) Threat of weapon'
                  5='(5) Used a weapon' 6='(6) Other' ;
  VALUE y7_722ff  0='(0) No injury' 1='(1) Knocked down' 2='(2) Bruised' 3='(3) Cut/bleeding'
                  4='(4) Unconscious' 5='(5) Hospitalized'
                  6='(6) Required medical treatment' 7='(7) Other' ;
  VALUE y7_723ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_724ff  1='(1) A stranger' 2='(2) An acquaintance' 3='(3) A friend'
                  4='(4) Family member' 5='(5) Other' ;
  VALUE y7_725ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_726ff  0='(0) No' ;
  VALUE y7_727ff  0='(0) No' ;
  VALUE y7_728ff  1='(1) Actually forced' 2='(2) Tried but didnt succeed' ;
  VALUE y7_729ff  1='(1) Verbal threats of injury' 2='(2) Mild roughness'
                  3='(3) Physical beating/choking' 4='(4) Threat of weapon'
                  5='(5) Used a weapon' 6='(6) Other' ;
  VALUE y7_730ff  0='(0) No injury' 1='(1) Knocked down' 2='(2) Bruised' 3='(3) Cut/bleeding'
                  4='(4) Unconscious' 5='(5) Hospitalized'
                  6='(6) Required medical treatment' 7='(7) Other' ;
  VALUE y7_731ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_732ff  1='(1) A stranger' 2='(2) An acquaintance' 3='(3) A friend'
                  4='(4) Family member' 5='(5) Other' ;
  VALUE y7_733ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_734ff  0='(0) No' ;
  VALUE y7_735ff  0='(0) No' ;
  VALUE y7_736ff  1='(1) Actually hit' 2='(2) Tried, didnt succeed'
                  3='(3) Only threatened to hit' ;
  VALUE y7_737ff  0='(0) No injury' 1='(1) Pushed or slapped' 2='(2) Caused pain'
                  3='(3) knocked down' 4='(4) Bruised' 5='(5) Cut/bleeding'
                  6='(6) Unconscious' 7='(7) Hospitalized'
                  8='(8) Required medical treatment' 9='(9) Other' ;
  VALUE y7_738ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_739ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_740ff  0='(0) No' ;
  VALUE y7_741ff  0='(0) No' ;
  VALUE y7_742ff  1='(1) Actually hit' 2='(2) Tried, didnt succeed'
                  3='(3) Only threatened to hit' ;
  VALUE y7_743ff  0='(0) No injury' 1='(1) Pushed or slapped' 2='(2) Caused pain'
                  3='(3) knocked down' 4='(4) Bruised' 5='(5) Cut/bleeding'
                  6='(6) Unconscious' 7='(7) Hospitalized'
                  8='(8) Required medical treatment' 9='(9) Other' ;
  VALUE y7_744ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_745ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_746ff  0='(0) No' ;
  VALUE y7_747ff  0='(0) No' ;
  VALUE y7_748ff  1='(1) Actually hit' 2='(2) Tried, didnt succeed'
                  3='(3) Only threatened to hit' ;
  VALUE y7_749ff  0='(0) No injury' 1='(1) Pushed or slapped' 2='(2) Caused pain'
                  3='(3) knocked down' 4='(4) Bruised' 5='(5) Cut/bleeding'
                  6='(6) Unconscious' 7='(7) Hospitalized'
                  8='(8) required medical treatment' 9='(9) Other' ;
  VALUE y7_750ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_751ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_752ff  0='(0) No' ;
  VALUE y7_753ff  0='(0) No' ;
  VALUE y7_754ff  1='(1) Marijuana' 2='(2) Pills' 3='(3) Cocaine' 4='(4) Heroin' 5='(5) Other' ;
  VALUE y7_756ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_757ff  0='(0) No' ;
  VALUE y7_758ff  0='(0) No' ;
  VALUE y7_759ff  1='(1) Stranger' 2='(2) Family member' 3='(3) Friend' 4='(4) Other' ;
  VALUE y7_762ff  1='(1) Actually sold it' 2='(2) Tried to sell it' ;
  VALUE y7_763ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_764ff  0='(0) No' ;
  VALUE y7_765ff  0='(0) No' ;
  VALUE y7_766ff  1='(1) Car' 2='(2) Truck' 3='(3) Motorcycle' 4='(4) Other' ;
  VALUE y7_767ff  1='(1) Family member' 2='(2) Friend' 3='(3) Other' ;
  VALUE y7_768ff  1='(1) Had keys' 2='(2) Hot wired' 3='(3) Keys in ignition' 4='(4) Other' ;
  VALUE y7_769ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_770ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_771ff  0='(0) No' ;
  VALUE y7_772ff  0='(0) No' ;
  VALUE y7_773ff  1='(1) Punched' 2='(2) Physical beating' 3='(3) Other' ;
  VALUE y7_774ff  0='(0) No weapons' 1='(1) Knives, cutting/stabbing things'
                  2='(2) Chains, bats/hitting things' 3='(3) Hard knuckles/numchucks'
                  4='(4) Guns and other firearms' 5='(5) Other'
                  6='(6) Mixed weapons excluding guns'
                  7='(7) Mixed weapons including guns'
                  8='(8) Mixed weapons-no gun or knife types' ;
  VALUE y7_775ff  1='(1) Money' 2='(2) Other' ;
  VALUE y7_776ff  0='(0) No injury' 1='(1) Knocked down' 2='(2) Bruised' 3='(3) Cut/bleeding'
                  4='(4) Unconscious' 5='(5) Hospitalized'
                  6='(6) Required medical treatment' 7='(7) Other' ;
  VALUE y7_777ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_778ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_779ff  0='(0) No' ;
  VALUE y7_780ff  0='(0) No' ;
  VALUE y7_781ff  1='(1) Punched' 2='(2) Physical beating' 3='(3) Other' ;
  VALUE y7_782ff  0='(0) No weapons' 1='(1) Knives, cutting/stabbing things'
                  2='(2) Chains, bats/hitting things' 3='(3) Hard knuckles/numchucks'
                  4='(4) Guns and other firearms' 5='(5) Other'
                  6='(6) Mixed weapons excluding guns'
                  7='(7) Mixed weapons including guns'
                  8='(8) Mixed weapons-no gun or knife types' ;
  VALUE y7_783ff  1='(1) Money' 2='(2) Other' ;
  VALUE y7_784ff  0='(0) No injury' 1='(1) Knocked down' 2='(2) Bruised' 3='(3) Cut/bleeding'
                  4='(4) Unconscious' 5='(5) Hospitalized'
                  6='(6) Required medical treatment' 7='(7) Other' ;
  VALUE y7_785ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_786ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_787ff  0='(0) No' ;
  VALUE y7_788ff  0='(0) No' ;
  VALUE y7_789ff  1='(1) Punched' 2='(2) Physical beating' 3='(3) Other' ;
  VALUE y7_790ff  0='(0) No weapons' 1='(1) Knives, cutting/stabbing things'
                  2='(2) Chains, bats/hitting things' 3='(3) Hard knuckles/numchucks'
                  4='(4) Guns and other firearms' 5='(5) Other'
                  6='(6) Mixed weapons excluding guns'
                  7='(7) Mixed weapons including guns'
                  8='(8) Mixed weapons-no gun or knife types' ;
  VALUE y7_791ff  1='(1) Money' 2='(2) Other' ;
  VALUE y7_792ff  0='(0) No injury' 1='(1) Knocked down' 2='(2) Bruised' 3='(3) Cut/bleeding'
                  4='(4) Unconscious' 5='(5) Hospitalized'
                  6='(6) Required medical treatment' 7='(7) Other' ;
  VALUE y7_793ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_794ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_795ff  0='(0) No' ;
  VALUE y7_796ff  0='(0) No' ;
  VALUE y7_798ff  1='(1) Retail store' 2='(2) Private home' 3='(3) Auto' 4='(4) Work place'
                  5='(5) School/college' 6='(6) Construction site' 7='(7) Warehouse'
                  8='(8) Other' ;
  VALUE y7_799ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_800ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_801ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_802ff  0='(0) No' ;
  VALUE y7_803ff  0='(0) No' ;
  VALUE y7_804ff  1='(1) Building' 2='(2) Vehicle' 3='(3) House' 4='(4) Other' ;
  VALUE y7_805ff  1='(1) Broke in' 2='(2) Tried' 3='(3) Door open' ;
  VALUE y7_806ff  1='(1) Look around' 2='(2) Steal' 3='(3) Other' ;
  VALUE y7_807ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_808ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_809ff  0='(0) No' ;
  VALUE y7_810ff  0='(0) No' ;
  VALUE y7_811ff  1='(1) Building' 2='(2) Vehicle' 3='(3) House' 4='(4) Other' ;
  VALUE y7_812ff  1='(1) Broke in' 2='(2) Tried' 3='(3) Door open' ;
  VALUE y7_813ff  1='(1) Look around' 2='(2) Steal' 3='(3) Other' ;
  VALUE y7_814ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_815ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_816ff  0='(0) No' ;
  VALUE y7_817ff  0='(0) No' ;
  VALUE y7_818ff  1='(1) Building' 2='(2) Vehicle' 3='(3) House' 4='(4) Other' ;
  VALUE y7_819ff  1='(1) Broke in' 2='(2) Tried' 3='(3) Door open' ;
  VALUE y7_820ff  1='(1) Look around' 2='(2) Steal' 3='(3) Other' ;
  VALUE y7_821ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_822ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_823ff  0='(0) No' ;
  VALUE y7_824ff  0='(0) No' ;
  VALUE y7_825ff  1='(1) Stranger' 2='(2) Family member' 3='(3) Friend' 4='(4) Other' ;
  VALUE y7_827ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_828ff  0='(0) No' ;
  VALUE y7_829ff  0='(0) No' ;
  VALUE y7_830ff  1='(1) Purse snatching' 2='(2) Pick pocket' 3='(3) Other' ;
  VALUE y7_831ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_832ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_833ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_834ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_835ff  0='(0) Alone' 1='(1) 1 person' 2='(2) 2 people' 3='(3) 3 people'
                  4='(4) 4 people' 5='(5) 5 people' 6='(6) 6 people' 7='(7) 7 people'
                  8='(8) 8 people' 9='(9) 9 people' ;
  VALUE y7_836ff  0='(0) No' 1='(1) Drinking' 2='(2) Using drugs' 3='(3) Drinking and drugs' ;
  VALUE y7_837ff  0='(0) No' ;
  VALUE y7_838ff  0='(0) No' ;
  VALUE y7_840ff  0='(0) No' ;
  VALUE y7_841ff  0='(0) No' ;
  VALUE y7_843ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_844ff  1='(1) LT 2 weeks' 2='(2) 2 to 4 weeks' 3='(3) GT 1 to 2 months'
                  4='(4) GT 2 to 3 months' 5='(5) GT 3 to 4 months'
                  6='(6) GT 4 to 6 months' 7='(7) GT 6 months' ;
  VALUE y7_845ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_846ff  1='(1) LT 2 weeks' 2='(2) 2 to 4 weeks' 3='(3) GT 1 to 2 months'
                  4='(4) GT 2 to 3 months' 5='(5) GT 3 to 4 months'
                  6='(6) GT 4 to 6 months' 7='(7) GT 6 months' ;
  VALUE y7_851ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_852ff  1='(1) LT 2 weeks' 2='(2) 2 to 4 weeks' 3='(3) GT 1 to 2 months'
                  4='(4) GT 2 to 3 months' 5='(5) GT 3 to 4 months'
                  6='(6) GT 4 to 6 months' 7='(7) GT 6 months' ;
  VALUE y7_854ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_855ff  1='(1) LT 2 weeks' 2='(2) 2 to 4 weeks' 3='(3) GT 1 to 2 months'
                  4='(4) GT 2 to 3 months' 5='(5) GT 3 to 4 months'
                  6='(6) GT 4 to 6 months' 7='(7) GT 6 months' ;
  VALUE y7_857ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_858ff  1='(1) LT 2 weeks' 2='(2) 2 to 4 weeks' 3='(3) GT 1 to 2 months'
                  4='(4) GT 2 to 3 months' 5='(5) GT 3 to 4 months'
                  6='(6) GT 4 to 6 months' 7='(7) GT 6 months' ;
  VALUE y7_861ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_862ff  1='(1) LT 2 weeks' 2='(2) 2 to 4 weeks' 3='(3) GT 1 to 2 months'
                  4='(4) GT 2 to 3 months' 5='(5) GT 3 to 4 months'
                  6='(6) GT 4 to 6 months' 7='(7) GT 6 months' ;
  VALUE y7_865ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_866ff  1='(1) LT 2 weeks' 2='(2) 2 to 4 weeks' 3='(3) GT 1 to 2 months'
                  4='(4) GT 2 to 3 months' 5='(5) GT 3 to 4 months'
                  6='(6) GT 4 to 6 months' 7='(7) GT 6 months' ;
  VALUE y7_869ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_870ff  1='(1) LT 2 weeks' 2='(2) 2 to 4 weeks' 3='(3) GT 1 to 2 months'
                  4='(4) GT 2 to 3 months' 5='(5) GT 3 to 4 months'
                  6='(6) GT 4 to 6 months' 7='(7) GT 6 months' ;
  VALUE y7_873ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_874ff  1='(1) LT 2 weeks' 2='(2) 2 to 4 weeks' 3='(3) GT 1 to 2 months'
                  4='(4) GT 2 to 3 months' 5='(5) GT 3 to 4 months'
                  6='(6) GT 4 to 6 months' 7='(7) GT 6 months' ;
  VALUE y7_876ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_877ff  1='(1) LT 2 weeks' 2='(2) 2 to 4 weeks' 3='(3) GT 1 to 2 months'
                  4='(4) GT 2 to 3 months' 5='(5) GT 3 to 4 months'
                  6='(6) GT 4 to 6 months' 7='(7) GT 6 months' ;
  VALUE y7_879ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_880ff  1='(1) LT 2 weeks' 2='(2) 2 to 4 weeks' 3='(3) GT 1 to 2 months'
                  4='(4) GT 2 to 3 months' 5='(5) GT 3 to 4 months'
                  6='(6) GT 4 to 6 months' 7='(7) GT 6 months' ;
  VALUE y7_882ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_883ff  1='(1) LT 2 weeks' 2='(2) 2 to 4 weeks' 3='(3) GT 1 to 2 months'
                  4='(4) GT 2 to 3 months' 5='(5) GT 3 to 4 months'
                  6='(6) GT 4 to 6 months' 7='(7) GT 6 months' ;
  VALUE y7_885ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_886ff  1='(1) LT 2 weeks' 2='(2) 2 to 4 weeks' 3='(3) GT 1 to 2 months'
                  4='(4) GT 2 to 3 months' 5='(5) GT 3 to 4 months'
                  6='(6) GT 4 to 6 months' 7='(7) GT 6 months' ;
  VALUE y7_887ff  1='(1) THC' 2='(2) Quaaludes' 3='(3) Cough medicine' 4='(4) Robitussin'
                  5='(5) Sominex' 6='(6) Sudafed' 7='(7) No-Doze' 8='(8) Demerol'
                  9='(9) Weight control pills' 10='(10) Coricidin' 11='(11) Mushrooms'
                  12='(12) MDA' 13='(13) Pam' 99='(99) Other' ;
  VALUE y7_889ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_890ff  1='(1) LT 2 weeks' 2='(2) 2 to 4 weeks' 3='(3) GT 1 to 2 months'
                  4='(4) GT 2 to 3 months' 5='(5) GT 3 to 4 months'
                  6='(6) GT 4 to 6 months' 7='(7) GT 6 months' ;
  VALUE y7_892ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Once every 2-3 months'
                  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_893ff  1='(1) LT 2 weeks' 2='(2) 2 to 4 weeks' 3='(3) GT 1 to 2 months'
                  4='(4) GT 2 to 3 months' 5='(5) GT 3 to 4 months'
                  6='(6) GT 4 to 6 months' 7='(7) GT 6 months' ;
  VALUE y7_894ff  0='(0) No' 1='(1) Heroin' 2='(2) Cocaine' 3='(3) Other drugs'
                  4='(4) Heroin and cocaine' 5='(5) Other comb incl heroin'
                  6='(6) Other comb incl cocaine' 7='(7) Comb incl heroin and' ;
  VALUE y7_895ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_896ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE y7_897ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE y7_898ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE y7_899ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE y7_900ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE y7_901ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE y7_902ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE y7_903ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE y7_904ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE y7_905ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE y7_906ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE y7_907ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE y7_908ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE y7_909ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE y7_910ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE y7_911ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE y7_912ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE y7_913ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE y7_914ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE y7_915ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE y7_916ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE y7_917ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE y7_918ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE y7_919ff  1='(1) Never' 2='(2) Once or twice' 3='(3) Three or four times'
                  4='(4) Five or six times' 5='(5) More than six times' ;
  VALUE y7_920ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_921ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_922ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_923ff  1='(1) Yes' ;
  VALUE y7_924ff  1='(1) Yes' ;
  VALUE y7_925ff  1='(1) Yes' ;
  VALUE y7_926ff  1='(1) Yes' ;
  VALUE y7_927ff  1='(1) Yes' ;
  VALUE y7_928ff  1='(1) Yes' ;
  VALUE y7_929ff  1='(1) Yes' ;
  VALUE y7_930ff  1='(1) Yes' ;
  VALUE y7_931ff  1='(1) Yes' ;
  VALUE y7_932ff  1='(1) Yes' ;
  VALUE y7_933ff  1='(1) Yes' ;
  VALUE y7_934ff  1='(1) Yes' ;
  VALUE y7_944ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_945ff  99='(99) Cant remember' ;
  VALUE y7_946ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_947ff  99='(99) Cant remember' ;
  VALUE y7_948ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_949ff  99='(99) Cant remember' ;
  VALUE y7_950ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_951ff  99='(99) Cant remember' ;
  VALUE y7_952ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_953ff  99='(99) Cant remember' ;
  VALUE y7_954ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_955ff  99='(99) Cant remember' ;
  VALUE y7_956ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_957ff  99='(99) Cant remember' ;
  VALUE y7_958ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_959ff  99='(99) Cant remember' ;
  VALUE y7_960ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_961ff  99='(99) Cant remember' ;
  VALUE y7_962ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_963ff  99='(99) Cant remember' ;
  VALUE y7_964ff  1='(1) No' 2='(2) Yes' ;
  VALUE y7_965ff  99='(99) Cant remember' ;
  VALUE y7_966ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_967ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_968ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_969ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_970ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_971ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_972ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_973ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_974ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_975ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_976ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_977ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_978ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_979ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_980ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_981ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_982ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_983ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_984ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_985ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_986ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_987ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_988ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_989ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_990ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_991ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_992ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_993ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_994ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_995ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_996ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_997ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_998ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_999ff  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1000f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1001f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1002f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1003f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1004f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1005f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1006f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1007f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1008f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1009f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1010f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1011f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1012f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1013f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1014f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1015f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1016f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1017f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1018f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1019f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1020f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1021f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1022f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1023f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1024f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1025f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1026f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1027f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1028f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1029f  1='(1) Never' 2='(2) 1-2 Times' 3='(3) 3-11 Times' 4='(4) 12 or More Times' ;
  VALUE y7_1030f  0='(0) No' ;
  VALUE y7_1031f  1='(1) Jan' 2='(2) Feb' 3='(3) Mar' 4='(4) Apr' 5='(5) May' 6='(6) Jun' 7='(7) Jul'
                  8='(8) Aug' 9='(9) Sept' 10='(10) Oct' 11='(11) Nov' 12='(12) Dec' 13='(13) Winter'
                  14='(14) Spring' 15='(15) Summer' 16='(16) Fall' 99='(99) Unknown' ;
  VALUE y7_1032f  84='(84) 1984' 85='(85) 1985' 86='(86) 1986' ;
  VALUE y7_1039f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1040f  1='(1) Jan' 2='(2) Feb' 3='(3) Mar' 4='(4) Apr' 5='(5) May' 6='(6) Jun' 7='(7) Jul'
                  8='(8) Aug' 9='(9) Sept' 10='(10) Oct' 11='(11) Nov' 12='(12) Dec' 13='(13) Winter'
                  14='(14) Spring' 15='(15) Summer' 16='(16) Fall' 99='(99) Unknown' ;
  VALUE y7_1041f  84='(84) 1984' 85='(85) 1985' 86='(86) 1986' ;
  VALUE y7_1048f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1049f  1='(1) Jan' 2='(2) Feb' 3='(3) Mar' 4='(4) Apr' 5='(5) May' 6='(6) Jun' 7='(7) Jul'
                  8='(8) Aug' 9='(9) Sept' 10='(10) Oct' 11='(11) Nov' 12='(12) Dec' 13='(13) Winter'
                  14='(14) Spring' 15='(15) Summer' 16='(16) Fall' 99='(99) Unknown' ;
  VALUE y7_1050f  84='(84) 1984' 85='(85) 1985' 86='(86) 1986' ;
  VALUE y7_1057f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1058f  0='(0) No' ;
  VALUE y7_1059f  1='(1) Jan' 2='(2) Feb' 3='(3) Mar' 4='(4) Apr' 5='(5) May' 6='(6) Jun' 7='(7) Jul'
                  8='(8) Aug' 9='(9) Sept' 10='(10) Oct' 11='(11) Nov' 12='(12) Dec' 13='(13) Winter'
                  14='(14) Spring' 15='(15) Summer' 16='(16) Fall' 99='(99) Unknown' ;
  VALUE y7_1060f  84='(84) 1984' 85='(85) 1985' 86='(86) 1986' ;
  VALUE y7_1062f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1064f  1='(1) No police action' 2='(2) Asked questions, no action'
                  3='(3) Took Respondent home, no action'
                  4='(4) Investigation report/complaint'
                  5='(5) Temporarily detained/questioned'
                  6='(6) Arrested/released on bail' 7='(7) Placed in custody/jailed'
                  9='(9) Other' ;
  VALUE y7_1065f  1='(1) Jan' 2='(2) Feb' 3='(3) Mar' 4='(4) Apr' 5='(5) May' 6='(6) Jun' 7='(7) Jul'
                  8='(8) Aug' 9='(9) Sept' 10='(10) Oct' 11='(11) Nov' 12='(12) Dec' 13='(13) Winter'
                  14='(14) Spring' 15='(15) Summer' 16='(16) Fall' 99='(99) Unknown' ;
  VALUE y7_1066f  84='(84) 1984' 85='(85) 1985' 86='(86) 1986' ;
  VALUE y7_1068f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1071f  1='(1) Jan' 2='(2) Feb' 3='(3) Mar' 4='(4) Apr' 5='(5) May' 6='(6) Jun' 7='(7) Jul'
                  8='(8) Aug' 9='(9) Sept' 10='(10) Oct' 11='(11) Nov' 12='(12) Dec' 13='(13) Winter'
                  14='(14) Spring' 15='(15) Summer' 16='(16) Fall' 99='(99) Unknown' ;
  VALUE y7_1072f  84='(84) 1984' 85='(85) 1985' 86='(86) 1986' ;
  VALUE y7_1074f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1076f  1='(1) No police action' 2='(2) Asked questions, no action'
                  3='(3) Took Respondent home, no action'
                  4='(4) Investigation report/complaint'
                  5='(5) Temporarily detained/questioned'
                  6='(6) Arrested/released on bail' 7='(7) Placed in custody/jailed'
                  9='(9) Other' ;
  VALUE y7_1077f  0='(0) No' 1='(1) Juvenile Court' 2='(2) Adult Court' 3='(3) Both' ;
  VALUE y7_1079f  0='(0) Never convicted' ;
  VALUE y7_1083f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1092f  0='(0) 0% chance' 1='(1) 10% chance' 2='(2) 20% chance' 3='(3) 30% chance'
                  4='(4) 40% chance' 5='(5) 50% chance' 6='(6) 60% chance' 7='(7) 70% chance'
                  8='(8) 80% chance' 9='(9) 90% chance' 10='(10) 100% chance' ;
  VALUE y7_1093f  0='(0) 0% chance' 1='(1) 10% chance' 2='(2) 20% chance' 3='(3) 30% chance'
                  4='(4) 40% chance' 5='(5) 50% chance' 6='(6) 60% chance' 7='(7) 70% chance'
                  8='(8) 80% chance' 9='(9) 90% chance' 10='(10) 100% chance' ;
  VALUE y7_1094f  0='(0) 0% chance' 1='(1) 10% chance' 2='(2) 20% chance' 3='(3) 30% chance'
                  4='(4) 40% chance' 5='(5) 50% chance' 6='(6) 60% chance' 7='(7) 70% chance'
                  8='(8) 80% chance' 9='(9) 90% chance' 10='(10) 100% chance' ;
  VALUE y7_1095f  0='(0) 0% chance' 1='(1) 10% chance' 2='(2) 20% chance' 3='(3) 30% chance'
                  4='(4) 40% chance' 5='(5) 50% chance' 6='(6) 60% chance' 7='(7) 70% chance'
                  8='(8) 80% chance' 9='(9) 90% chance' 10='(10) 100% chance' ;
  VALUE y7_1096f  0='(0) 0% chance' 1='(1) 10% chance' 2='(2) 20% chance' 3='(3) 30% chance'
                  4='(4) 40% chance' 5='(5) 50% chance' 6='(6) 60% chance' 7='(7) 70% chance'
                  8='(8) 80% chance' 9='(9) 90% chance' 10='(10) 100% chance' ;
  VALUE y7_1097f  0='(0) 0% chance' 1='(1) 10% chance' 2='(2) 20% chance' 3='(3) 30% chance'
                  4='(4) 40% chance' 5='(5) 50% chance' 6='(6) 60% chance' 7='(7) 70% chance'
                  8='(8) 80% chance' 9='(9) 90% chance' 10='(10) 100% chance' ;
  VALUE y7_1098f  0='(0) 0% chance' 1='(1) 10% chance' 2='(2) 20% chance' 3='(3) 30% chance'
                  4='(4) 40% chance' 5='(5) 50% chance' 6='(6) 60% chance' 7='(7) 70% chance'
                  8='(8) 80% chance' 9='(9) 90% chance' 10='(10) 100% chance' ;
  VALUE y7_1099f  1='(1) Released without charges' 2='(2) Dismissed at court'
                  3='(3) Fined and released' 4='(4) Probation/suspended sentence'
                  5='(5) Short time in jail' 6='(6) Long time in jail'
                  7='(7) Serious punishment' 8='(8) Nonserious punishment'
                  9='(9) No punishment' ;
  VALUE y7_1100f  1='(1) Released without charges' 2='(2) Dismissed at court'
                  3='(3) Fined and released' 4='(4) Probation/suspended sentence'
                  5='(5) Short time in jail' 6='(6) Long time in jail'
                  7='(7) Serious punishment' 8='(8) Nonserious punishment'
                  9='(9) No punishment' ;
  VALUE y7_1101f  1='(1) Released without charges' 2='(2) Dismissed at court'
                  3='(3) Fined and released' 4='(4) Probation/suspended sentence'
                  5='(5) Short time in jail' 6='(6) Long time in jail'
                  7='(7) Serious punishment' 8='(8) Nonserious punishment'
                  9='(9) No punishment' ;
  VALUE y7_1102f  1='(1) Released without charges' 2='(2) Dismissed at court'
                  3='(3) Fined and released' 4='(4) Probation/suspended sentence'
                  5='(5) Short time in jail' 6='(6) Long time in jail'
                  7='(7) Serious punishment' 8='(8) Nonserious punishment'
                  9='(9) No punishment' ;
  VALUE y7_1103f  1='(1) Released without charges' 2='(2) Dismissed at court'
                  3='(3) Fined and released' 4='(4) Probation/suspended sentence'
                  5='(5) Short time in jail' 6='(6) Long time in jail'
                  7='(7) Serious punishment' 8='(8) Nonserious punishment'
                  9='(9) No punishment' ;
  VALUE y7_1104f  1='(1) Released without charges' 2='(2) Dismissed at court'
                  3='(3) Fined and released' 4='(4) Probation/suspended sentence'
                  5='(5) Short time in jail' 6='(6) Long time in jail'
                  7='(7) Serious punishment' 8='(8) Nonserious punishment'
                  9='(9) No punishment' ;
  VALUE y7_1105f  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_1106f  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_1107f  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_1108f  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_1109f  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_1110f  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_1111f  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_1112f  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_1113f  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_1114f  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_1115f  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_1116f  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_1119f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1120f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1121f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1122f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1125f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1126f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1127f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1128f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1129f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1130f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1131f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1132f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1133f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1134f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1135f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1136f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1137f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1138f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1140f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1141f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1142f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1143f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1144f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1145f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1146f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1147f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1148f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1149f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1150f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1151f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1152f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1153f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1157f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1158f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1159f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1160f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1161f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1162f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1163f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1164f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1165f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1166f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1167f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1168f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1169f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1173f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1174f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1175f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1177f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1182f  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_1183f  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_1184f  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_1185f  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_1186f  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_1187f  1='(1) Strongly disagree' 2='(2) Disagree'
                  3='(3) Neither agree nor disagree' 4='(4) Agree' 5='(5) Strongly agree' ;
  VALUE y7_1188f  1='(1) Yes' 2='(2) No' ;
  VALUE y7_1189f  0='(0) No problem' 1='(1) Orthopedic problems'
                  2='(2) Endocrinology problems' 3='(3) Ear/eye/nose/throat'
                  4='(4) Heart disease' 5='(5) Blood/circulatory' 6='(6) Urological'
                  7='(7) Skin problems' 8='(8) Neurological' 9='(9) Pulmonary'
                  10='(10) Cancer' 11='(11) Other' ;
  VALUE y7_1190f  0='(0) No problem' 1='(1) Orthopedic problems'
                  2='(2) Endocrinology problems' 3='(3) Ear/eye/nose/throat'
                  4='(4) Heart disease' 5='(5) Blood/circulatory' 6='(6) Urological'
                  7='(7) Skin problems' 8='(8) Neurological' 9='(9) Pulmonary'
                  10='(10) Cancer' 11='(11) Other' ;
  VALUE y7_1191f  0='(0) No problem' 1='(1) Orthopedic problems'
                  2='(2) Endocrinology problems' 3='(3) Ear/eye/nose/throat'
                  4='(4) Heart disease' 5='(5) Blood/circulatory' 6='(6) Urological'
                  7='(7) Skin problems' 8='(8) Neurological' 9='(9) Pulmonary'
                  10='(10) Cancer' 11='(11) Other' ;
  VALUE y7_1192f  0='(0) No problem' 1='(1) Orthopedic problems'
                  2='(2) Endocrinology problems' 3='(3) Ear/eye/nose/throat'
                  4='(4) Heart disease' 5='(5) Blood/circulatory' 6='(6) Urological'
                  7='(7) Skin problems' 8='(8) Neurological' 9='(9) Pulmonary'
                  10='(10) Cancer' 11='(11) Other' ;
  VALUE y7_1193f  1='(1) Yes' 2='(2) No' 8='(8) Dont know' ;
  VALUE y7_1194f  1='(1) Gonorrhea' 2='(2) Genital herpes' 3='(3) Syphilis' 4='(4) Clap'
                  5='(5) Other' ;
  VALUE y7_1195f  1='(1) Yes' 2='(2) No' ;
  VALUE y7_1197f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1198f  1='(1) Negative' 2='(2) Positive' 3='(3) Outcome unknown' 4='(4) Refused' ;
  VALUE y7_1199f  1='(1) Excellent' 2='(2) Very good' 3='(3) Good' 4='(4) Fair' 5='(5) Poor' ;
  VALUE y7_1200f  88='(88) Cant remember' ;
  VALUE y7_1201f  1='(1) Yes' 2='(2) No' ;
  VALUE y7_1202f  83='(83) 1983' 84='(84) 1984' 85='(85) 1985' 86='(86) 1986' ;
  VALUE y7_1203f  1='(1) Live birth' 2='(2) Abortion' 3='(3) Miscarriage' 4='(4) Stillbirth'
                  5='(5) Currently pregnant' 8='(8) Other' ;
  VALUE y7_1204f  0='(0) No' 1='(1) Difficult labor/delivery' 2='(2) C-section'
                  3='(3) Urological problems' 4='(4) Respiratory/cardiac distress'
                  5='(5) Atopic pregnancy' 6='(6) Miscarriage (or threat of)'
                  7='(7) Difficult presentation' 8='(8) Drug addiction'
                  9='(9) Phlebitis, hemorrhoids'
                  10='(10) Hemorrhaging during delivery' 11='(11) Other' ;
  VALUE y7_1205f  0='(0) No' 1='(1) Difficult labor/delivery' 2='(2) C-section'
                  3='(3) Urological problems' 4='(4) Respiratory/cardiac distress'
                  5='(5) Atopic pregnancy' 6='(6) Miscarriage (or threat of)'
                  7='(7) Difficult presentation' 8='(8) Drug addiction'
                  9='(9) Phlebitis, hemorrhoids'
                  10='(10) Hemorrhaging during delivery' 11='(11) Other' ;
  VALUE y7_1206f  1='(1) Involuntary' 2='(2) Voluntary' ;
  VALUE y7_1207f  83='(83) 1983' 84='(84) 1984' 85='(85) 1985' 86='(86) 1986' ;
  VALUE y7_1208f  1='(1) Live birth' 2='(2) Abortion' 3='(3) Miscarriage' 4='(4) Stillbirth'
                  5='(5) Currently pregnant' 8='(8) Other' ;
  VALUE y7_1209f  0='(0) No' 1='(1) Difficult labor/delivery' 2='(2) C-section'
                  3='(3) Urological problems' 4='(4) Respiratory/cardiac distress'
                  5='(5) Atopic pregnancy' 6='(6) Miscarriage (or threat of)'
                  7='(7) Difficult presentation' 8='(8) Drug addiction'
                  9='(9) Phlebitis, hemorrhoids'
                  10='(10) Hemorrhaging during delivery' 11='(11) Other' ;
  VALUE y7_1210f  0='(0) No' 1='(1) Difficult labor/delivery' 2='(2) C-section'
                  3='(3) Urological problems' 4='(4) Respiratory/cardiac distress'
                  5='(5) Atopic pregnancy' 6='(6) Miscarriage (or threat of)'
                  7='(7) Difficult presentation' 8='(8) Drug addiction'
                  9='(9) Phlebitis, hemorrhoids'
                  10='(10) Hemorrhaging during delivery' 11='(11) Other' ;
  VALUE y7_1211f  1='(1) Involuntary' 2='(2) Voluntary' ;
  VALUE y7_1212f  83='(83) 1983' 84='(84) 1984' 85='(85) 1985' 86='(86) 1986' ;
  VALUE y7_1213f  1='(1) Live birth' 2='(2) Abortion' 3='(3) Miscarriage' 4='(4) Stillbirth'
                  5='(5) Currently pregnant' 8='(8) Other' ;
  VALUE y7_1214f  0='(0) No' 1='(1) Difficult labor/delivery' 2='(2) C-section'
                  3='(3) Urological problems' 4='(4) Respiratory/cardiac distress'
                  5='(5) Atopic pregnancy' 6='(6) Miscarriage (or threat of)'
                  7='(7) Difficult presentation' 8='(8) Drug addiction'
                  9='(9) Phlebitis, hemorrhoids'
                  10='(10) Hemorrhaging during delivery' 11='(11) Other' ;
  VALUE y7_1215f  0='(0) No' 1='(1) Difficult labor/delivery' 2='(2) C-section'
                  3='(3) Urological problems' 4='(4) Respiratory/cardiac distress'
                  5='(5) Atopic pregnancy' 6='(6) Miscarriage (or threat of)'
                  7='(7) Difficult presentation' 8='(8) Drug addiction'
                  9='(9) Phlebitis, hemorrhoids'
                  10='(10) Hemorrhaging during delivery' 11='(11) Other' ;
  VALUE y7_1216f  1='(1) Involuntary' 2='(2) Voluntary' ;
  VALUE y7_1217f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1218f  0='(0) No effect' 1='(1) Hemorrhaging/blood disorders'
                  2='(2) Hysterectomy' 3='(3) Infections' 4='(4) Depression' 5='(5) Guilt'
                  6='(6) Fatigue' 7='(7) Fear of pregnancy/intercourse'
                  8='(8) Husband/boyfriend upset' 9='(9) Never get another abortion'
                  10='(10) Relieved' 11='(11) Other problem' 12='(12) Other benefit'
                  13='(13) Anger' ;
  VALUE y7_1219f  0='(0) No effect' 1='(1) Hemorrhaging/blood disorders'
                  2='(2) Hysterectomy' 3='(3) Infections' 4='(4) Depression' 5='(5) Guilt'
                  6='(6) Fatigue' 7='(7) Fear of pregnancy/intercourse'
                  8='(8) Husband/boyfriend upset' 9='(9) Never get another abortion'
                  10='(10) Relieved' 11='(11) Other problem' 12='(12) Other benefit'
                  13='(13) Anger' ;
  VALUE y7_1220f  0='(0) No effect' 1='(1) Hemorrhaging/blood disorders'
                  2='(2) Hysterectomy' 3='(3) Infections' 4='(4) Depression' 5='(5) Guilt'
                  6='(6) Fatigue' 7='(7) Fear of pregnancy/intercourse'
                  8='(8) Husband/boyfriend upset' 9='(9) Never get another abortion'
                  10='(10) Relieved' 11='(11) Other problem' 12='(12) Other benefit'
                  13='(13) Anger' ;
  VALUE y7_1221f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1222f  0='(0) No effect' 1='(1) Hemorrhaging/blood disorders'
                  2='(2) Hysterectomy' 3='(3) Infections' 4='(4) Depression' 5='(5) Guilt'
                  6='(6) Fatigue' 7='(7) Fear of pregnancy/intercourse'
                  8='(8) Husband/boyfriend upset' 9='(9) Never get another abortion'
                  10='(10) Relieved' 11='(11) Other problem' 12='(12) Other benefit'
                  13='(13) Anger' ;
  VALUE y7_1223f  0='(0) No effect' 1='(1) Hemorrhaging/blood disorders'
                  2='(2) Hysterectomy' 3='(3) Infections' 4='(4) Depression' 5='(5) Guilt'
                  6='(6) Fatigue' 7='(7) Fear of pregnancy/intercourse'
                  8='(8) Husband/boyfriend upset' 9='(9) Never get another abortion'
                  10='(10) Relieved' 11='(11) Other problem' 12='(12) Other benefit'
                  13='(13) Anger' ;
  VALUE y7_1224f  0='(0) No effect' 1='(1) Hemorrhaging/blood disorders'
                  2='(2) Hysterectomy' 3='(3) Infections' 4='(4) Depression' 5='(5) Guilt'
                  6='(6) Fatigue' 7='(7) Fear of pregnancy/intercourse'
                  8='(8) Husband/boyfriend upset' 9='(9) Never get another abortion'
                  10='(10) Relieved' 11='(11) Other problem' 12='(12) Other benefit'
                  13='(13) Anger' ;
  VALUE y7_1225f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1226f  0='(0) No effect' 1='(1) Hemorrhaging/blood disorders'
                  2='(2) Hysterectomy' 3='(3) Infections' 4='(4) Depression' 5='(5) Guilt'
                  6='(6) Fatigue' 7='(7) Fear of pregnancy/intercourse'
                  8='(8) Husband/boyfriend upset' 9='(9) Never get another abortion'
                  10='(10) Relieved' 11='(11) Other problem' 12='(12) Other benefit'
                  13='(13) Anger' ;
  VALUE y7_1227f  0='(0) No effect' 1='(1) Hemorrhaging/blood disorders'
                  2='(2) Hysterectomy' 3='(3) Infections' 4='(4) Depression' 5='(5) Guilt'
                  6='(6) Fatigue' 7='(7) Fear of pregnancy/intercourse'
                  8='(8) Husband/boyfriend upset' 9='(9) Never get another abortion'
                  10='(10) Relieved' 11='(11) Other problem' 12='(12) Other benefit'
                  13='(13) Anger' ;
  VALUE y7_1228f  0='(0) No effect' 1='(1) Hemorrhaging/blood disorders'
                  2='(2) Hysterectomy' 3='(3) Infections' 4='(4) Depression' 5='(5) Guilt'
                  6='(6) Fatigue' 7='(7) Fear of pregnancy/intercourse'
                  8='(8) Husband/boyfriend upset' 9='(9) Never get another abortion'
                  10='(10) Relieved' 11='(11) Other problem' 12='(12) Other benefit'
                  13='(13) Anger' ;
  VALUE y7_1229f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1230f  1='(1) Symptom not present' 5='(5) Symptom present' ;
  VALUE y7_1231f  1='(1) Symptom not present' 5='(5) Symptom present' ;
  VALUE y7_1232f  1='(1) Symptom not present' 5='(5) Symptom present' ;
  VALUE y7_1233f  1='(1) No symptom(s)' 5='(5) Symptom in at least one category' ;
  VALUE y7_1234f  1='(1) Symptom not present' 5='(5) Symptom present' ;
  VALUE y7_1235f  1='(1) Symptom not present' 5='(5) Symptom present' ;
  VALUE y7_1236f  1='(1) No symptom(s)' 5='(5) Symptom in at least one category' ;
  VALUE y7_1237f  1='(1) Symptom not present' 5='(5) Symptom present' ;
  VALUE y7_1238f  1='(1) No symptom(s)' 5='(5) Symptom in at least one category' ;
  VALUE y7_1239f  1='(1) Symptom not present' 5='(5) Symptom present' ;
  VALUE y7_1240f  1='(1) Symptom not present' 5='(5) Symptom present' ;
  VALUE y7_1241f  1='(1) No symptom(s)' 5='(5) Symptom in at least one category' ;
  VALUE y7_1242f  1='(1) Symptom not present' 5='(5) Symptom present' ;
  VALUE y7_1243f  1='(1) No symptom(s)' 5='(5) Symptom in at least one category' ;
  VALUE y7_1244f  1='(1) Symptom not present' 5='(5) Symptom present' ;
  VALUE y7_1245f  1='(1) Symptom not present' 5='(5) Symptom present' ;
  VALUE y7_1246f  1='(1) No symptom(s)' 5='(5) Symptom in at least one category' ;
  VALUE y7_1247f  1='(1) Symptom not present' 5='(5) Symptom present' ;
  VALUE y7_1248f  1='(1) No symptom(s)' 5='(5) Symptom in at least one category' ;
  VALUE y7_1249f  1='(1) Symptom not present' 5='(5) Symptom present' ;
  VALUE y7_1250f  1='(1) Symptom not present' 5='(5) Symptom present' ;
  VALUE y7_1251f  1='(1) Symptom not present' 5='(5) Symptom present' ;
  VALUE y7_1252f  1='(1) Symptom not present' 5='(5) Symptom present' ;
  VALUE y7_1253f  1='(1) No symptom(s)' 5='(5) Symptom in at least one category' ;
  VALUE y7_1254f  1='(1) No: less than 3 summaries' 2='(2) Yes: 3 or more summaries' ;
  VALUE y7_1255f  1='(1) Yes' 2='(2) No' ;
  VALUE y7_1256f  1='(1) Yes (No correction)' 2='(2) No (Depression with symptoms)' ;
  VALUE y7_1262f  1='(1) No' 5='(5) Yes' ;
  VALUE y7_1263f  1='(1) No' 5='(5) Yes' ;
  VALUE y7_1264f  1='(1) No' 5='(5) Yes' ;
  VALUE y7_1265f  1='(1) No' 5='(5) Yes' ;
  VALUE y7_1266f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1267f  2='(2) Only due to a death' 5='(5) Not due to a death' ;
  VALUE y7_1268f  1='(1) Yes' 2='(2) No' ;
  VALUE y7_1269f  1='(1) Within last 2 weeks' 2='(2) Within last month'
                  3='(3) Within last 6 months' 4='(4) Within last year'
                  5='(5) More than 1 year ago' ;
  VALUE y7_1271f  1='(1) Yes' 2='(2) No' ;
  VALUE y7_1274f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1275f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1276f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1277f  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE y7_1279f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1280f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1281f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1282f  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE y7_1284f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1285f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1286f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1287f  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE y7_1289f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1290f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1291f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1292f  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE y7_1294f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1295f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1296f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1297f  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE y7_1299f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1300f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1301f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1302f  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE y7_1304f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1305f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1306f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1307f  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE y7_1309f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1310f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1311f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1312f  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE y7_1314f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1315f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1316f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1317f  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE y7_1319f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1320f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1321f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1322f  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE y7_1324f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1325f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1326f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1327f  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE y7_1329f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1330f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1331f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1332f  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE y7_1334f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1335f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1336f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1337f  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE y7_1339f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1340f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1341f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1342f  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE y7_1344f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1345f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1346f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1347f  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE y7_1349f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1350f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1351f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1352f  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE y7_1354f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1355f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1356f  0='(0) No problem' 1='(1) Drugs' 2='(2) Alcohol'
                  3='(3) Family relationships' 4='(4) Depression'
                  5='(5) Sexual relationships' 6='(6) Trouble with the law'
                  7='(7) Emotional stress/nerves' 8='(8) Problem with boy/girlfriend'
                  9='(9) Work/school problems' 10='(10) Problems with friends'
                  11='(11) Physical health/illness' 12='(12) Financial problems'
                  13='(13) Death of friend/relative' 99='(99) Other' ;
  VALUE y7_1357f  1='(1) None at all' 2='(2) Only a little' 3='(3) Some'
                  4='(4) A fair amount' 5='(5) A great deal' ;
  VALUE y7_1358f  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE y7_1359f  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE y7_1360f  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE y7_1361f  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE y7_1362f  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE y7_1363f  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE y7_1364f  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE y7_1365f  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE y7_1366f  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE y7_1367f  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE y7_1368f  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE y7_1369f  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE y7_1370f  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE y7_1371f  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE y7_1372f  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE y7_1373f  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE y7_1374f  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE y7_1375f  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE y7_1376f  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE y7_1377f  0='(0) Never' 1='(1) Once' 2='(2) Twice' 3='(3) 3-5 Times' 4='(4) 6-10 Times'
                  5='(5) 11-20 Times' 6='(6) More Than 20 Times' ;
  VALUE y7_1383f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1385f  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_1387f  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_1390f  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_1391f  1='(1) Boy/girlfriend' 2='(2) Date' 3='(3) Friend' 4='(4) Acquaintance'
                  5='(5) Stranger' 6='(6) Spouse' 7='(7) Relative' 8='(8) Other' ;
  VALUE y7_1392f  1='(1) Male' 2='(2) Female' 3='(3) Both' ;
  VALUE y7_1393f  1='(1) Verbal persuasion' 2='(2) Verbal threats of injury'
                  3='(3) Hit, slap, mild roughness' 4='(4) Physical beating/choking'
                  5='(5) Threat to use weapon' 6='(6) Used a weapon' ;
  VALUE y7_1394f  0='(0) No' ;
  VALUE y7_1395f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1396f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1397f  0='(0) No' ;
  VALUE y7_1399f  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_1400f  1='(1) Boy/girlfriend' 2='(2) Date' 3='(3) Friend' 4='(4) Acquaintance'
                  5='(5) Stranger' 6='(6) Spouse' 7='(7) Relative' 8='(8) Other' ;
  VALUE y7_1401f  1='(1) Male' 2='(2) Female' 3='(3) Both' ;
  VALUE y7_1402f  1='(1) Verbal persuasion' 2='(2) Verbal threats of injury'
                  3='(3) Hit, slap, mild roughness' 4='(4) Physical beating/choking'
                  5='(5) Threat to use weapon' 6='(6) Used a weapon' ;
  VALUE y7_1403f  0='(0) No' ;
  VALUE y7_1404f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1405f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1406f  0='(0) No' ;
  VALUE y7_1408f  1='(1) Husband/wife' 2='(2) Fiance/fiancee'
                  3='(3) Steady dating partner' 4='(4) Friend' 5='(5) Teacher'
                  6='(6) Casual acquaintance' 7='(7) Relative' 8='(8) Complete stranger'
                  9='(9) Prostitute' ;
  VALUE y7_1409f  1='(1) Forced' 2='(2) Voluntary' ;
  VALUE y7_1410f  1='(1) Very positive' 2='(2) Positive'
                  3='(3) Both positive and negative'
                  4='(4) Neither positive or negative' 5='(5) Negative'
                  6='(6) Very negative' ;
  VALUE y7_1411f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1413f  1='(1) Forced' 2='(2) Voluntary' ;
  VALUE y7_1414f  1='(1) Very positive' 2='(2) Positive'
                  3='(3) Both positive and negative'
                  4='(4) Neither positive or negative' 5='(5) Negative'
                  6='(6) Very negative' ;
  VALUE y7_1416f  4='(4) Once a month' 5='(5) Once every 2-3 weeks' 6='(6) Once a week'
                  7='(7) 2-3 times a week' 8='(8) Once a day' 9='(9) 2-3 times a day' ;
  VALUE y7_1418f  1='(1) Heterosexual' 2='(2) Bisexual' 3='(3) Gay' 4='(4) Uncertain'
                  9='(9) Dont know (Respondent did not' ;
  VALUE y7_1419f  1='(1) Very dissatisfied' 2='(2) Somewhat dissatisfied'
                  3='(3) Neither satisfied nor dissatisfied'
                  4='(4) Somewhat satisfied' 5='(5) Very satisfied' ;
  VALUE y7_1420f  1='(1) Very little' 2='(2) Not too much' 3='(3) Some' 4='(4) Quite a bit'
                  5='(5) A great deal' ;
  VALUE y7_1421f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1423f  0='(0) Not in past yr' 999='(999) Some time/not past yr' ;
  VALUE y7_1424f  0='(0) Not in past yr' 999='(999) Some time/not past yr' ;
  VALUE y7_1425f  0='(0) Not in past yr' 999='(999) Some time/not past yr' ;
  VALUE y7_1426f  0='(0) Not in past yr' 999='(999) Some time/not past yr' ;
  VALUE y7_1427f  0='(0) Not in past yr' 999='(999) Some time/not past yr' ;
  VALUE y7_1428f  0='(0) Not in past yr' 999='(999) Some time/not past yr' ;
  VALUE y7_1429f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1430f  1='(1) Drugs' ;
  VALUE y7_1431f  1='(1) Sex' ;
  VALUE y7_1432f  1='(1) Mental health' ;
  VALUE y7_1433f  1='(1) Criminal behavior' ;
  VALUE y7_1434f  1='(1) Spouse violence' ;
  VALUE y7_1437f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1451f  1='(1) Not at all anxious' 2='(2) Somewhat anxious'
                  3='(3) Very anxious' ;
  VALUE y7_1452f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1453f  1='(1) Very low' 2='(2) Below average' 3='(3) Average'
                  4='(4) Above average' 5='(5) Very high' ;
  VALUE y7_1454f  1='(1) Difficulty with language' ;
  VALUE y7_1455f  1='(1) Difficulty with questions' ;
  VALUE y7_1456f  1='(1) Interruptions' ;
  VALUE y7_1457f  1='(1) Temporary breakoff' ;
  VALUE y7_1458f  1='(1) Breakoff' ;
  VALUE y7_1459f  1='(1) Other (all other unclassifiable)' ;
  VALUE y7_1460f  1='(1) Relaxed' 2='(2) Tense' 3='(3) Other' ;
  VALUE y7_1461f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1466f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1467f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1468f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1469f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1470f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1471f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1472f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1473f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1474f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1475f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1476f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1477f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1478f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1479f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1480f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1481f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1482f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1483f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1484f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1485f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1486f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1487f  1='(1) No' 2='(2) Yes' ;
  VALUE y7_1730f  1='(1) Urban' 2='(2) Suburban' 3='(3) Rural' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=3187;
INPUT
        CASEID 1-8              DTSET1 9-12             SSMPL1 13-14
        HHLD1 15-18             RESP1 19-20             Y7_1 21-22
        Y7_2 23-24              Y7_3 25-26              Y7_7 27-28
        Y7_8 29-30              Y7_9 31-32              Y7_10 33-34
        Y7_11 35-36             Y7_12 37-38             Y7_13 39-40
        Y7_14 41-42             Y7_15 43-44             Y7_16 45-46
        Y7_17 47-48             Y7_18 49-50             Y7_19 51-52
        Y7_20 53-54             Y7_21 55-56             Y7_22 57-58
        Y7_23 59-60             Y7_24 61-62             Y7_25 63-64
        Y7_26 65-66             Y7_27 67-68             Y7_28 69-70
        Y7_29 71-72             Y7_30 73-74             Y7_31 75-76
        Y7_32 77-78             Y7_33 79-80             Y7_34 81-82
        Y7_35 83-84             Y7_36 85-86             Y7_37 87-88
        Y7_38 89-90             Y7_39 91-92             Y7_40 93-94
        Y7_41 95-96             Y7_42 97-98             Y7_43 99-100
        Y7_44 101-102           Y7_45 103-104           Y7_46 105-106
        Y7_47 107-108           Y7_48 109-110           Y7_49 111-112
        Y7_50 113-114           Y7_51 115-116           Y7_52 117-118
        Y7_53 119-120           Y7_54 121-122           Y7_55 123-124
        Y7_56 125-126           Y7_57 127-128           Y7_58 129-130
        Y7_59 131-132           Y7_60 133-134           Y7_61 135-136
        Y7_62 137-138           Y7_63 139-140           Y7_64 141-142
        Y7_65 143-144           Y7_66 145-146           Y7_67 147-148
        Y7_68 149-150           Y7_69 151-152           Y7_70 153-154
        Y7_71 155-156           Y7_72 157-158           Y7_73 159-160
        Y7_74 161-162           Y7_75 163-164           Y7_76 165-166
        Y7_77 167-168           Y7_78 169-170           Y7_79 171-172
        Y7_80 173-174           Y7_81 175-176           Y7_82 177-178
        Y7_83 179-180           Y7_84 181-182           Y7_85 183-184
        Y7_86 185-186           Y7_87 187-188           Y7_88 189-190
        Y7_89 191-192           Y7_90 193-194           Y7_91 195-196
        Y7_92 197-198           Y7_93 199-200           Y7_94 201-202
        Y7_95 203-204           Y7_96 205-206           Y7_97 207-208
        Y7_98 209-210           Y7_99 211-212           Y7_100 213-214
        Y7_101 215-216          Y7_102 217-218          Y7_103 219-220
        Y7_104 221-222          Y7_105 223-224          Y7_106 225-226
        Y7_107 227-228          Y7_108 229-230          Y7_109 231-232
        Y7_110 233-234          Y7_111 235-236          Y7_112 237-238
        Y7_113 239-240          Y7_114 241-242          Y7_115 243-244
        Y7_116 245-246          Y7_117 247-248          Y7_118 249-250
        Y7_119 251-252          Y7_120 253-254          Y7_121 255-256
        Y7_122 257-258          Y7_123 259-260          Y7_124 261-262
        Y7_125 263-264          Y7_126 265-266          Y7_127 267-268
        Y7_128 269-270          Y7_129 271-272          Y7_130 273-274
        Y7_131 275-276          Y7_132 277-278          Y7_133 279-280
        Y7_134 281-282          Y7_135 283-284          Y7_136 285-286
        Y7_137 287-288          Y7_138 289-290          Y7_139 291-292
        Y7_140 293-294          Y7_141 295-296          Y7_142 297-298
        Y7_143 299-300          Y7_144 301-302          Y7_145 303-304
        Y7_146 305-306          Y7_147 307-308          Y7_148 309-310
        Y7_149 311-312          Y7_150 313-314          Y7_151 315-316
        Y7_152 317-318          Y7_153 319-320          Y7_154 321-322
        Y7_155 323-324          Y7_156 325-326          Y7_157 327-328
        Y7_158 329-330          Y7_159 331-332          Y7_160 333-334
        Y7_161 335-336          Y7_162 337-338          Y7_163 339-340
        Y7_164 341-342          Y7_165 343-344          Y7_166 345-346
        Y7_167 347-348          Y7_168 349-350          Y7_169 351-352
        Y7_170 353-354          Y7_171 355-356          Y7_172 357-358
        Y7_173 359-360          Y7_174 361-362          Y7_175 363-364
        Y7_176 365-366          Y7_177 367-368          Y7_178 369-370
        Y7_179 371-372          Y7_180 373-374          Y7_181 375-376
        Y7_182 377-378          Y7_183 379-380          Y7_184 381-382
        Y7_185 383-384          Y7_186 385-389          Y7_187 390-391
        Y7_188 392-393          Y7_189 394-395          Y7_190 396-397
        Y7_191 398-399          Y7_192 400-401          Y7_193 402-403
        Y7_194 404-405          Y7_195 406-407          Y7_196 408-409
        Y7_197 410-411          Y7_198 412-413          Y7_199 414-415
        Y7_200 416-417          Y7_201 418-419          Y7_202 420-421
        Y7_203 422-423          Y7_204 424-425          Y7_205 426-427
        Y7_206 428-429          Y7_207 430-431          Y7_208 432-433
        Y7_209 434-435          Y7_210 436-437          Y7_211 438-439
        Y7_212 440-441          Y7_213 442-443          Y7_214 444-445
        Y7_215 446-447          Y7_216 448-449          Y7_217 450-451
        Y7_218 452-453          Y7_219 454-455          Y7_220 456-457
        Y7_221 458-459          Y7_222 460-461          Y7_223 462-463
        Y7_224 464-465          Y7_225 466-467          Y7_226 468-469
        Y7_227 470-471          Y7_228 472-473          Y7_229 474-475
        Y7_230 476-477          Y7_231 478-479          Y7_232 480-481
        Y7_233 482-483          Y7_234 484-485          Y7_235 486-487
        Y7_236 488-489          Y7_237 490-491          Y7_238 492-493
        Y7_239 494-495          Y7_240 496-497          Y7_241 498-499
        Y7_242 500-501          Y7_243 502-503          Y7_244 504-505
        Y7_245 506-507          Y7_246 508-509          Y7_247 510-511
        Y7_248 512-513          Y7_249 514-515          Y7_250 516-517
        Y7_251 518-519          Y7_252 520-521          Y7_253 522-523
        Y7_254 524-525          Y7_255 526-527          Y7_256 528-529
        Y7_257 530-531          Y7_258 532-533          Y7_259 534-535
        Y7_260 536-537          Y7_261 538-539          Y7_262 540-544
        Y7_263 545-546          Y7_264 547-548          Y7_265 549-550
        Y7_266 551-552          Y7_267 553-554          Y7_268 555-556
        Y7_269 557-558          Y7_270 559-560          Y7_271 561-562
        Y7_272 563-564          Y7_273 565-566          Y7_274 567-568
        Y7_275 569-570          Y7_276 571-572          Y7_277 573-574
        Y7_278 575-576          Y7_279 577-578          Y7_280 579-580
        Y7_281 581-582          Y7_282 583-584          Y7_283 585-586
        Y7_284 587-588          Y7_285 589-590          Y7_286 591-592
        Y7_287 593-594          Y7_288 595-596          Y7_289 597-598
        Y7_290 599-600          Y7_291 601-602          Y7_292 603-604
        Y7_293 605-606          Y7_294 607-608          Y7_295 609-610
        Y7_296 611-612          Y7_297 613-614          Y7_298 615-616
        Y7_299 617-618          Y7_300 619-620          Y7_301 621-622
        Y7_302 623-624          Y7_303 625-626          Y7_304 627-628
        Y7_305 629-630          Y7_306 631-632          Y7_307 633-634
        Y7_308 635-636          Y7_309 637-638          Y7_310 639-640
        Y7_311 641-642          Y7_312 643-644          Y7_313 645-646
        Y7_314 647-648          Y7_315 649-650          Y7_316 651-652
        Y7_317 653-654          Y7_318 655-656          Y7_319 657-658
        Y7_320 659-660          Y7_321 661-663          Y7_322 664-665
        Y7_323 666-667          Y7_324 668-669          Y7_325 670-671
        Y7_326 672-673          Y7_327 674-675          Y7_328 676-677
        Y7_329 678-679          Y7_330 680-681          Y7_331 682-683
        Y7_332 684-685          Y7_333 686-687          Y7_334 688-689
        Y7_335 690-691          Y7_336 692-693          Y7_337 694-695
        Y7_338 696-697          Y7_339 698-699          Y7_340 700-701
        Y7_341 702-703          Y7_342 704-705          Y7_343 706-707
        Y7_344 708-709          Y7_345 710-711          Y7_346 712-713
        Y7_347 714-715          Y7_348 716-717          Y7_349 718-719
        Y7_350 720-721          Y7_351 722-723          Y7_352 724-725
        Y7_353 726-727          Y7_354 728-729          Y7_355 730-731
        Y7_356 732-733          Y7_357 734-735          Y7_358 736-737
        Y7_359 738-739          Y7_360 740-741          Y7_361 742-743
        Y7_362 744-745          Y7_363 746-747          Y7_364 748-749
        Y7_365 750-751          Y7_366 752-753          Y7_367 754-755
        Y7_368 756-757          Y7_369 758-759          Y7_370 760-761
        Y7_371 762-763          Y7_372 764-765          Y7_373 766-767
        Y7_374 768-769          Y7_375 770-771          Y7_376 772-773
        Y7_377 774-775          Y7_378 776-777          Y7_379 778-779
        Y7_380 780-781          Y7_381 782-783          Y7_382 784-785
        Y7_383 786-787          Y7_384 788-789          Y7_385 790-791
        Y7_386 792-793          Y7_387 794-795          Y7_388 796-797
        Y7_389 798-799          Y7_390 800-801          Y7_391 802-803
        Y7_392 804-805          Y7_393 806-807          Y7_394 808-809
        Y7_395 810-811          Y7_396 812-813          Y7_397 814-815
        Y7_398 816-817          Y7_399 818-819          Y7_400 820-821
        Y7_401 822-823          Y7_402 824-825          Y7_403 826-827
        Y7_404 828-829          Y7_405 830-831          Y7_406 832-833
        Y7_407 834-835          Y7_408 836-837          Y7_409 838-839
        Y7_410 840-841          Y7_411 842-843          Y7_412 844-845
        Y7_413 846-847          Y7_414 848-849          Y7_415 850-851
        Y7_416 852-853          Y7_417 854-855          Y7_418 856-857
        Y7_419 858-859          Y7_420 860-861          Y7_421 862-863
        Y7_422 864-865          Y7_423 866-867          Y7_424 868-869
        Y7_425 870-871          Y7_426 872-873          Y7_427 874-875
        Y7_428 876-877          Y7_429 878-879          Y7_430 880-881
        Y7_431 882-883          Y7_432 884-885          Y7_433 886-887
        Y7_434 888-889          Y7_435 890-891          Y7_436 892-893
        Y7_437 894-895          Y7_438 896-897          Y7_439 898-899
        Y7_440 900-901          Y7_441 902-903          Y7_442 904-905
        Y7_443 906-907          Y7_444 908-909          Y7_445 910-911
        Y7_446 912-913          Y7_447 914-915          Y7_448 916-917
        Y7_449 918-919          Y7_450 920-922          Y7_451 923-924
        Y7_452 925-927          Y7_453 928-929          Y7_454 930-932
        Y7_455 933-934          Y7_456 935-937          Y7_457 938-939
        Y7_458 940-942          Y7_459 943-944          Y7_460 945-947
        Y7_461 948-949          Y7_462 950-952          Y7_463 953-954
        Y7_464 955-957          Y7_465 958-959          Y7_466 960-962
        Y7_467 963-964          Y7_468 965-967          Y7_469 968-969
        Y7_470 970-972          Y7_471 973-974          Y7_472 975-977
        Y7_473 978-979          Y7_474 980-982          Y7_475 983-984
        Y7_476 985-987          Y7_477 988-989          Y7_478 990-992
        Y7_479 993-994          Y7_480 995-997          Y7_481 998-999
        Y7_482 1000-1002        Y7_483 1003-1004        Y7_484 1005-1007
        Y7_485 1008-1009        Y7_486 1010-1012        Y7_487 1013-1014
        Y7_488 1015-1017        Y7_489 1018-1019        Y7_490 1020-1022
        Y7_491 1023-1024        Y7_492 1025-1027        Y7_493 1028-1029
        Y7_494 1030-1032        Y7_495 1033-1034        Y7_496 1035-1037
        Y7_497 1038-1039        Y7_498 1040-1042        Y7_499 1043-1044
        Y7_500 1045-1047        Y7_501 1048-1049        Y7_502 1050-1052
        Y7_503 1053-1054        Y7_504 1055-1057        Y7_505 1058-1059
        Y7_506 1060-1062        Y7_507 1063-1064        Y7_508 1065-1067
        Y7_509 1068-1069        Y7_510 1070-1072        Y7_511 1073-1074
        Y7_512 1075-1077        Y7_513 1078-1079        Y7_514 1080-1082
        Y7_515 1083-1084        Y7_516 1085-1087        Y7_517 1088-1089
        Y7_518 1090-1092        Y7_519 1093-1094        Y7_520 1095-1097
        Y7_521 1098-1099        Y7_522 1100-1102        Y7_523 1103-1104
        Y7_524 1105-1107        Y7_525 1108-1109        Y7_526 1110-1111
        Y7_527 1112-1113        Y7_528 1114-1115        Y7_529 1116-1117
        Y7_530 1118-1119        Y7_531 1120-1121        Y7_532 1122-1123
        Y7_533 1124-1125        Y7_534 1126-1127        Y7_535 1128-1129
        Y7_536 1130-1131        Y7_537 1132-1133        Y7_538 1134-1135
        Y7_539 1136-1137        Y7_540 1138-1139        Y7_541 1140-1141
        Y7_542 1142-1143        Y7_543 1144-1145        Y7_544 1146-1147
        Y7_545 1148-1149        Y7_546 1150-1151        Y7_547 1152-1153
        Y7_548 1154-1155        Y7_549 1156-1157        Y7_550 1158-1159
        Y7_551 1160-1161        Y7_552 1162-1163        Y7_553 1164-1165
        Y7_554 1166-1167        Y7_555 1168-1169        Y7_556 1170-1171
        Y7_557 1172-1173        Y7_558 1174-1175        Y7_559 1176-1177
        Y7_560 1178-1179        Y7_561 1180-1181        Y7_562 1182-1183
        Y7_563 1184-1185        Y7_564 1186-1187        Y7_565 1188-1189
        Y7_566 1190-1191        Y7_567 1192-1193        Y7_568 1194-1196
        Y7_569 1197-1198        Y7_570 1199-1201        Y7_571 1202-1204
        Y7_572 1205-1208        Y7_573 1209-1210        Y7_574 1211-1213
        Y7_575 1214-1216        Y7_576 1217-1219        Y7_577 1220-1221
        Y7_578 1222-1224        Y7_579 1225-1227        Y7_580 1228-1229
        Y7_581 1230-1231        Y7_582 1232-1233        Y7_583 1234-1235
        Y7_584 1236-1237        Y7_585 1238-1239        Y7_586 1240-1241
        Y7_587 1242-1244        Y7_588 1245-1247        Y7_589 1248-1249
        Y7_590 1250-1251        Y7_591 1252-1253        Y7_592 1254-1255
        Y7_593 1256-1257        Y7_594 1258-1259        Y7_595 1260-1261
        Y7_596 1262-1264        Y7_597 1265-1267        Y7_598 1268-1269
        Y7_599 1270-1271        Y7_600 1272-1273        Y7_601 1274-1275
        Y7_602 1276-1277        Y7_603 1278-1279        Y7_604 1280-1281
        Y7_605 1282-1284        Y7_606 1285-1287        Y7_607 1288-1290
        Y7_608 1291-1292        Y7_609 1293-1294        Y7_610 1295-1296
        Y7_611 1297-1298        Y7_612 1299-1301        Y7_613 1302-1304
        Y7_614 1305-1307        Y7_615 1308-1309        Y7_616 1310-1311
        Y7_617 1312-1313        Y7_618 1314-1315        Y7_619 1316-1318
        Y7_620 1319-1321        Y7_621 1322-1324        Y7_622 1325-1326
        Y7_623 1327-1328        Y7_624 1329-1330        Y7_625 1331-1332
        Y7_626 1333-1335        Y7_627 1336-1338        Y7_628 1339-1340
        Y7_629 1341-1344        Y7_630 1345-1346        Y7_631 1347-1349
        Y7_632 1350-1352        Y7_633 1353-1354        Y7_634 1355-1356
        Y7_635 1357-1358        Y7_636 1359-1361        Y7_637 1362-1364
        Y7_638 1365-1366        Y7_639 1367-1368        Y7_640 1369-1370
        Y7_641 1371-1372        Y7_642 1373-1374        Y7_643 1375-1377
        Y7_644 1378-1380        Y7_645 1381-1382        Y7_646 1383-1384
        Y7_647 1385-1386        Y7_648 1387-1388        Y7_649 1389-1390
        Y7_650 1391-1393        Y7_651 1394-1396        Y7_652 1397-1398
        Y7_653 1399-1400        Y7_654 1401-1402        Y7_655 1403-1404
        Y7_656 1405-1406        Y7_657 1407-1409        Y7_658 1410-1412
        Y7_659 1413-1414        Y7_660 1415-1416        Y7_661 1417-1418
        Y7_662 1419-1420        Y7_663 1421-1422        Y7_664 1423-1425
        Y7_665 1426-1428        Y7_666 1429-1430        Y7_667 1431-1432
        Y7_668 1433-1434        Y7_669 1435-1436        Y7_670 1437-1438
        Y7_671 1439-1441        Y7_672 1442-1444        Y7_673 1445-1446
        Y7_674 1447-1448        Y7_675 1449-1450        Y7_676 1451-1452
        Y7_677 1453-1454        Y7_678 1455-1457        Y7_679 1458-1460
        Y7_680 1461-1462        Y7_681 1463-1464        Y7_682 1465-1466
        Y7_683 1467-1468        Y7_684 1469-1470        Y7_685 1471-1473
        Y7_686 1474-1476        Y7_687 1477-1478        Y7_688 1479-1481
        Y7_689 1482-1483        Y7_690 1484-1486        Y7_691 1487-1489
        Y7_692 1490-1494        Y7_693 1495-1499        Y7_694 1500-1501
        Y7_695 1502-1504        Y7_696 1505-1507        Y7_697 1508-1509
        Y7_698 1510-1512        Y7_699 1513-1515        Y7_700 1516-1517
        Y7_701 1518-1519        Y7_702 1520-1521        Y7_703 1522-1524
        Y7_704 1525-1527        Y7_705 1528-1529        Y7_706 1530-1532
        Y7_707 1533-1535        Y7_708 1536-1537        Y7_709 1538-1539
        Y7_710 1540-1542        Y7_711 1543-1545        Y7_712 1546-1547
        Y7_713 1548-1549        Y7_714 1550-1551        Y7_715 1552-1553
        Y7_716 1554-1555        Y7_717 1556-1557        Y7_718 1558-1560
        Y7_719 1561-1563        Y7_720 1564-1565        Y7_721 1566-1567
        Y7_722 1568-1569        Y7_723 1570-1571        Y7_724 1572-1573
        Y7_725 1574-1575        Y7_726 1576-1578        Y7_727 1579-1581
        Y7_728 1582-1583        Y7_729 1584-1585        Y7_730 1586-1587
        Y7_731 1588-1589        Y7_732 1590-1591        Y7_733 1592-1593
        Y7_734 1594-1596        Y7_735 1597-1599        Y7_736 1600-1601
        Y7_737 1602-1603        Y7_738 1604-1605        Y7_739 1606-1607
        Y7_740 1608-1610        Y7_741 1611-1613        Y7_742 1614-1615
        Y7_743 1616-1617        Y7_744 1618-1619        Y7_745 1620-1621
        Y7_746 1622-1624        Y7_747 1625-1627        Y7_748 1628-1629
        Y7_749 1630-1631        Y7_750 1632-1633        Y7_751 1634-1635
        Y7_752 1636-1638        Y7_753 1639-1641        Y7_754 1642-1643
        Y7_755 1644-1648        Y7_756 1649-1650        Y7_757 1651-1653
        Y7_758 1654-1656        Y7_759 1657-1658        Y7_760 1659-1662
        Y7_761 1663-1666        Y7_762 1667-1668        Y7_763 1669-1670
        Y7_764 1671-1673        Y7_765 1674-1676        Y7_766 1677-1678
        Y7_767 1679-1680        Y7_768 1681-1682        Y7_769 1683-1684
        Y7_770 1685-1686        Y7_771 1687-1689        Y7_772 1690-1692
        Y7_773 1693-1694        Y7_774 1695-1696        Y7_775 1697-1698
        Y7_776 1699-1700        Y7_777 1701-1702        Y7_778 1703-1704
        Y7_779 1705-1707        Y7_780 1708-1710        Y7_781 1711-1712
        Y7_782 1713-1714        Y7_783 1715-1716        Y7_784 1717-1718
        Y7_785 1719-1720        Y7_786 1721-1722        Y7_787 1723-1725
        Y7_788 1726-1728        Y7_789 1729-1730        Y7_790 1731-1732
        Y7_791 1733-1734        Y7_792 1735-1736        Y7_793 1737-1738
        Y7_794 1739-1740        Y7_795 1741-1743        Y7_796 1744-1746
        Y7_797 1747-1748        Y7_798 1749-1750        Y7_799 1751-1752
        Y7_800 1753-1754        Y7_801 1755-1756        Y7_802 1757-1759
        Y7_803 1760-1762        Y7_804 1763-1764        Y7_805 1765-1766
        Y7_806 1767-1768        Y7_807 1769-1770        Y7_808 1771-1772
        Y7_809 1773-1775        Y7_810 1776-1778        Y7_811 1779-1780
        Y7_812 1781-1782        Y7_813 1783-1784        Y7_814 1785-1786
        Y7_815 1787-1788        Y7_816 1789-1791        Y7_817 1792-1794
        Y7_818 1795-1796        Y7_819 1797-1798        Y7_820 1799-1800
        Y7_821 1801-1802        Y7_822 1803-1804        Y7_823 1805-1807
        Y7_824 1808-1810        Y7_825 1811-1812        Y7_826 1813-1815
        Y7_827 1816-1817        Y7_828 1818-1820        Y7_829 1821-1823
        Y7_830 1824-1825        Y7_831 1826-1827        Y7_832 1828-1829
        Y7_833 1830-1831        Y7_834 1832-1833        Y7_835 1834-1835
        Y7_836 1836-1837        Y7_837 1838-1840        Y7_838 1841-1843
        Y7_839 1844-1846        Y7_840 1847-1849        Y7_841 1850-1852
        Y7_842 1853-1855        Y7_843 1856-1857        Y7_844 1858-1859
        Y7_845 1860-1861        Y7_846 1862-1863        Y7_847 1864-1865
        Y7_848 1866-1867        Y7_849 1868-1869        Y7_850 1870-1872
        Y7_851 1873-1874        Y7_852 1875-1876        Y7_853 1877-1879
        Y7_854 1880-1881        Y7_855 1882-1883        Y7_856 1884-1886
        Y7_857 1887-1888        Y7_858 1889-1890        Y7_859 1891-1893
        Y7_860 1894-1896        Y7_861 1897-1898        Y7_862 1899-1900
        Y7_863 1901-1903        Y7_864 1904-1906        Y7_865 1907-1908
        Y7_866 1909-1910        Y7_867 1911-1913        Y7_868 1914-1916
        Y7_869 1917-1918        Y7_870 1919-1920        Y7_871 1921-1923
        Y7_872 1924-1926        Y7_873 1927-1928        Y7_874 1929-1930
        Y7_875 1931-1933        Y7_876 1934-1935        Y7_877 1936-1937
        Y7_878 1938-1940        Y7_879 1941-1942        Y7_880 1943-1944
        Y7_881 1945-1947        Y7_882 1948-1949        Y7_883 1950-1951
        Y7_884 1952-1954        Y7_885 1955-1956        Y7_886 1957-1958
        Y7_887 1959-1960        Y7_888 1961-1963        Y7_889 1964-1965
        Y7_890 1966-1967        Y7_891 1968-1970        Y7_892 1971-1972
        Y7_893 1973-1974        Y7_894 1975-1976        Y7_895 1977-1978
        Y7_896 1979-1980        Y7_897 1981-1982        Y7_898 1983-1984
        Y7_899 1985-1986        Y7_900 1987-1988        Y7_901 1989-1990
        Y7_902 1991-1992        Y7_903 1993-1994        Y7_904 1995-1996
        Y7_905 1997-1998        Y7_906 1999-2000        Y7_907 2001-2002
        Y7_908 2003-2004        Y7_909 2005-2006        Y7_910 2007-2008
        Y7_911 2009-2010        Y7_912 2011-2012        Y7_913 2013-2014
        Y7_914 2015-2016        Y7_915 2017-2018        Y7_916 2019-2020
        Y7_917 2021-2022        Y7_918 2023-2024        Y7_919 2025-2026
        Y7_920 2027-2028        Y7_921 2029-2030        Y7_922 2031-2032
        Y7_923 2033-2034        Y7_924 2035-2036        Y7_925 2037-2038
        Y7_926 2039-2040        Y7_927 2041-2042        Y7_928 2043-2044
        Y7_929 2045-2046        Y7_930 2047-2048        Y7_931 2049-2050
        Y7_932 2051-2052        Y7_933 2053-2054        Y7_934 2055-2056
        Y7_935 2057-2059        Y7_936 2060-2062        Y7_937 2063-2065
        Y7_938 2066-2068        Y7_939 2069-2071        Y7_940 2072-2074
        Y7_941 2075-2077        Y7_942 2078-2080        Y7_943 2081-2083
        Y7_944 2084-2085        Y7_945 2086-2087        Y7_946 2088-2089
        Y7_947 2090-2091        Y7_948 2092-2093        Y7_949 2094-2095
        Y7_950 2096-2097        Y7_951 2098-2099        Y7_952 2100-2101
        Y7_953 2102-2103        Y7_954 2104-2105        Y7_955 2106-2107
        Y7_956 2108-2109        Y7_957 2110-2111        Y7_958 2112-2113
        Y7_959 2114-2115        Y7_960 2116-2117        Y7_961 2118-2119
        Y7_962 2120-2121        Y7_963 2122-2123        Y7_964 2124-2125
        Y7_965 2126-2127        Y7_966 2128-2129        Y7_967 2130-2131
        Y7_968 2132-2133        Y7_969 2134-2135        Y7_970 2136-2137
        Y7_971 2138-2139        Y7_972 2140-2141        Y7_973 2142-2143
        Y7_974 2144-2145        Y7_975 2146-2147        Y7_976 2148-2149
        Y7_977 2150-2151        Y7_978 2152-2153        Y7_979 2154-2155
        Y7_980 2156-2157        Y7_981 2158-2159        Y7_982 2160-2161
        Y7_983 2162-2163        Y7_984 2164-2165        Y7_985 2166-2167
        Y7_986 2168-2169        Y7_987 2170-2171        Y7_988 2172-2173
        Y7_989 2174-2175        Y7_990 2176-2177        Y7_991 2178-2179
        Y7_992 2180-2181        Y7_993 2182-2183        Y7_994 2184-2185
        Y7_995 2186-2187        Y7_996 2188-2189        Y7_997 2190-2191
        Y7_998 2192-2193        Y7_999 2194-2195        Y7_1000 2196-2197
        Y7_1001 2198-2199       Y7_1002 2200-2201       Y7_1003 2202-2203
        Y7_1004 2204-2205       Y7_1005 2206-2207       Y7_1006 2208-2209
        Y7_1007 2210-2211       Y7_1008 2212-2213       Y7_1009 2214-2215
        Y7_1010 2216-2217       Y7_1011 2218-2219       Y7_1012 2220-2221
        Y7_1013 2222-2223       Y7_1014 2224-2225       Y7_1015 2226-2227
        Y7_1016 2228-2229       Y7_1017 2230-2231       Y7_1018 2232-2233
        Y7_1019 2234-2235       Y7_1020 2236-2237       Y7_1021 2238-2239
        Y7_1022 2240-2241       Y7_1023 2242-2243       Y7_1024 2244-2245
        Y7_1025 2246-2247       Y7_1026 2248-2249       Y7_1027 2250-2251
        Y7_1028 2252-2253       Y7_1029 2254-2255       Y7_1030 2256-2257
        Y7_1031 2258-2259       Y7_1032 2260-2261       Y7_1033 2262-2263
        Y7_1034 2264-2265       Y7_1035 2266-2267       Y7_1036 2268-2269
        Y7_1037 2270-2271       Y7_1038 2272-2273       Y7_1039 2274-2275
        Y7_1040 2276-2277       Y7_1041 2278-2279       Y7_1042 2280-2281
        Y7_1043 2282-2283       Y7_1044 2284-2285       Y7_1045 2286-2287
        Y7_1046 2288-2289       Y7_1047 2290-2291       Y7_1048 2292-2293
        Y7_1049 2294-2295       Y7_1050 2296-2297       Y7_1051 2298-2299
        Y7_1052 2300-2301       Y7_1053 2302-2303       Y7_1054 2304-2305
        Y7_1055 2306-2307       Y7_1056 2308-2309       Y7_1057 2310-2311
        Y7_1058 2312-2313       Y7_1059 2314-2315       Y7_1060 2316-2317
        Y7_1061 2318-2319       Y7_1062 2320-2321       Y7_1063 2322-2323
        Y7_1064 2324-2325       Y7_1065 2326-2327       Y7_1066 2328-2329
        Y7_1067 2330-2331       Y7_1068 2332-2333       Y7_1069 2334-2335
        Y7_1070 2336-2337       Y7_1071 2338-2339       Y7_1072 2340-2341
        Y7_1073 2342-2343       Y7_1074 2344-2345       Y7_1075 2346-2347
        Y7_1076 2348-2349       Y7_1077 2350-2351       Y7_1078 2352-2353
        Y7_1079 2354-2355       Y7_1080 2356-2357       Y7_1081 2358-2359
        Y7_1082 2360-2361       Y7_1083 2362-2363       Y7_1084 2364-2365
        Y7_1085 2366-2367       Y7_1086 2368-2369       Y7_1087 2370-2371
        Y7_1088 2372-2374       Y7_1089 2375-2376       Y7_1090 2377-2378
        Y7_1091 2379-2380       Y7_1092 2381-2382       Y7_1093 2383-2384
        Y7_1094 2385-2386       Y7_1095 2387-2388       Y7_1096 2389-2390
        Y7_1097 2391-2392       Y7_1098 2393-2394       Y7_1099 2395-2396
        Y7_1100 2397-2398       Y7_1101 2399-2400       Y7_1102 2401-2402
        Y7_1103 2403-2404       Y7_1104 2405-2406       Y7_1105 2407-2408
        Y7_1106 2409-2410       Y7_1107 2411-2412       Y7_1108 2413-2414
        Y7_1109 2415-2416       Y7_1110 2417-2418       Y7_1111 2419-2420
        Y7_1112 2421-2422       Y7_1113 2423-2424       Y7_1114 2425-2426
        Y7_1115 2427-2428       Y7_1116 2429-2430       Y7_1117 2431-2433
        Y7_1118 2434-2436       Y7_1119 2437-2438       Y7_1120 2439-2440
        Y7_1121 2441-2442       Y7_1122 2443-2444       Y7_1123 2445-2447
        Y7_1124 2448-2450       Y7_1125 2451-2452       Y7_1126 2453-2454
        Y7_1127 2455-2456       Y7_1128 2457-2458       Y7_1129 2459-2460
        Y7_1130 2461-2462       Y7_1131 2463-2464       Y7_1132 2465-2466
        Y7_1133 2467-2468       Y7_1134 2469-2470       Y7_1135 2471-2472
        Y7_1136 2473-2474       Y7_1137 2475-2476       Y7_1138 2477-2478
        Y7_1139 2479-2481       Y7_1140 2482-2483       Y7_1141 2484-2485
        Y7_1142 2486-2487       Y7_1143 2488-2489       Y7_1144 2490-2491
        Y7_1145 2492-2493       Y7_1146 2494-2495       Y7_1147 2496-2497
        Y7_1148 2498-2499       Y7_1149 2500-2501       Y7_1150 2502-2503
        Y7_1151 2504-2505       Y7_1152 2506-2507       Y7_1153 2508-2509
        Y7_1154 2510-2512       Y7_1155 2513-2515       Y7_1156 2516-2518
        Y7_1157 2519-2520       Y7_1158 2521-2522       Y7_1159 2523-2524
        Y7_1160 2525-2526       Y7_1161 2527-2528       Y7_1162 2529-2530
        Y7_1163 2531-2532       Y7_1164 2533-2534       Y7_1165 2535-2536
        Y7_1166 2537-2538       Y7_1167 2539-2540       Y7_1168 2541-2542
        Y7_1169 2543-2544       Y7_1170 2545-2547       Y7_1171 2548-2550
        Y7_1172 2551-2553       Y7_1173 2554-2555       Y7_1174 2556-2557
        Y7_1175 2558-2559       Y7_1176 2560-2562       Y7_1177 2563-2564
        Y7_1178 2565-2566       Y7_1179 2567-2569       Y7_1180 2570-2572
        Y7_1181 2573-2574       Y7_1182 2575-2576       Y7_1183 2577-2578
        Y7_1184 2579-2580       Y7_1185 2581-2582       Y7_1186 2583-2584
        Y7_1187 2585-2586       Y7_1188 2587-2588       Y7_1189 2589-2590
        Y7_1190 2591-2592       Y7_1191 2593-2594       Y7_1192 2595-2596
        Y7_1193 2597-2598       Y7_1194 2599-2600       Y7_1195 2601-2602
        Y7_1197 2603-2604       Y7_1198 2605-2606       Y7_1199 2607-2608
        Y7_1200 2609-2610       Y7_1201 2611-2612       Y7_1202 2613-2614
        Y7_1203 2615-2616       Y7_1204 2617-2618       Y7_1205 2619-2620
        Y7_1206 2621-2622       Y7_1207 2623-2624       Y7_1208 2625-2626
        Y7_1209 2627-2628       Y7_1210 2629-2630       Y7_1211 2631-2632
        Y7_1212 2633-2634       Y7_1213 2635-2636       Y7_1214 2637-2638
        Y7_1215 2639-2640       Y7_1216 2641-2642       Y7_1217 2643-2644
        Y7_1218 2645-2646       Y7_1219 2647-2648       Y7_1220 2649-2650
        Y7_1221 2651-2652       Y7_1222 2653-2654       Y7_1223 2655-2656
        Y7_1224 2657-2658       Y7_1225 2659-2660       Y7_1226 2661-2662
        Y7_1227 2663-2664       Y7_1228 2665-2666       Y7_1229 2667-2668
        Y7_1230 2669-2670       Y7_1231 2671-2672       Y7_1232 2673-2674
        Y7_1233 2675-2676       Y7_1234 2677-2678       Y7_1235 2679-2680
        Y7_1236 2681-2682       Y7_1237 2683-2684       Y7_1238 2685-2686
        Y7_1239 2687-2688       Y7_1240 2689-2690       Y7_1241 2691-2692
        Y7_1242 2693-2694       Y7_1243 2695-2696       Y7_1244 2697-2698
        Y7_1245 2699-2700       Y7_1246 2701-2702       Y7_1247 2703-2704
        Y7_1248 2705-2706       Y7_1249 2707-2708       Y7_1250 2709-2710
        Y7_1251 2711-2712       Y7_1252 2713-2714       Y7_1253 2715-2716
        Y7_1254 2717-2718       Y7_1255 2719-2720       Y7_1256 2721-2722
        Y7_1257 2723-2724       Y7_1258 2725-2726       Y7_1259 2727-2728
        Y7_1260 2729-2730       Y7_1261 2731-2732       Y7_1262 2733-2734
        Y7_1263 2735-2736       Y7_1264 2737-2738       Y7_1265 2739-2740
        Y7_1266 2741-2742       Y7_1267 2743-2744       Y7_1268 2745-2746
        Y7_1269 2747-2748       Y7_1270 2749-2750       Y7_1271 2751-2752
        Y7_1272 2753-2754       Y7_1273 2755-2757       Y7_1274 2758-2759
        Y7_1275 2760-2761       Y7_1276 2762-2763       Y7_1277 2764-2765
        Y7_1278 2766-2768       Y7_1279 2769-2770       Y7_1280 2771-2772
        Y7_1281 2773-2774       Y7_1282 2775-2776       Y7_1283 2777-2779
        Y7_1284 2780-2781       Y7_1285 2782-2783       Y7_1286 2784-2785
        Y7_1287 2786-2787       Y7_1288 2788-2790       Y7_1289 2791-2792
        Y7_1290 2793-2794       Y7_1291 2795-2796       Y7_1292 2797-2798
        Y7_1293 2799-2801       Y7_1294 2802-2803       Y7_1295 2804-2805
        Y7_1296 2806-2807       Y7_1297 2808-2809       Y7_1298 2810-2812
        Y7_1299 2813-2814       Y7_1300 2815-2816       Y7_1301 2817-2818
        Y7_1302 2819-2820       Y7_1303 2821-2823       Y7_1304 2824-2825
        Y7_1305 2826-2827       Y7_1306 2828-2829       Y7_1307 2830-2831
        Y7_1308 2832-2834       Y7_1309 2835-2836       Y7_1310 2837-2838
        Y7_1311 2839-2840       Y7_1312 2841-2842       Y7_1313 2843-2845
        Y7_1314 2846-2847       Y7_1315 2848-2849       Y7_1316 2850-2851
        Y7_1317 2852-2853       Y7_1318 2854-2856       Y7_1319 2857-2858
        Y7_1320 2859-2860       Y7_1321 2861-2862       Y7_1322 2863-2864
        Y7_1323 2865-2867       Y7_1324 2868-2869       Y7_1325 2870-2871
        Y7_1326 2872-2873       Y7_1327 2874-2875       Y7_1328 2876-2878
        Y7_1329 2879-2880       Y7_1330 2881-2882       Y7_1331 2883-2884
        Y7_1332 2885-2886       Y7_1333 2887-2889       Y7_1334 2890-2891
        Y7_1335 2892-2893       Y7_1336 2894-2895       Y7_1337 2896-2897
        Y7_1338 2898-2900       Y7_1339 2901-2902       Y7_1340 2903-2904
        Y7_1341 2905-2906       Y7_1342 2907-2908       Y7_1343 2909-2911
        Y7_1344 2912-2913       Y7_1345 2914-2915       Y7_1346 2916-2917
        Y7_1347 2918-2919       Y7_1348 2920-2922       Y7_1349 2923-2924
        Y7_1350 2925-2926       Y7_1351 2927-2928       Y7_1352 2929-2930
        Y7_1353 2931-2933       Y7_1354 2934-2935       Y7_1355 2936-2937
        Y7_1356 2938-2939       Y7_1357 2940-2941       Y7_1358 2942-2943
        Y7_1359 2944-2945       Y7_1360 2946-2947       Y7_1361 2948-2949
        Y7_1362 2950-2951       Y7_1363 2952-2953       Y7_1364 2954-2955
        Y7_1365 2956-2957       Y7_1366 2958-2959       Y7_1367 2960-2961
        Y7_1368 2962-2963       Y7_1369 2964-2965       Y7_1370 2966-2967
        Y7_1371 2968-2969       Y7_1372 2970-2971       Y7_1373 2972-2973
        Y7_1374 2974-2975       Y7_1375 2976-2977       Y7_1376 2978-2979
        Y7_1377 2980-2981       Y7_1378 2982-2984       Y7_1379 2985-2987
        Y7_1380 2988-2989       Y7_1381 2990-2992       Y7_1382 2993-2994
        Y7_1383 2995-2996       Y7_1384 2997-2999       Y7_1385 3000-3001
        Y7_1386 3002-3004       Y7_1387 3005-3006       Y7_1388 3007-3008
        Y7_1389 3009-3011       Y7_1390 3012-3013       Y7_1391 3014-3015
        Y7_1392 3016-3017       Y7_1393 3018-3019       Y7_1394 3020-3021
        Y7_1395 3022-3023       Y7_1396 3024-3025       Y7_1397 3026-3028
        Y7_1398 3029-3031       Y7_1399 3032-3033       Y7_1400 3034-3035
        Y7_1401 3036-3037       Y7_1402 3038-3039       Y7_1403 3040-3041
        Y7_1404 3042-3043       Y7_1405 3044-3045       Y7_1406 3046-3048
        Y7_1407 3049-3050       Y7_1408 3051-3052       Y7_1409 3053-3054
        Y7_1410 3055-3056       Y7_1411 3057-3058       Y7_1412 3059-3060
        Y7_1413 3061-3062       Y7_1414 3063-3064       Y7_1415 3065-3067
        Y7_1416 3068-3069       Y7_1417 3070-3071       Y7_1418 3072-3073
        Y7_1419 3074-3075       Y7_1420 3076-3077       Y7_1421 3078-3079
        Y7_1422 3080-3081       Y7_1423 3082-3084       Y7_1424 3085-3087
        Y7_1425 3088-3090       Y7_1426 3091-3093       Y7_1427 3094-3096
        Y7_1428 3097-3099       Y7_1429 3100-3101       Y7_1430 3102-3103
        Y7_1431 3104-3105       Y7_1432 3106-3107       Y7_1433 3108-3109
        Y7_1434 3110-3111       Y7_1435 3112-3114       Y7_1436 3115-3117
        Y7_1437 3118-3119       Y7_1451 3120-3121       Y7_1452 3122-3123
        Y7_1453 3124-3125       Y7_1454 3126-3127       Y7_1455 3128-3129
        Y7_1456 3130-3131       Y7_1457 3132-3133       Y7_1458 3134-3135
        Y7_1459 3136-3137       Y7_1460 3138-3139       Y7_1461 3140-3141
        Y7_1466 3142-3143       Y7_1467 3144-3145       Y7_1468 3146-3147
        Y7_1469 3148-3149       Y7_1470 3150-3151       Y7_1471 3152-3153
        Y7_1472 3154-3155       Y7_1473 3156-3157       Y7_1474 3158-3159
        Y7_1475 3160-3161       Y7_1476 3162-3163       Y7_1477 3164-3165
        Y7_1478 3166-3167       Y7_1479 3168-3169       Y7_1480 3170-3171
        Y7_1481 3172-3173       Y7_1482 3174-3175       Y7_1483 3176-3177
        Y7_1484 3178-3179       Y7_1485 3180-3181       Y7_1486 3182-3183
        Y7_1487 3184-3185       Y7_1730 3186-3187       ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'CASE IDENTIFICATION NUMBER'
   DTSET1  = 'DATA SET NAME'
   SSMPL1  = 'SSMPL'
   HHLD1   = 'HOUSEHOLD ID'
   RESP1   = 'RESPONDENT ID'
   Y7_1    = 'ADMINISTRATION CODE'
   Y7_2    = 'SEX'
   Y7_3    = 'ETHNICITY'
   Y7_7    = 'AGE'
   Y7_8    = 'MILITARY IN 1984'
   Y7_9    = 'MILITARY IN 1985'
   Y7_10   = 'MILITARY IN 1986'
   Y7_11   = 'BRANCH OF MILITARY'
   Y7_12   = 'MARITAL STATUS'
   Y7_13   = 'IF SINGLE: Ever Married?'
   Y7_14   = 'MARRIED IN 1984'
   Y7_15   = 'MARRIED IN 1985'
   Y7_16   = 'MARRIED IN 1986'
   Y7_17   = 'SPOUSE SERIOUS ACCIDENT'
   Y7_18   = 'SPOUSE SERIOUS ACCIDENT-MONTH'
   Y7_19   = 'SPOUSE SERIOUS ACCIDENT-YEAR'
   Y7_20   = 'SPOUSE SERIOUS ILLNESS'
   Y7_21   = 'SPOUSE SERIOUS ILLNESS-MONTH'
   Y7_22   = 'SPOUSE SERIOUS ILLNESS-YEAR'
   Y7_23   = 'SPOUSE UNEMPLOYED'
   Y7_24   = 'SPOUSE UNEMPLOYED 1984-MOS'
   Y7_25   = 'SPOUSE UNEMPLOYED 1985-MOS'
   Y7_26   = 'SPOUSE UNEMPLOYED 1986-MOS'
   Y7_27   = 'RESPONDENT SERIOUS ACCIDENT'
   Y7_28   = 'RESPONDENT SERIOUS ACCIDENT-MOS'
   Y7_29   = 'RESP SERIOUS ACCID-1984,1985,1986'
   Y7_30   = 'RESPONDENT SERIOUS ILLNESS'
   Y7_31   = 'RESPONDENT SERIOUS ILLNESS-MOS'
   Y7_32   = 'RESP SERIOUS ILLNESS-1984,85,86'
   Y7_33   = 'PARENTS DIVORCE-1984'
   Y7_34   = 'PARENTS DIVORCE-1985'
   Y7_35   = 'PARENTS DIVORCE-1986'
   Y7_36   = 'PARENTS SEPARATION-1984'
   Y7_37   = 'PARENTS SEPARATION-1985'
   Y7_38   = 'PARENTS SEPARATION-1986'
   Y7_39   = 'PARENTS REMARRIAGE-1984'
   Y7_40   = 'PARENTS REMARRIAGE-1985'
   Y7_41   = 'PARENTS REMARRIAGE-1986'
   Y7_42   = 'PARENTS DEATH-1984'
   Y7_43   = 'PARENTS DEATH-1985'
   Y7_44   = 'PARENTS DEATH-1986'
   Y7_45   = 'PARENTS SERIOUS ACCIDENT-1984'
   Y7_46   = 'PARENTS SERIOUS ACCIDENT-1985'
   Y7_47   = 'PARENTS SERIOUS ACCIDENT-1986'
   Y7_48   = 'PARENTS SERIOUS ILLNESS-1984'
   Y7_49   = 'PARENTS SERIOUS ILLNESS-1985'
   Y7_50   = 'PARENTS SERIOUS ILLNESS-1986'
   Y7_51   = 'FATHER LOST JOB-1984'
   Y7_52   = 'FATHER LOST JOB-1985'
   Y7_53   = 'FATHER LOST JOB-1986'
   Y7_54   = 'MOTHER LOST JOB-1984'
   Y7_55   = 'MOTHER LOST JOB-1985'
   Y7_56   = 'MOTHER LOST JOB-1986'
   Y7_57   = 'LIVED WITH LONGEST'
   Y7_58   = 'LIVED WITH 2ND LONGEST'
   Y7_59   = 'LIVED WITH 3RD LONGEST'
   Y7_60   = 'NEIGH PROB-HIGH UNEMPLOYMENT'
   Y7_61   = 'NEIGH PROB-RACIAL CONFLICT'
   Y7_62   = 'NEIGH PROB-VANDALISM'
   Y7_63   = 'NEIGH PROB-LAWLESSNESS'
   Y7_64   = 'NEIGH PROB-WINOS AND JUNKIES'
   Y7_65   = 'NEIGH PROB-PROSTITUTION'
   Y7_66   = 'NEIGH PROB-TRAFFIC'
   Y7_67   = 'NEIGH PROB-ABANDONED HOUSES'
   Y7_68   = 'NEIGH PROB-SEX ASSAULTS/RAPES'
   Y7_69   = 'NEIGH PROB-BURGLARIES/THEFTS'
   Y7_70   = 'NEIGH PROB-GAMBLING'
   Y7_71   = 'NEIGH PROB-RUN DOWN BUILDINGS'
   Y7_72   = 'NEIGH PROB-ORGANIZED CRIME'
   Y7_73   = 'NEIGH PROB-ASSAULTS/MUGGINGS'
   Y7_74   = 'NEIGH PROB-DELINQUENT GANGS'
   Y7_75   = 'PARTICULAR GROUP OF FRIENDS'
   Y7_76   = 'ANY CLOSE FRIENDS'
   Y7_77   = 'HOW IMPORTANT TO HAVE FRIENDS'
   Y7_78   = 'STRESS FROM NOT HAVING FRIENDS'
   Y7_79   = 'AFT/WKD SPENT W/FRIENDS'
   Y7_80   = 'EVEN/WKD SPENT W/FRIENDS'
   Y7_81   = 'TIME SPENT W/FRIENDS ON WKENDS'
   Y7_82   = 'HRS PER WK SPENT W/FRIENDS'
   Y7_83   = 'FRIENDS'' INFLUENCE'
   Y7_84   = 'WANT TO BE LIKE CLOSEST FRIENDS'
   Y7_85   = 'HOW IMP WAS IT TO HAVE FRIENDS'
   Y7_86   = 'HOW SATISFIED W/GROUP OF FRIENDS'
   Y7_87   = 'INTEREST/ACTIVITY SHARED W/FRIEND'
   Y7_88   = 'STRESS/PRESSURE W/FRIENDS'
   Y7_89   = 'WARMTH/AFFECTION FROM FRIENDS'
   Y7_90   = 'SUPPORT/ENCOURAGE FROM FRIENDS'
   Y7_91   = 'LOYALTY FOR ONE'
   Y7_92   = 'RESPONDENT IN EDUCATION EXPER'
   Y7_93   = 'HIGHEST GRADE COMPLETED'
   Y7_94   = 'LAST YEAR IN SCHOOL'
   Y7_95   = 'SATISFIED W/EDUCATION EXPERIENCE'
   Y7_96   = 'IMP PAST EDUCATION EXPERIENCE'
   Y7_97   = 'STRESS/PRESSURE FROM SIG OTHERS'
   Y7_98   = 'SCHOOL 1986, HIGHEST GRADE COMPL'
   Y7_99   = 'GRADE POINT AVERAGE'
   Y7_100  = 'AFT/SCHOOL WK SPENT STUDYING'
   Y7_101  = 'EVE/SCHOOL WK SPENT STUDYING'
   Y7_102  = 'TIME SPENT STUDYING ON WKENDS'
   Y7_103  = 'HRS PER WK SPENT STUDYING'
   Y7_104  = 'HOW IMP SCHOOL/COLLEGE WORK'
   Y7_105  = 'SATISFIED W/EDUCATION EXPERIENCE'
   Y7_106  = 'STRESS/PRESSURE IN SCHOOL/COLLEGE'
   Y7_107  = 'ANY JOBS IN THE PAST YEAR'
   Y7_108  = 'LOOKED COULDN''T FIND JOB IN 1986'
   Y7_109  = 'LACKED NECESSARY SKILLS'
   Y7_110  = 'LACKED EXPERIENCE'
   Y7_111  = 'LACKED EDUCATIONAL REQUIREMENTS'
   Y7_112  = 'RACIAL DISCRIMINATION'
   Y7_113  = 'SEXUAL DISCRIMINATION'
   Y7_114  = 'JOB DIDN''T PAY ENOUGH'
   Y7_115  = 'NO JOBS AVAILABLE'
   Y7_116  = 'PRISON RECORD'
   Y7_117  = 'TRANSPORTATION PROBLEMS'
   Y7_118  = 'TOO YOUNG'
   Y7_119  = 'TIMING PROBLEMS'
   Y7_120  = 'OTHER'
   Y7_121  = 'RECEIVE WELFARE/PUBLIC ASSISTANCE'
   Y7_122  = 'HOW IMPORTANT TO HAVE A JOB'
   Y7_123  = 'HOW MUCH STRESS/PRESSURE SIG OTH'
   Y7_124  = 'TOTAL NO. JOBS REPORTED FOR 1986'
   Y7_125  = 'DUNCAN SOCIOECONOMIC INDEX 1986'
   Y7_126  = 'HOLLINGSHEAD CODE MAJOR JOB 1986'
   Y7_127  = 'WEEKS WORKED-1986'
   Y7_128  = 'HOURS PER WEEK-1986'
   Y7_129  = 'HIGHEST HOURLY WAGE IN 1986'
   Y7_130  = 'DUNCAN SOCIOECONOMIC INDEX 1986'
   Y7_131  = 'WEEKS WORKED-1986'
   Y7_132  = 'HOURS PER WEEK-1986'
   Y7_133  = 'HIGHEST HOURLY WAGE IN 1986'
   Y7_134  = 'DUNCAN SOCIOECONOMIC INDEX 1986'
   Y7_135  = 'WEEKS WORKED-1986'
   Y7_136  = 'HOURS PER WEEK-1986'
   Y7_137  = 'HIGHEST HOURLY WAGE IN 1986'
   Y7_138  = 'DUNCAN SOCIOECONOMIC INDEX 1986'
   Y7_139  = 'WEEKS WORKED-1986'
   Y7_140  = 'HOURS PER WEEK-1986'
   Y7_141  = 'HIGHEST HOURLY WAGE IN 1986'
   Y7_142  = 'DUNCAN SOCIOECONOMIC INDEX 1986'
   Y7_143  = 'WEEKS WORKED-1986'
   Y7_144  = 'HOURS PER WEEK-1986'
   Y7_145  = 'HIGHEST HOURLY WAGE IN 1986'
   Y7_146  = 'TOTAL WKS WORKED OTHER JOBS-1986'
   Y7_147  = 'MEAN NO HRS/WK OTHER JOBS-1986'
   Y7_148  = 'AVG HRLY WAGE ALL OTHER JOBS-1986'
   Y7_149  = 'HOW IMPORTANT WAS MAJOR JOB'
   Y7_150  = 'HOW SATISFIED WITH MAJOR JOB'
   Y7_151  = 'HOW MUCH PRESSURE/STRESS AT WORK'
   Y7_152  = 'LOOKED COULDN''T FIND JOB IN 1986'
   Y7_153  = 'LACKED NECESSARY SKILLS'
   Y7_154  = 'LACKED EXPERIENCE'
   Y7_155  = 'LACKED EDUCATIONAL REQUIREMENTS'
   Y7_156  = 'RACIAL DISCRIMINATION'
   Y7_157  = 'SEXUAL DISCRIMINATION'
   Y7_158  = 'JOB DIDN''T PAY ENOUGH'
   Y7_159  = 'NO JOBS AVAILABLE'
   Y7_160  = 'PRISON RECORD'
   Y7_161  = 'TRANSPORTATION PROBLEMS'
   Y7_162  = 'TOO YOUNG'
   Y7_163  = 'TIMING PROBLEMS'
   Y7_164  = 'OTHER'
   Y7_165  = 'WELFARE/PUBLIC ASSISTANCE'
   Y7_166  = 'BEEN FIRED/LAID OFF PAST YEAR'
   Y7_167  = 'REDUCTION IN FORCE'
   Y7_168  = 'LOW SENIORITY'
   Y7_169  = 'FOR VIOLATION OF COMPANY RULES'
   Y7_170  = 'RACIAL DISCRIMINATION'
   Y7_171  = 'SEXUAL DISCRIMINATION'
   Y7_172  = 'LACK OF SKILLS FOR THE JOB'
   Y7_173  = 'PERSONALITY CONFLICT'
   Y7_174  = 'USING ALCOHOL/DRUGS ON THE JOB'
   Y7_175  = 'USING ALCOHOL/DRUGS OFF THE JOB'
   Y7_176  = 'THEFT OF COMPANY CASH/PROPERTY'
   Y7_177  = 'SEXUAL HARRASSMENT'
   Y7_178  = 'WAS TERMINATION JUSTIFIED'
   Y7_179  = 'INTERPERSONAL SKILLS'
   Y7_180  = 'JOB SKILLS'
   Y7_181  = 'LEVEL OF EDUCATIONAL ACHIEVEMENT'
   Y7_182  = 'AMOUNT OF JOB EXPERIENCE'
   Y7_183  = 'SEXUAL DISCRIMINATION'
   Y7_184  = 'RACIAL DISCRIMINATION'
   Y7_185  = 'APPEARANCE'
   Y7_186  = 'AMOUNT INCOME OTHER THAN JOB EARN'
   Y7_187  = 'EMPLOYED DURING 1985'
   Y7_188  = 'NUMBER OF JOBS IN 1985'
   Y7_189  = 'DUNCAN SOCIOECONOMIC INDEX 1985'
   Y7_190  = 'HOLLINGSHEAD CODE MAJOR JOB 1985'
   Y7_191  = 'WEEKS WORKED-1985'
   Y7_192  = 'HOURS PER WEEK-1985'
   Y7_193  = 'HIGHEST HOURLY WAGE IN 1985'
   Y7_194  = 'DUNCAN SOCIOECONOMIC INDEX 1985'
   Y7_195  = 'WEEKS WORKED-1985'
   Y7_196  = 'HOURS PER WEEK-1985'
   Y7_197  = 'HIGHEST HOURLY WAGE IN 1985'
   Y7_198  = 'DUNCAN SOCIOECONOMIC INDEX 1985'
   Y7_199  = 'WEEKS WORKED-1985'
   Y7_200  = 'HOURS PER WEEK-1985'
   Y7_201  = 'HIGHEST HOURLY WAGE IN 1985'
   Y7_202  = 'DUNCAN SOCIOECONOMIC INDEX 1985'
   Y7_203  = 'WEEKS WORKED-1985'
   Y7_204  = 'HOURS PER WEEK-1985'
   Y7_205  = 'HOURLY WAGE IN 1985'
   Y7_206  = 'DUNCAN SOCIOECONOMIC INDEX 1985'
   Y7_207  = 'WEEKS WORKED-1985'
   Y7_208  = 'HOURS PER WEEK-1985'
   Y7_209  = 'HIGHEST HOURLY WAGE IN 1985'
   Y7_210  = 'EMPLOYED DURING 1984'
   Y7_211  = 'NUMBER OF JOBS IN 1984'
   Y7_212  = 'DUNCAN SOCIOECONOMIC INDEX 1984'
   Y7_213  = 'HOLLINGSHEAD CODE MAJOR JOB 1984'
   Y7_214  = 'WEEKS WORKED-1984'
   Y7_215  = 'HOURS PER WEEK-1984'
   Y7_216  = 'HIGHEST HOURLY WAGE IN 1984'
   Y7_217  = 'DUNCAN SOCIOECONOMIC INDEX 1984'
   Y7_218  = 'WEEKS WORKED-1984'
   Y7_219  = 'HOURS PER WEEK-1984'
   Y7_220  = 'HIGHEST HOURLY WAGE IN 1984'
   Y7_221  = 'DUNCAN SOCIOECONOMIC INDEX 1984'
   Y7_222  = 'WEEKS WORKED-1984'
   Y7_223  = 'HOURS PER WEEK-1984'
   Y7_224  = 'HIGHEST HOURLY WAGE IN 1984'
   Y7_225  = 'DUNCAN SOCIOECONOMIC INDEX 1984'
   Y7_226  = 'WEEKS WORKED-1984'
   Y7_227  = 'HOURS PER WEEK-1984'
   Y7_228  = 'HIGHEST HOURLY WAGE IN 1984'
   Y7_229  = 'DUNCAN SOCIOECONOMIC INDEX 1984'
   Y7_230  = 'WEEKS WORKED-1984'
   Y7_231  = 'HOURS PER WEEK-1984'
   Y7_232  = 'HIGHEST HOURLY WAGE IN 1984'
   Y7_233  = 'DURING 1986 MOST RECENT PARTNER'
   Y7_234  = 'MONTHS LIVED WITH PARTNER'
   Y7_235  = 'HOW IMPORTANT ACTIVIT W/PARTNER'
   Y7_236  = 'PARTNER''S INFLUENCE'
   Y7_237  = 'WANT TO BE LIKE PARTNER'
   Y7_238  = 'SATISFIED W/RELATION W/PARTNER'
   Y7_239  = 'INTEREST/ACTIVIT SHARED W/PARTN'
   Y7_240  = 'HOW MUCH WARMTH/AFF FROM PARTNER'
   Y7_241  = 'HOW SATISFIED W/SEXUAL RELATIONS'
   Y7_242  = 'HOW MUCH SUPP/ENCOURAGE F/PARTNER'
   Y7_243  = 'HOW MUCH LOYALTY BETWN YOU/PART'
   Y7_244  = 'HOW MUCH STRESS/PRESS IN RELATION'
   Y7_245  = 'PARTNER TRY INFLUENCE YOU WRONG'
   Y7_246  = 'PARTNER EMPLOYED DURING 1986'
   Y7_247  = 'NO. JOBS PARTNER HAD IN 1986'
   Y7_248  = 'DUNCAN SOCIOECONOMIC INDEX'
   Y7_249  = 'HOLLINGSHEAD CODE FOR MAJOR JOB'
   Y7_250  = 'WEEKS WORKED AT PRIMARY JOB'
   Y7_251  = 'HRS PER WKS WORKED AT PRIMARY JOB'
   Y7_252  = 'DUNCAN SOCIOECONOMIC INDEX'
   Y7_253  = 'WEEKS WORKED AT 2ND JOB'
   Y7_254  = 'HRS PER WKS WORKED AT 2ND JOB'
   Y7_255  = 'DUNCAN SOCIOECONOMIC INDEX'
   Y7_256  = 'WEEKS WORKED AT 3RD JOB'
   Y7_257  = 'HRS PER WKS WORKED AT 3RD JOB'
   Y7_258  = 'DUNCAN SOCIOECONOMIC INDEX'
   Y7_259  = 'WEEKS WORKED AT 4TH JOB'
   Y7_260  = 'HRS PER WKS WORKED AT 4TH JOB'
   Y7_261  = 'HIGHEST GRADE PARTNER COMPLETED'
   Y7_262  = 'PARTNER''S TOTAL INCOME IN 1986'
   Y7_263  = 'ACCURACY OF AMT GIVEN AS ANSWER'
   Y7_264  = 'FREQ PARTICIPATION FAM ACTIVITY'
   Y7_265  = 'NO. MOS LIVED W/FAMILY'
   Y7_266  = 'FREQ CONTACT W/FAMILY'
   Y7_267  = 'PARENTS'' INFLUENCE'
   Y7_268  = 'IMPORTANCE FAMILY ACTIVITIES'
   Y7_269  = 'HOW SATISFIED W/REL W/PARENTS'
   Y7_270  = 'HOW MUCH STRESS/PRESS REL PARENTS'
   Y7_271  = 'FREQ PARTICIPATION PART FAM ACTIV'
   Y7_272  = 'NO. MOS LIVED W/PARTNER''S FAMILY'
   Y7_273  = 'FREQ CONTACT W/PARTNER''S FAMILY'
   Y7_274  = 'PARTNER''S PARENTS'' INFLUENCE'
   Y7_275  = 'IMPORTANCE PARTNER''S FAM ACTIVITY'
   Y7_276  = 'STRESS/PRESS REL W/PART PAR'
   Y7_277  = 'HOW SATISFIED W/REL W/PART PAR'
   Y7_278  = 'AFT/SCHOOL WK SPENT W/FAMILY'
   Y7_279  = 'EVE/SCHOOL WK SPENT W/FAMILY'
   Y7_280  = 'TIME WKNDS SPENT W/FAMILY'
   Y7_281  = 'FREQ PARTICIPATION FAM ACTIV'
   Y7_282  = 'NO. MOS LIVED W/FAMILY'
   Y7_283  = 'FREQ OF CONTACT W/FAMILY'
   Y7_284  = 'PARENTS'' INFLUENCE'
   Y7_285  = 'IMPORTANCE OF FAMILY ACTIVITIES'
   Y7_286  = 'HOW SATISFIED W/REL W/PARENTS'
   Y7_287  = 'HOW MUCH WARMTH/AFF FROM PARENTS'
   Y7_288  = 'HOW MUCH SUPPORT/ENCOURAGE F/PAR'
   Y7_289  = 'HOW MUCH STRESS/PRESS REL W/PAR'
   Y7_290  = 'HAVE ANY CHILDREN'
   Y7_291  = 'OLDEST CHILD-BIRTHDATE MO'
   Y7_292  = 'OLDEST CHILD-BIRTHDATE YR'
   Y7_293  = 'OLDEST CHILD-SEX'
   Y7_294  = 'OLDEST CHILD-LIVING W/RESP'
   Y7_295  = 'OLDEST CHILD-BIOLOGICAL'
   Y7_296  = 'NEXT OLDEST CHILD-BIRTHDATE MO'
   Y7_297  = 'NEXT OLDEST CHILD-BIRTHDATE YR'
   Y7_298  = 'NEXT OLDEST CHILD-SEX'
   Y7_299  = 'NEXT OLDEST CHILD-LIVING W/RESP'
   Y7_300  = 'NEXT OLDEST CHILD-BIOLOGICAL'
   Y7_301  = 'NEXT OLDEST CHILD-BIRTHDATE MO'
   Y7_302  = 'NEXT OLDEST CHILD-BIRTHDATE YR'
   Y7_303  = 'NEXT OLDEST CHILD-SEX'
   Y7_304  = 'NEXT OLDEST CHILD-LIVING W/RESP'
   Y7_305  = 'NEXT OLDEST CHILD-BIOLOGICAL'
   Y7_306  = 'NEXT OLDEST CHILD-BIRTHDATE MO'
   Y7_307  = 'NEXT OLDEST CHILD-BIRTHDATE YR'
   Y7_308  = 'NEXT OLDEST CHILD-SEX'
   Y7_309  = 'NEXT OLDEST CHILD-LIVING W/RESP'
   Y7_310  = 'NEXT OLDEST CHILD-BIOLOGICAL'
   Y7_311  = 'NEXT OLDEST CHILD-BIRTHDATE MO'
   Y7_312  = 'NEXT OLDEST CHILD-BIRTHDATE YR'
   Y7_313  = 'NEXT OLDEST CHILD-SEX'
   Y7_314  = 'NEXT OLDEST CHILD-LIVING W/RESP'
   Y7_315  = 'NEXT OLDEST CHILD-BIOLOGICAL'
   Y7_316  = 'NEXT OLDEST CHILD-BIRTHDATE MO'
   Y7_317  = 'NEXT OLDEST CHILD-BIRTHDATE YR'
   Y7_318  = 'NEXT OLDEST CHILD-SEX'
   Y7_319  = 'NEXT OLDEST CHILD-LIVING W/RESP'
   Y7_320  = 'NEXT OLDEST CHILD-BIOLOGICAL'
   Y7_321  = 'HOW MUCH TIME SPENT W/CHILDREN'
   Y7_322  = 'ENJOYED BEING W/CHILDREN'
   Y7_323  = 'HOW SATISFIED W/RELATIONSHIP'
   Y7_324  = 'STRESS/PRESS IN REL W/CHILD'
   Y7_325  = 'ATTENDANCE AT RELIGIOUS SERVICES'
   Y7_326  = 'IMPORTANCE OF RELIGION'
   Y7_327  = 'SUCCESS IN WORK-HOW IMPORTANT'
   Y7_328  = 'SUCCESS IN WORK-HOW DOING'
   Y7_329  = 'ABILITIES IN WORK-HOW IMPORTANT'
   Y7_330  = 'ABILITIES IN WORK-HOW DOING'
   Y7_331  = 'GET AHEAD IN WORK-HOW IMPORTANT'
   Y7_332  = 'GET AHEAD IN WORK-HOW DOING'
   Y7_333  = 'HAVE GOOD JOB-HOW IMPORTANT'
   Y7_334  = 'HAVE GOOD JOB-HOW DOING'
   Y7_335  = 'GRAD FROM COLLEGE-HOW IMPORTANT'
   Y7_336  = 'GRAD FROM COLLEGE-HOW DOING'
   Y7_337  = 'GET MARRIED-HOW IMPORTANT'
   Y7_338  = 'GET MARRIED-HOW DOING'
   Y7_339  = 'HAVE LONG TERM REL-HOW IMPORTANT'
   Y7_340  = 'HAVE LONG TERM REL-HOW DOING'
   Y7_341  = 'HAVE CHILDREN-HOW IMPORTANT'
   Y7_342  = 'HAVE CHILDREN-HOW DOING'
   Y7_343  = 'EARN $20K ANNUAL-HOW IMPORTANT'
   Y7_344  = 'EARN $20K ANNUAL-HOW DOING'
   Y7_345  = 'CAN SUCCEED AT WORK W/O CHEATING'
   Y7_346  = 'LIE TO PARTNER AVOID ARGUMENTS'
   Y7_347  = 'LIE TO GET A JOB'
   Y7_348  = 'W/FRIENDS GOOD IMPRESS FOREMOST'
   Y7_349  = 'TO AVOID TROUBLE LIE TO TEACHERS'
   Y7_350  = 'W/PARENTS GOOD IMPRESS FOREMOST'
   Y7_351  = 'LIKING WORKERS REQUIRES COVER UP'
   Y7_352  = 'LIE OK KEEP PARTNER OUT/O TROUBLE'
   Y7_353  = 'CAN SUCCEED SCHOOL W/O CHEATING'
   Y7_354  = 'IMPORTANT TO BE HONEST W/PARENTS'
   Y7_355  = 'TO BE POPULAR MUST BREAK RULES'
   Y7_356  = 'OWN WORK MORE IMPORTANT'
   Y7_357  = 'BEAT UP KIDS GAIN RESPECT'
   Y7_358  = 'BREAK RULES TO SUCCEED AT WORK'
   Y7_359  = 'TO HAVE GOOD REL MUST DECEIVE'
   Y7_360  = 'PLAY DIRTY TO WIN AT SCHOOL'
   Y7_361  = 'LIE TO PARENTS TO KEEP TRUST'
   Y7_362  = 'W/TEACHERS GOOD IMPRESS FOREMOST'
   Y7_363  = 'BREAK PROMISE GET ALONG W/PARTNER'
   Y7_364  = 'LIE OK KEEP FRIEND OUT OF TROUBLE'
   Y7_365  = 'BREAK PARENT RULE KEEP FRIENDS'
   Y7_366  = 'WELL-LIKED'
   Y7_367  = 'NEED HELP'
   Y7_368  = 'BAD KID'
   Y7_369  = 'OFTEN UPSET'
   Y7_370  = 'GOOD CITIZEN'
   Y7_371  = 'GET ALONG WELL W/OTHERS'
   Y7_372  = 'MESSED UP'
   Y7_373  = 'BREAK RULES'
   Y7_374  = 'PERSONAL PROBLEMS'
   Y7_375  = 'GET INTO TROUBLE'
   Y7_376  = 'LIKELY TO SUCCEED'
   Y7_377  = 'DO THINGS AGAINST THE LAW'
   Y7_378  = 'PARENTS OPIN:CHEAT ON INCOME TAX'
   Y7_379  = 'PARENTS OPIN:STOLE WORTH < $5'
   Y7_380  = 'PARENTS OPIN:SOLD HARD DRUGS'
   Y7_381  = 'PARENTS OPIN:USED MARIJUANA'
   Y7_382  = 'PARENTS OPIN:STOLE WORTH > $50'
   Y7_383  = 'PARENTS OPIN:HIT SOMEONE'
   Y7_384  = 'PARENTS OPIN:USED ALCOHOL'
   Y7_385  = 'PARENTS OPIN:DESTROYED PROPERTY'
   Y7_386  = 'PARENTS OPIN:BROKE INTO VEHICLE'
   Y7_387  = 'PARENTS OPIN:DELIB HURT SP/PARTN'
   Y7_388  = 'PEER OPIN:CHEATED ON INCOME TAX'
   Y7_389  = 'PEER OPIN:STOLE WORTH < $5'
   Y7_390  = 'PEER OPIN:SOLD HARD DRUGS'
   Y7_391  = 'PEER OPIN:USED MARIJUANA'
   Y7_392  = 'PEER OPIN:STOLE WORTH > $50'
   Y7_393  = 'PEER OPIN:HIT SOMEONE'
   Y7_394  = 'PEER OPIN:USED ALCOHOL'
   Y7_395  = 'PEER OPIN:PRESSURED SEXUALLY'
   Y7_396  = 'PEER OPIN:DESTROYED PROPERTY'
   Y7_397  = 'PEER OPIN:BROKE INTO VEHICLE'
   Y7_398  = 'PEER OPIN:HAD SEXUAL INTERCOURSE'
   Y7_399  = 'PEER OPIN:DELIB HURT SPOUSE/PARTN'
   Y7_400  = 'COWORK OPIN:CHEATED ON INCOME TAX'
   Y7_401  = 'COWORK OPIN:STOLE WORTH < $5'
   Y7_402  = 'COWORK OPIN:SOLD HARD DRUGS'
   Y7_403  = 'COWORK OPIN:USED MARIJUANA'
   Y7_404  = 'COWORK OPIN:STOLE WORTH > $50'
   Y7_405  = 'COWORK OPIN:HIT SOMEONE'
   Y7_406  = 'COWORK OPIN:USED ALCOHOL'
   Y7_407  = 'COWORK OPIN:DESTROYED PROPERTY'
   Y7_408  = 'COWORK OPIN:BROKE INTO VEHICLE'
   Y7_409  = 'COWORK OPIN:DELIB HURT SP/PARTN'
   Y7_410  = 'PARTNER OPIN:CHEAT ON INCOME TAX'
   Y7_411  = 'PARTNER OPIN:STOLE WORTH < $5'
   Y7_412  = 'PARTNER OPIN:SOLD HARD DRUGS'
   Y7_413  = 'PARTNER OPIN:USED MARIJUANA'
   Y7_414  = 'PARTNER OPIN:STOLE WORTH > $50'
   Y7_415  = 'PARTNER OPIN:HIT SOMEONE'
   Y7_416  = 'PARTNER OPIN:USED ALCOHOL'
   Y7_417  = 'PARTNER OPIN:DESTROYED PROPERTY'
   Y7_418  = 'PARTNER OPIN:BROKE INTO VEHICLE'
   Y7_419  = 'PARTNER OPIN:DELIB HURT SP/PARTN'
   Y7_420  = 'OWN OPIN:CHEAT ON INCOME TAX'
   Y7_421  = 'OWN OPIN:DESTROY PROPERTY'
   Y7_422  = 'OWN OPIN:USE MARIJUANA'
   Y7_423  = 'OWN OPIN:STEAL WORTH < $5'
   Y7_424  = 'OWN OPIN:HIT SOMEONE'
   Y7_425  = 'OWN OPIN:USE ALCOHOL'
   Y7_426  = 'OWN OPIN:BREAK INTO VEHICLE'
   Y7_427  = 'OWN OPIN:SELL HARD DRUGS'
   Y7_428  = 'OWN OPIN:STOLE WORTH > $50'
   Y7_429  = 'OWN OPIN:GET DRUNK'
   Y7_430  = 'OWN OPIN:USE PRESCRIPTION DRUGS'
   Y7_431  = 'OWN OPIN:GIVE OR SELL ALCHOHOL'
   Y7_432  = 'OWN OPIN:ATTACK ONE TO HURT/KILL'
   Y7_433  = 'OWN OPIN:EXC SPEED LIM 10-20 MPH'
   Y7_434  = 'OWN OPIN:STRONGARM OTHER PEOPLE'
   Y7_435  = 'OWN OPIN:DELIB HURT SPOUSE/PART'
   Y7_436  = 'OWN FRIENDS:CHEAT ON INCOME TAX'
   Y7_437  = 'OWN FRIENDS:DESTROYED PROPERTY'
   Y7_438  = 'OWN FRIENDS:USED MARIJUANA'
   Y7_439  = 'OWN FRIENDS:STOLE WORTH < $5'
   Y7_440  = 'OWN FRIENDS:HIT SOMEONE'
   Y7_441  = 'OWN FRIENDS:USED ALCOHOL'
   Y7_442  = 'OWN FRIENDS:BROKEN INTO VEHICLE'
   Y7_443  = 'OWN FRIENDS:SOLD HARD DRUGS'
   Y7_444  = 'OWN FRIENDS:STOLEN WORTH > $50'
   Y7_445  = 'OWN FRIENDS:SUGG YOU BREAK LAW'
   Y7_446  = 'OWN FRIENDS:GOTTEN DRUNK'
   Y7_447  = 'OWN FRIENDS:USED PRESCRIP DRUGS'
   Y7_448  = 'OWN FRIENDS:GIVEN OR SOLD ALCH'
   Y7_449  = 'OWN FRIENDS:PRESS ONE SEXUALLY'
   Y7_450  = 'DAMAGED FAMILY PROP-FREQ'
   Y7_451  = 'DAMAGED FAMILY PROP-RATE'
   Y7_452  = 'DAMAGED EMPLOYER PROP-FREQ'
   Y7_453  = 'DAMAGED EMPLOYER PROP-RATE'
   Y7_454  = 'DAMAGED OTHER PROP-FREQ'
   Y7_455  = 'DAMAGED OTHER PROP-RATE'
   Y7_456  = 'STOLEN MOTOR VEHICLE-FREQ'
   Y7_457  = 'STOLEN MOTOR VEHICLE-RATE'
   Y7_458  = 'STOLEN > $50-FREQ'
   Y7_459  = 'STOLEN > $50-RATE'
   Y7_460  = 'BOUGHT STOLEN GOODS-FREQ'
   Y7_461  = 'BOUGHT STOLEN GOODS-RATE'
   Y7_462  = 'SET FIRE TO PROPERTY-FREQ'
   Y7_463  = 'SET FIRE TO PROPERTY-RATE'
   Y7_464  = 'CARRIED HIDDEN WEAPON-FREQ'
   Y7_465  = 'CARRIED HIDDEN WEAPON-RATE'
   Y7_466  = 'STOLEN < $5-FREQ'
   Y7_467  = 'STOLEN < $5-RATE'
   Y7_468  = 'ATTACKED SOMEONE-FREQ'
   Y7_469  = 'ATTACKED SOMEONE-RATE'
   Y7_470  = 'BEEN PAID SEX RELATIONS-FREQ'
   Y7_471  = 'BEEN PAID SEX RELATIONS-RATE'
   Y7_472  = 'PAID FOR SEX RELATIONS-FREQ'
   Y7_473  = 'PAID FOR SEX RELATIONS-RATE'
   Y7_474  = 'BEEN IN GANG FIGHTS-FREQ'
   Y7_475  = 'BEEN IN GANG FIGHTS-RATE'
   Y7_476  = 'USED CHECKS ILLEGALLY-FREQ'
   Y7_477  = 'USED CHECKS ILLEGALLY-RATE'
   Y7_478  = 'SOLD MARIJUANA-FREQ'
   Y7_479  = 'SOLD MARIJUANA-RATE'
   Y7_480  = 'HITCHHIKED WHERE ILLEGAL-FREQ'
   Y7_481  = 'HITCHHIKED WHERE ILLEGAL-RATE'
   Y7_482  = 'STOLEN MONEY FROM FAMILY-FREQ'
   Y7_483  = 'STOLEN MONEY FROM FAMILY-RATE'
   Y7_484  = 'STOLEN MONEY FROM EMPLOYER-FREQ'
   Y7_485  = 'STOLEN MONEY FROM EMPLOYER-RATE'
   Y7_486  = 'SEX AGAINST SOMEONE''S WILL-FREQ'
   Y7_487  = 'SEX AGAINST SOMEONE''S WILL-RATE'
   Y7_488  = 'HIT PARENT-FREQ'
   Y7_489  = 'HIT PARENT-RATE'
   Y7_490  = 'HIT SOMEONE AT WORK-FREQ'
   Y7_491  = 'HIT SOMEONE AT WORK-RATE'
   Y7_492  = 'HIT ANYONE ELSE-FREQ'
   Y7_493  = 'HIT ANYONE ELSE-RATE'
   Y7_494  = 'BEEN LOUD/ROWDY-FREQ'
   Y7_495  = 'BEEN LOUD/ROWDY-RATE'
   Y7_496  = 'SOLD HARD DRUGS-FREQ'
   Y7_497  = 'SOLD HARD DRUGS-RATE'
   Y7_498  = 'TRIED TO SELL WORTHLESS-FREQ'
   Y7_499  = 'TRIED TO SELL WORTHLESS-RATE'
   Y7_500  = 'TAKEN VEHICLE-FREQ'
   Y7_501  = 'TAKEN VEHICLE-RATE'
   Y7_502  = 'BOUGHT LIQUOR FOR MINOR-FREQ'
   Y7_503  = 'BOUGHT LIQUOR FOR MINOR-RATE'
   Y7_504  = 'USED FORCE ON OTHERS-FREQ'
   Y7_505  = 'USED FORCE ON OTHERS-RATE'
   Y7_506  = 'AVOIDED PAYING FOR THINGS-FREQ'
   Y7_507  = 'AVOIDED PAYING FOR THINGS-RATE'
   Y7_508  = 'BEEN DRUNK-FREQ'
   Y7_509  = 'BEEN DRUNK-RATE'
   Y7_510  = 'STOLEN THINGS $5 TO $50-FREQ'
   Y7_511  = 'STOLEN THINGS $5 TO $50-RATE'
   Y7_512  = 'BROKEN INTO BUILDING-FREQ'
   Y7_513  = 'BROKEN INTO BUILDING-RATE'
   Y7_514  = 'BEGGED FOR MONEY-FREQ'
   Y7_515  = 'BEGGED FOR MONEY-RATE'
   Y7_516  = 'FAILED TO RETURN CHANGE-FREQ'
   Y7_517  = 'FAILED TO RETURN CHANGE-RATE'
   Y7_518  = 'USED CREDIT W/O PERMISSION-FREQ'
   Y7_519  = 'USED CREDIT W/O PERMISSION-RATE'
   Y7_520  = 'OBSCENE PHONE CALLS-FREQ'
   Y7_521  = 'OBSCENE PHONE CALLS-RATE'
   Y7_522  = 'PICKED SOMEONE''S POCKET-FREQ'
   Y7_523  = 'PICKED SOMEONE''S POCKET-RATE'
   Y7_524  = 'EMBEZZLED MONEY/FUNDS-FREQ'
   Y7_525  = 'EMBEZZLED MONEY/FUNDS-RATE'
   Y7_526  = 'DAMAGED FAMILY PROPERTY'
   Y7_527  = 'DAMAGED EMPLOYER''S PROPERTY'
   Y7_528  = 'DAMAGED OTHER PROPERTY'
   Y7_529  = 'STOLEN MV-THE LAST TIME'
   Y7_530  = 'STOLEN MV-NEXT TO LAST TIME'
   Y7_531  = 'STOLEN MV-TIME BEFORE THAT'
   Y7_532  = 'STOLEN > $50-THE LAST TIME'
   Y7_533  = 'STOLEN > $50-NEXT TO LAST TIME'
   Y7_534  = 'STOLEN > $50-TIME BEFORE THAT'
   Y7_535  = 'BOUGHT STOLEN GOODS'
   Y7_536  = 'SET FIRE TO PROPERTY'
   Y7_537  = 'CARRIED A HIDDEN WEAPON'
   Y7_538  = 'STOLEN SOMETHING WORTH < $5'
   Y7_539  = 'ATTACK SOMEONE-THE LAST TIME'
   Y7_540  = 'ATTACK SOMEONE-NEXT TO LAST TIME'
   Y7_541  = 'ATTACK SOMEONE-TIME BEFORE THAT'
   Y7_542  = 'IN GANG FIGHTS-THE LAST TIME'
   Y7_543  = 'IN GANG FIGHTS-NEXT TO LAST TIME'
   Y7_544  = 'IN GANG FIGHTS-TIME BEFORE THAT'
   Y7_545  = 'USED CHECKS ILLEGALLY'
   Y7_546  = 'SOLD MARIJUANA'
   Y7_547  = 'STOLEN MONEY FROM FAMILY'
   Y7_548  = 'STOLEN MONEY FROM EMPLOYER'
   Y7_549  = 'SEX AGAINST WILL-THE LAST TIME'
   Y7_550  = 'SEX AGAINST WILL-NEXT/LAST TIME'
   Y7_551  = 'SEX AGN''ST WILL-TIME BEFORE THAT'
   Y7_552  = 'HIT PARENT'
   Y7_553  = 'HIT SOMEONE AT WORK'
   Y7_554  = 'HIT ANYONE ELSE'
   Y7_555  = 'SOLD HARD DRUGS'
   Y7_556  = 'TRIED SELL SOMETHING WORTHLESS'
   Y7_557  = 'TAKEN VEHICLE'
   Y7_558  = 'FORCE OTHERS-THE LAST TIME'
   Y7_559  = 'FORCE OTHERS-NEXT TO LAST TIME'
   Y7_560  = 'FORCE OTHERS-TIME BEFORE THAT'
   Y7_561  = 'STOLEN THINGS WORTH FROM $5-$50'
   Y7_562  = 'BROKEN INTO BLDG-THE LAST TIME'
   Y7_563  = 'BROKEN INTO BLDG-NEXT/LAST TIME'
   Y7_564  = 'BROKE INTO BLDG-TIME BEFORE THAT'
   Y7_565  = 'CREDIT CARDS WITHOUT PERMISSION'
   Y7_566  = 'PICKED SOMEONE''S POCKET'
   Y7_567  = 'EMBEZZLED MONEY OR FUNDS'
   Y7_568  = 'DAMAGE FAM PROP-HOW MUCH WORTH'
   Y7_569  = 'DAMAGE FAM PROP-OTHERS INVOLVED'
   Y7_570  = 'DAMAGE FAM PROP-1ST ITEM NO.'
   Y7_571  = 'DAMAGE FAM PROP-2ND ITEM NO.'
   Y7_572  = 'DAMAGE EMPLOY PROP-WORTH'
   Y7_573  = 'DAMAGE EMPLOY PROP-OTHER INVOLVE'
   Y7_574  = 'DAMAGE EMPLOY PROP-1ST ITEM NO.'
   Y7_575  = 'DAMAGE EMPLOY PROP-2ND ITEM NO.'
   Y7_576  = 'DAMAGE OTHER PROP-HOW MUCH WORTH'
   Y7_577  = 'DAMAGE OTHER PROP-OTHER INVOLVE'
   Y7_578  = 'DAMAGE OTHER PROP-1ST ITEM NO.'
   Y7_579  = 'DAMAGE OTHER PROP-2ND ITEM NO.'
   Y7_580  = 'STOLE MV/LAST TIME-KIND O/VEHICLE'
   Y7_581  = 'STOLE MV/LAST TIME-ACTUALLY STEAL'
   Y7_582  = 'STOLE MV/LAST TIME-VEHICLE OWNER'
   Y7_583  = 'STOLE MV/LAST TIME-START VEHICLE'
   Y7_584  = 'STOLE MV/LAST TIME-INTENT'
   Y7_585  = 'STOLE MV/LAST TIME-OTH INVOLVE'
   Y7_586  = 'STOLE MV/LAST TIME-DRINK/DRUGS'
   Y7_587  = 'STOLE MV/LAST TIME-1ST ITEM NO.'
   Y7_588  = 'STOLE MV/LAST TIME-2ND ITEM NO.'
   Y7_589  = 'STOLE MV/NEXT LAST-KIND VEHICLE'
   Y7_590  = 'STOLE MV/NEXT LAST-ACTUALLY STEAL'
   Y7_591  = 'STOLE MV/NEXT LAST-VEHICLE OWNER'
   Y7_592  = 'STOLE MV/NEXT LAST-START VEHICLE'
   Y7_593  = 'STOLE MV/NEXT LAST-INTENT'
   Y7_594  = 'STOLE MV/NEXT LAST-OTH INVOLVE'
   Y7_595  = 'STOLE MV/NEXT LAST-DRINK/DRUGS'
   Y7_596  = 'STOLE MV/NEXT LAST-1ST ITEM NO.'
   Y7_597  = 'STOLE MV/NEXT LAST-2ND ITEM NO.'
   Y7_598  = 'STOLE MV/TIME BEF-KIND VEHICLE'
   Y7_599  = 'STOLE MV/TIME BEF-ACTUALLY STEAL'
   Y7_600  = 'STOLE MV/TIME BEF-VEHICLE OWNER'
   Y7_601  = 'STOLE MV/TIME BEF-START VEHICLE'
   Y7_602  = 'STOLE MV/TIME BEF-INTENT'
   Y7_603  = 'STOLE MV/TIME BEF-OTH INVOLVE'
   Y7_604  = 'STOLE MV/TIME BEF-DRINK/DRUGS'
   Y7_605  = 'STOLE MV/TIME BEF-1ST ITEM NO.'
   Y7_606  = 'STOLE MV/TIME BEF-2ND ITEM NO.'
   Y7_607  = 'STOLE LAST TIME-VALUE ($0-$999)'
   Y7_608  = 'STOLE LAST TME-ACTUAL STEAL'
   Y7_609  = 'STOLE LAST TIME-STOLEN FROM'
   Y7_610  = 'STOLE LAST TIME-OTH INVOLVE'
   Y7_611  = 'STOLE LAST TIME-DRINK/DRUGS'
   Y7_612  = 'STOLE LAST TIME-1ST ITEM NO'
   Y7_613  = 'STOLE LAST TIME-2ND ITEM NO'
   Y7_614  = 'STOLE ($0-$999)/NEXT LAST-VALUE'
   Y7_615  = 'STOLE NEXT LST-ACTUAL STEAL'
   Y7_616  = 'STOLE NEXT LAST-STOLEN FROM'
   Y7_617  = 'STOLE NEXT LAST-OTH INVOLVE'
   Y7_618  = 'STOLE NEXT LAST-DRINK/DRUGS'
   Y7_619  = 'STOLE NEXT LAST-1ST ITEM NO'
   Y7_620  = 'STOLE NEXT LAST-2ND ITEM NO'
   Y7_621  = 'STOLE ($0-$999)/TIME BEF-VALUE'
   Y7_622  = 'STOLE TIME BEF-ACTUAL STEAL'
   Y7_623  = 'STOLE TIME BEF-STOLEN FROM'
   Y7_624  = 'STOLE TIME BEF-OTH INVOLVE'
   Y7_625  = 'STOLE TIME BEF-DRINK/DRUGS'
   Y7_626  = 'STOLE TIME BEF-1ST ITEM NO.'
   Y7_627  = 'STOLE TIME BEF-2ND ITEM NO.'
   Y7_628  = 'BOUGHT STOLEN-WHAT DID YOU DO'
   Y7_629  = 'BOUGHT STOLEN-VALUE ($0-$9999)'
   Y7_630  = 'BOUGHT STOLEN-OTH INVOLVE'
   Y7_631  = 'BOUGHT STOLEN-1ST ITEM NO.'
   Y7_632  = 'BOUGHT STOLEN-2ND ITEM NO.'
   Y7_633  = 'SET FIRE TO PROP-ACTUALLY SET'
   Y7_634  = 'SET FIRE TO PROP-OTH INVOLVE'
   Y7_635  = 'SET FIRE TO PROP-DRINK/DRUGS'
   Y7_636  = 'SET FIRE TO PROP-1ST ITEM NO.'
   Y7_637  = 'SET FIRE TO PROP-2ND ITEM NO.'
   Y7_638  = 'CARRIED HIDDEN WEAPON-KIND'
   Y7_639  = 'STOLE-VALUE ($0-$9)'
   Y7_640  = 'STOLE-VALUE ACTUALLY STEAL'
   Y7_641  = 'STOLE OTH INVOLVE'
   Y7_642  = 'STOLE DRINK/DRUGS'
   Y7_643  = 'STOLE ($0-$9)-1ST ITEM NO.'
   Y7_644  = 'STOLE ($0-$9)-2ND ITEM NO.'
   Y7_645  = 'ATTACK/LAST TIME-FORM OF ATTACK'
   Y7_646  = 'ATTACK/LAST TIME-EXTENT INJURY'
   Y7_647  = 'ATTACK/LAST TIME-WAS THE PERSON'
   Y7_648  = 'ATTACK/LAST TIME-OTH INVOLVE'
   Y7_649  = 'ATTACK/LAST TIME-DRINK/DRUGS'
   Y7_650  = 'ATTACK/LAST TIME-1ST ITEM NO.'
   Y7_651  = 'ATTACK/LAST TIME-2ND ITEM NO.'
   Y7_652  = 'ATTACK/NEXT LAST-FORM OF ATTACK'
   Y7_653  = 'ATTACK/NEXT LAST-EXTENT OF INJURY'
   Y7_654  = 'ATTACK/NEXT LAST-WAS THE PERSON'
   Y7_655  = 'ATTACK/NEXT LAST-OTH INVOLVE'
   Y7_656  = 'ATTACK/NEXT LAST-DRINK/DRUGS'
   Y7_657  = 'ATTACK/NEXT LAST-1ST ITEM NO.'
   Y7_658  = 'ATTACK/NEXT LAST-2ND ITEM NO.'
   Y7_659  = 'ATTACK/TIME BEF-FORM OF ATTACK'
   Y7_660  = 'ATTACK/TIME BEF-EXTENT OF INJURY'
   Y7_661  = 'ATTACK/TIME BEF-WAS THE PERSON'
   Y7_662  = 'ATTACK/TIME BEF-OTH INVOLVE'
   Y7_663  = 'ATTACK/TIME BEF-DRINK/DRUGS'
   Y7_664  = 'ATTACK/TIME BEF-1ST ITEM NO.'
   Y7_665  = 'ATTACK/TIME BEF-2ND ITEM NO.'
   Y7_666  = 'GANG FIGHT/LAST-NO. GROUP'
   Y7_667  = 'GANG FIGHT/LAST-NO. OTH GROUP'
   Y7_668  = 'GANG FIGHT/LAST-NATURE OF WEAPON'
   Y7_669  = 'GANG FIGHT/LAST-EXTENT OF INJURY'
   Y7_670  = 'GANG FIGHT/LAST-DRINK/DRUGS'
   Y7_671  = 'GANG FIGHT/LAST-1ST ITEM NO.'
   Y7_672  = 'GANG FIGHT/LAST-2ND ITEM NO.'
   Y7_673  = 'GANG FIGHT/NEXT-NO. GROUP'
   Y7_674  = 'GANG FIGHT/NEXT-NO. OTH GROUP'
   Y7_675  = 'GANG FIGHT/NEXT-NATURE OF WEAPON'
   Y7_676  = 'GANG FIGHT/NEXT-EXTENT OF INJURY'
   Y7_677  = 'GANG FIGHT/NEXT-DRINK/DRUGS'
   Y7_678  = 'GANG FIGHT/NEXT-1ST ITEM NO.'
   Y7_679  = 'GANG FIGHT/NEXT-2ND ITEM NO.'
   Y7_680  = 'GANG FIGHT/BEF-NO. GROUP'
   Y7_681  = 'GANG FIGHT/BEF-NO. OTH GROUP'
   Y7_682  = 'GANG FIGHT/BEF-NATURE OF WEAPONS'
   Y7_683  = 'GANG FIGHT/BEF-EXTENT OF INJURY'
   Y7_684  = 'GANG FIGHT/BEF-DRINK/DRUGS'
   Y7_685  = 'GANG FIGHT/BEF-1ST ITEM NO.'
   Y7_686  = 'GANG FIGHT/BEF-2ND ITEM NO.'
   Y7_687  = 'USE CHECK ILLEGALLY-HOW USED'
   Y7_688  = 'USE CHECK ILLEG-VALUE($0-$999)'
   Y7_689  = 'USE CHECK ILLEGALLY-OTH INVOLVE'
   Y7_690  = 'USE CHECK ILLEGALLY-1ST ITEM NO.'
   Y7_691  = 'USE CHECK ILLEGALLY-2ND ITEM NO.'
   Y7_692  = 'SOLD MARIJUANA-VALUE($0-$99999)'
   Y7_693  = 'SOLD MARIJUANA-AMOUNT(F5.2) OZ'
   Y7_694  = 'SOLD MARIJUANA-OTH INVOLVE'
   Y7_695  = 'SOLD MARIJUANA-1ST ITEM NO.'
   Y7_696  = 'SOLD MARIJUANA-2ND ITEM NO.'
   Y7_697  = 'STOLE F/FAM-WHAT DID YOU STEAL'
   Y7_698  = 'STOLE F/FAM-AMT STOLEN ($0-$999)'
   Y7_699  = 'STOLE F/FAM-VAL OF OTH ($0-$999)'
   Y7_700  = 'STOLE F/FAMILY-PLANNED USE'
   Y7_701  = 'STOLE F/FAMILY-OTH INVOLVE'
   Y7_702  = 'STOLE F/FAMILY-DRINK/DRUGS'
   Y7_703  = 'STOLE F/FAMILY-1ST ITEM NO.'
   Y7_704  = 'STOLE F/FAMILY-2ND ITEM NO.'
   Y7_705  = 'STOLE F/EMPLOY-WHAT DID YOU STEAL'
   Y7_706  = 'STOLE F/EMPL-AMT STOLEN ($0-$999)'
   Y7_707  = 'STOLE F/EMP-VAL OF OTHR ($0-$999)'
   Y7_708  = 'STOLE F/EMPLOY-OTH INVOLVE'
   Y7_709  = 'STOLE F/EMPLOY-DRINK/DRUGS'
   Y7_710  = 'STOLE F/EMPLOY-1ST ITEM NO.'
   Y7_711  = 'STOLE F/EMPLOY-2ND ITEM NO.'
   Y7_712  = 'SEX AGAINST/LAST-OUTCOME ATTEMPT'
   Y7_713  = 'SEX AGAINST/LAST-MEANS FORCE'
   Y7_714  = 'SEX AGAINST/LAST-EXTENT INJURY'
   Y7_715  = 'SEX AGAINST/LAST-OTH INVOLVE'
   Y7_716  = 'SEX AGAINST/LAST-WAS PERSON'
   Y7_717  = 'SEX AGAINST/LAST-DRINK/DRUGS'
   Y7_718  = 'SEX AGAINST/LAST-1ST ITEM NO.'
   Y7_719  = 'SEX AGAINST/LAST-2ND ITEM NO.'
   Y7_720  = 'SEX AGAINST/NEXT-OUTCOME ATTEMPT'
   Y7_721  = 'SEX AGAINST/NEXT-MEANS FORCE'
   Y7_722  = 'SEX AGAINST/NEXT-EXTENT INJURY'
   Y7_723  = 'SEX AGAINST/NEXT-OTH INVOLVE'
   Y7_724  = 'SEX AGAINST/NEXT-WAS PERSON'
   Y7_725  = 'SEX AGAINST/NEXT-DRINK/DRUGS'
   Y7_726  = 'SEX AGAINST/NEXT-1ST ITEM NO.'
   Y7_727  = 'SEX AGAINST/NEXT-2ND ITEM NO.'
   Y7_728  = 'SEX AGAINST/BEF-OUTCOME ATTEMPT'
   Y7_729  = 'SEX AGAINST/BEF-MEANS FORCE'
   Y7_730  = 'SEX AGAINST/BEF-EXTENT INJURY'
   Y7_731  = 'SEX AGAINST/BEF-OTH INVOLVE'
   Y7_732  = 'SEX AGAINST/BEF-WAS THE PERSON'
   Y7_733  = 'SEX AGAINST/BEF-DRINK/DRUGS'
   Y7_734  = 'SEX AGAINST/BEF-1ST ITEM NO.'
   Y7_735  = 'SEX AGAINST/BEF-2ND ITEM NO.'
   Y7_736  = 'HIT PARENTS-OUTCOME ATTEMPT'
   Y7_737  = 'HIT PARENTS-EXTENT INJURY'
   Y7_738  = 'HIT PARENTS-OTH INVOLVE'
   Y7_739  = 'HIT PARENTS-DRINK/DRUGS'
   Y7_740  = 'HIT PARENTS-1ST ITEM NO.'
   Y7_741  = 'HIT PARENTS-2ND ITEM NO.'
   Y7_742  = 'HIT AT WORK-OUTCOME ATTEMPT'
   Y7_743  = 'HIT AT WORK-EXTENT INJURY'
   Y7_744  = 'HIT AT WORK-OTH INVOLVE'
   Y7_745  = 'HIT AT WORK-DRINK/DRUGS'
   Y7_746  = 'HIT AT WORK-1ST ITEM NO.'
   Y7_747  = 'HIT AT WORK-2ND ITEM NO.'
   Y7_748  = 'HIT ELSE-OUTCOME ATTEMPT'
   Y7_749  = 'HIT ELSE-EXTENT INJURY'
   Y7_750  = 'HIT ELSE-OTH INVOLVE'
   Y7_751  = 'HIT ELSE-DRINK/DRUGS'
   Y7_752  = 'HIT ELSE-1ST ITEM NO.'
   Y7_753  = 'HIT ELSE-2ND ITEM NO.'
   Y7_754  = 'SOLD HARD DRUGS-WHAT DRUGS'
   Y7_755  = 'SOLD HARD DRUGS-VALUE'
   Y7_756  = 'SOLD HARD DRUGS-OTH INVOLVE'
   Y7_757  = 'SOLD HARD DRUGS-1ST ITEM NO.'
   Y7_758  = 'SOLD HARD DRUGS-2ND ITEM NO.'
   Y7_759  = 'SOLD WORTHLESS-SOLD TO WHOM'
   Y7_760  = 'SOLD WORTHLESS-REAL VALUE'
   Y7_761  = 'SOLD WORTHLESS-ASKING PRICE'
   Y7_762  = 'SOLD WORTHLESS-OUTCOME O/ATTEMPT'
   Y7_763  = 'SOLD WORTHLESS-OTH INVOLVE'
   Y7_764  = 'SOLD WORTHLESS-1ST ITEM NO.'
   Y7_765  = 'SOLD WORTHLESS-2ND ITEM NO.'
   Y7_766  = 'TAKEN VEHICLE-KIND OF VEHICLE'
   Y7_767  = 'TAKEN VEHICLE-VEHICLE OWNER'
   Y7_768  = 'TAKEN VEHICLE-STARTED VEHICLE'
   Y7_769  = 'TAKEN VEHICLE-OTH INVOLVE'
   Y7_770  = 'TAKEN VEHICLE-DRINK/DRUGS'
   Y7_771  = 'TAKEN VEHICLE-1ST ITEM NO.'
   Y7_772  = 'TAKEN VEHICLE-2ND ITEM NO.'
   Y7_773  = 'FORCE OTHERS/LAST-TYPE FORCE'
   Y7_774  = 'FORCE OTHERS/LAST-NATURE WEAPONS'
   Y7_775  = 'FORCE OTHERS/LAST-PURPOSE'
   Y7_776  = 'FORCE OTHERS/LAST-EXTENT INJURY'
   Y7_777  = 'FORCE OTHERS/LAST-OTH INVOLVE'
   Y7_778  = 'FORCE OTHERS/LAST-DRINK/DRUGS'
   Y7_779  = 'FORCE OTHERS/LAST-1ST ITEM NO.'
   Y7_780  = 'FORCE OTHERS/LAST-2ND ITEM NO.'
   Y7_781  = 'FORCE OTHERS/NEXT-TYPE FORCE'
   Y7_782  = 'FORCE OTHERS/NEXT-NATURE WEAPONS'
   Y7_783  = 'FORCE OTHERS/NEXT-PURPOSE'
   Y7_784  = 'FORCE OTHERS/NEXT-EXTENT INJURY'
   Y7_785  = 'FORCE OTHERS/NEXT-OTH INVOLVE'
   Y7_786  = 'FORCE OTHERS/NEXT-DRINK/DRUGS'
   Y7_787  = 'FORCE OTHERS/NEXT-1ST ITEM NO.'
   Y7_788  = 'FORCE OTHERS/NEXT-2ND ITEM NO.'
   Y7_789  = 'FORCE OTHERS/BEF-TYPE FORCE'
   Y7_790  = 'FORCE OTHERS/BEF-NATURE WEAPONS'
   Y7_791  = 'FORCE OTHERS/BEF-PURPOSE'
   Y7_792  = 'FORCE OTHERS/BEF-EXTENT INJURY'
   Y7_793  = 'FORCE OTHERS/BEF-OTH INVOLVE'
   Y7_794  = 'FORCE OTHERS/BEF-DRINK/DRUGS'
   Y7_795  = 'FORCE OTHERS/BEF-1ST ITEM NO.'
   Y7_796  = 'FORCE OTHERS/BEF-2ND ITEM NO.'
   Y7_797  = 'STOLE $0 TO $99-VALUE'
   Y7_798  = 'STOLE $0 TO $99-STOLEN FROM'
   Y7_799  = 'STOLE $0 TO $99-ACTUALLY STEAL'
   Y7_800  = 'STOLE $0 TO $99-OTH INVOLVE'
   Y7_801  = 'STOLE $0 TO $99-DRINK/DRUGS'
   Y7_802  = 'STOLE $0 TO $99-1ST ITEM NO.'
   Y7_803  = 'STOLE $0 TO $99-2ND ITEM NO.'
   Y7_804  = 'BROKE BLDG/LAST-BROKE INTO WHAT'
   Y7_805  = 'BROKE BLDG/LAST-ACTUAL BREAK IN'
   Y7_806  = 'BROKE BLDG/LAST-REASON'
   Y7_807  = 'BROKE BLDG/LAST-OTH INVOLVE'
   Y7_808  = 'BROKE BLDG/LAST-DRINK/DRUGS'
   Y7_809  = 'BROKE BLDG/LAST-1ST ITEM NO.'
   Y7_810  = 'BROKE BLDG/LAST-2ND ITEM NO.'
   Y7_811  = 'BROKE BLDG/NEXT-BROKE INTO WHAT'
   Y7_812  = 'BROKE BLDG/NEXT-ACTUAL BREAK IN'
   Y7_813  = 'BROKE BLDG/NEXT-REASON'
   Y7_814  = 'BROKE BLDG/NEXT-OTH INVOLVE'
   Y7_815  = 'BROKE BLDG/NEXT-DRINK/DRUGS'
   Y7_816  = 'BROKE BLDG/NEXT-1ST ITEM NO.'
   Y7_817  = 'BROKE BLDG/NEXT-2ND ITEM NO.'
   Y7_818  = 'BROKE BLDG/BEF-BROKE INTO WHAT'
   Y7_819  = 'BROKE BLDG/BEF-ACTUAL BREAK IN'
   Y7_820  = 'BROKE BLDG/BEF-REASON'
   Y7_821  = 'BROKE BLDG/BEF-OTH INVOLVE'
   Y7_822  = 'BROKE BLDG/BEF-DRINK/DRUGS'
   Y7_823  = 'BROKE BLDG/BEF-1ST ITEM NO.'
   Y7_824  = 'BROKE BLDG/BEF-2ND ITEM NO.'
   Y7_825  = 'CREDIT W/O PERMISSION-WHOSE CARD'
   Y7_826  = 'CREDIT W/O PERMIS-$0-$999 CHARGED'
   Y7_827  = 'CREDIT W/O PERMISSION-OTH INVOLVE'
   Y7_828  = 'CREDIT W/O PERMISSION-1ST ITEM NO'
   Y7_829  = 'CREDIT W/O PERMISSION-2ND ITEM NO'
   Y7_830  = 'PICKED POCKET-WHAT DID YOU DO'
   Y7_831  = 'PICKED POCKET-MONEY TAKEN'
   Y7_832  = 'PICKED POCKET-CREDIT CARDS TAKEN'
   Y7_833  = 'PICKED POCKET-CHECKS TAKEN'
   Y7_834  = 'PICKED POCKET-OTHER TAKEN'
   Y7_835  = 'PICKED POCKET-OTH INVOLVE'
   Y7_836  = 'PICKED POCKET-DRINK/DRUGS'
   Y7_837  = 'PICKED POCKET-1ST ITEM NO.'
   Y7_838  = 'PICKED POCKET-2ND ITEM NO.'
   Y7_839  = 'EMBEZZ MONEY/FNDS-($0-$999)VALUE'
   Y7_840  = 'EMBEZZLED MONEY/FUNDS-1ST ITEM NO'
   Y7_841  = 'EMBEZZLED MONEY/FUNDS-2ND ITEM NO'
   Y7_842  = 'ALCOHOLIC BEVERAGES-FREQ'
   Y7_843  = 'ALCOHOLIC BEVERAGES-RATE'
   Y7_844  = 'ALCOHOLIC BEVERAGES-EPISODIC'
   Y7_845  = 'TOBACCO-USED TOBACCO'
   Y7_846  = 'TOBACCO-EPISODIC'
   Y7_847  = 'TOBACCO-# CIGS PER DAY'
   Y7_848  = 'TOBACCO-# CIGARS/PIPES PER DAY'
   Y7_849  = 'TOBACCO-CANS CHEW TOBACCO/MO'
   Y7_850  = 'MARIJUANA-FREQ'
   Y7_851  = 'MARIJUANA-RATE'
   Y7_852  = 'MARIJUANA-EPISODIC'
   Y7_853  = 'HALLUCINOGENS-FREQ'
   Y7_854  = 'HALLUCINOGENS-RATE'
   Y7_855  = 'HALLUCINOGENS-EPISODIC'
   Y7_856  = 'TRANQUILIZERS-FREQ'
   Y7_857  = 'TRANQUILIZERS-RATE'
   Y7_858  = 'TRANQUILIZERS-EPISODIC'
   Y7_859  = 'AMPHETAMINES-DR PERSCRIBED'
   Y7_860  = 'AMPHETAMINES-FREQ'
   Y7_861  = 'AMPHETAMINES-RATE'
   Y7_862  = 'AMPHETAMINES-EPISODIC'
   Y7_863  = 'BARBITURATES-DR PERSCRIBED'
   Y7_864  = 'BARBITURATES-FREQ'
   Y7_865  = 'BARBITURATES-RATE'
   Y7_866  = 'BARBITURATES-EPISODIC'
   Y7_867  = 'CODEINE-DR PERSCRIBED'
   Y7_868  = 'CODEINE-FREQ'
   Y7_869  = 'CODEINE-RATE'
   Y7_870  = 'CODEINE-EPISODIC'
   Y7_871  = 'HEROIN-DR PERSCRIBED'
   Y7_872  = 'HEROIN-FREQ'
   Y7_873  = 'HEROIN-RATE'
   Y7_874  = 'HEROIN-EPISODIC'
   Y7_875  = 'CRACK-FREQ'
   Y7_876  = 'CRACK-RATE'
   Y7_877  = 'CRACK-EPISODIC'
   Y7_878  = 'COCAINE-FREQ'
   Y7_879  = 'COCAINE-RATE'
   Y7_880  = 'COCAINE-EPISODIC'
   Y7_881  = 'INHALANTS-FREQ'
   Y7_882  = 'INHALANTS-RATE'
   Y7_883  = 'INHALANTS-EPISODIC'
   Y7_884  = 'ANGEL DUST-FREQ'
   Y7_885  = 'ANGEL DUST-RATE'
   Y7_886  = 'ANGEL DUST-EPISODIC'
   Y7_887  = 'DRUGS-SSMPLSTANCE'
   Y7_888  = 'OTHER DRUGS-FREQ'
   Y7_889  = 'OTHER DRUGS-RATE'
   Y7_890  = 'OTHER DRUGS-EPISODIC'
   Y7_891  = 'DRUGS EXCEED DR RX-FREQ'
   Y7_892  = 'DRUGS EXCEED DR RX-RATE'
   Y7_893  = 'DRUGS EXCEED DR RX-EPISODIC'
   Y7_894  = 'INJECT ILLICIT DRUG'
   Y7_895  = 'SHARE UNSTERILIZED NEEDLE'
   Y7_896  = 'TROUBLE W/GIRL/BOYFRIEND-ALCOHOL'
   Y7_897  = 'TROUBLE W/GIRL/BOYFRIEND-MARIJ'
   Y7_898  = 'TROUBLE W/GIRL/BOYFRIEND-DRUGS'
   Y7_899  = 'TROUBLE W/FRIENDS-ALCOHOL'
   Y7_900  = 'TROUBLE W/FRIENDS-MARIJUANA'
   Y7_901  = 'TROUBLE W/FRIENDS-DRUGS'
   Y7_902  = 'PROBLEMS W/FAMILY-ALCOHOL'
   Y7_903  = 'PROBLEMS W/FAMILY-MARIJUANA'
   Y7_904  = 'PROBLEMS W/FAMILY-DRUGS'
   Y7_905  = 'GOTTEN INTO FIGHTS-ALCOHOL'
   Y7_906  = 'GOTTEN INTO FIGHTS-MARIJUANA'
   Y7_907  = 'GOTTEN INTO FIGHTS-DRUGS'
   Y7_908  = 'PROBS W/PHYS HEALTH-ALCOHOL'
   Y7_909  = 'PROBS W/PHYS HEALTH-MARIJUANA'
   Y7_910  = 'PROBS W/PHYS HEALTH-DRUGS'
   Y7_911  = 'TROUBLE W/POLICE-ALCOHOL'
   Y7_912  = 'TROUBLE W/POLICE-MARIJUANA'
   Y7_913  = 'TROUBLE W/POLICE-DRUGS'
   Y7_914  = 'ACCIDENTS WHILE DRIVE-ALCOHOL'
   Y7_915  = 'ACCIDENTS WHILE DRIVE-MARIJUANA'
   Y7_916  = 'ACCIDENTS WHILE DRIVE-DRUGS'
   Y7_917  = 'CALLED IN SICK WORK-ALCOHOL'
   Y7_918  = 'CALLED IN SICK WORK-MARIJUANA'
   Y7_919  = 'CALLED IN SICK WORK-DRUGS'
   Y7_920  = 'DONE ILLEGAL-ALCOHOL'
   Y7_921  = 'DONE ILLEGAL-MARIJUANA'
   Y7_922  = 'DONE ILLEGAL-DRUGS'
   Y7_923  = 'STEAL SOMETHING'
   Y7_924  = 'PROSTITUTION'
   Y7_925  = 'GAMBLE'
   Y7_926  = 'SELL DRUGS OR ALCOHOL'
   Y7_927  = 'SELL THINGS NOT YOURS'
   Y7_928  = 'BEAT SOMEONE UP'
   Y7_929  = 'BOUGHT ALCOHOL WHILE UNDERAGE'
   Y7_930  = 'USE FAKE ID'
   Y7_931  = 'STEAL ALCOHOL OR DRUGS'
   Y7_932  = 'FAKE PRESCRIPTION'
   Y7_933  = 'FAKE ILLNESS'
   Y7_934  = 'OTHER'
   Y7_935  = 'DRUNK ON ALCOHOL PAST YEAR'
   Y7_936  = 'DRUNK WHILE DRIVING'
   Y7_937  = 'DRUNK WHILE AT WORK'
   Y7_938  = 'HIGH ON MARIJUANA PAST YEAR'
   Y7_939  = 'HIGH ON MARIJUANA WHILE DRIVING'
   Y7_940  = 'HIGH ON MARIJUANA WHILE AT WORK'
   Y7_941  = 'HIGH ON OTHER DRUGS PAST YEAR'
   Y7_942  = 'HIGH ON OTHER DRUGS WHILE DRIVING'
   Y7_943  = 'HIGH ON OTHER DRUGS WHILE AT WORK'
   Y7_944  = 'STOLEN M VEH-IN LIFETIME'
   Y7_945  = 'STOLEN M VEH-AGE 1ST TIME'
   Y7_946  = 'STOLEN VALUED > $50-IN LIFETIME'
   Y7_947  = 'STOLEN VALUED > $50-AGE 1ST TIME'
   Y7_948  = 'SET FIRE TO PROPERTY-IN LIFETIME'
   Y7_949  = 'SET FIRE TO PROPERTY-AGE 1ST TIME'
   Y7_950  = 'ATTACKED SOMEONE-IN LIFETIME'
   Y7_951  = 'ATTACKED SOMEONE-AGE 1ST TIME'
   Y7_952  = 'BEEN IN GANG FIGHTS-IN LIFETIME'
   Y7_953  = 'BEEN IN GANG FIGHTS-AGE 1ST TIME'
   Y7_954  = 'SEX REL AGAINST WILL-IN LIFETIME'
   Y7_955  = 'SEX REL AGAINST WILL-AGE 1ST TIME'
   Y7_956  = 'BROKEN INTO BUILDING-IN LIFETIME'
   Y7_957  = 'BROKEN INTO BUILDING-AGE 1ST TIME'
   Y7_958  = 'USED FORCE ON OTHERS-IN LIFETIME'
   Y7_959  = 'USED FORCE ON OTHERS-AGE 1ST TIME'
   Y7_960  = 'PHYS HURT OTH FOR SEX-IN LIFETIME'
   Y7_961  = 'PHYS HRT OTH FOR SEX-AGE 1ST TIME'
   Y7_962  = 'SOLD HARD DRUGS-IN LIFETIME'
   Y7_963  = 'SOLD HARD DRUGS-AGE 1ST TIME'
   Y7_964  = 'INJURED SPOUSE/PARTN-IN LIFETIME'
   Y7_965  = 'INJURED SPOUSE/PARTN-AGE 1ST TIME'
   Y7_966  = 'STOLEN MOTOR VEHICLE-1984'
   Y7_967  = 'STOLEN MOTOR VEHICLE-1985'
   Y7_968  = 'STOLEN VALUED > $50-1984'
   Y7_969  = 'STOLEN VALUED > $50-1985'
   Y7_970  = 'BOUGHT STOLEN GOODS-1984'
   Y7_971  = 'BOUGHT STOLEN GOODS-1985'
   Y7_972  = 'SET FIRE TO PROPERTY-1984'
   Y7_973  = 'SET FIRE TO PROPERTY-1985'
   Y7_974  = 'CARRIED A HIDDEN WEAPON-1984'
   Y7_975  = 'CARRIED A HIDDEN WEAPON-1985'
   Y7_976  = 'STOLEN SOMETHING < $5-1984'
   Y7_977  = 'STOLEN SOMETHING < $5-1985'
   Y7_978  = 'ATTACK SOMEONE-1984'
   Y7_979  = 'ATTACK SOMEONE-1985'
   Y7_980  = 'BEEN PAID FOR SEX RELATIONS-1984'
   Y7_981  = 'BEEN PAID FOR SEX RELATIONS-1985'
   Y7_982  = 'PAY FOR SEX RELATIONS-1984'
   Y7_983  = 'PAY FOR SEX RELATIONS-1985'
   Y7_984  = 'BEEN IN GANG FIGHTS-1984'
   Y7_985  = 'BEEN IN GANG FIGHTS-1985'
   Y7_986  = 'USED CHECKS ILLEGALLY-1984'
   Y7_987  = 'USED CHECKS ILLEGALLY-1985'
   Y7_988  = 'SOLD MARIJUANA-1984'
   Y7_989  = 'SOLD MARIJUANA-1985'
   Y7_990  = 'SEX RELATIONS AGAINST WILL-1984'
   Y7_991  = 'SEX RELATIONS AGAINST WILL-1985'
   Y7_992  = 'HIT PARENT-1984'
   Y7_993  = 'HIT PARENT-1985'
   Y7_994  = 'HIT SOMEONE AT WORK-1984'
   Y7_995  = 'HIT SOMEONE AT WORK-1985'
   Y7_996  = 'HIT ANYONE ELSE-1984'
   Y7_997  = 'HIT ANYONE ELSE-1985'
   Y7_998  = 'SOLD HARD DRUGS-1984'
   Y7_999  = 'SOLD HARD DRUGS-1985'
   Y7_1000 = 'TRIED SELL WORTHLESS-1984'
   Y7_1001 = 'TRIED SELL WORTHLESS-1985'
   Y7_1002 = 'TAKEN VEHICLE-1984'
   Y7_1003 = 'TAKEN VEHICLE-1985'
   Y7_1004 = 'USED FORCE ON ANYONE-1984'
   Y7_1005 = 'USED FORCE ON ANYONE-1985'
   Y7_1006 = 'STOLEN THINGS $5 TO $50-1984'
   Y7_1007 = 'STOLEN THINGS $5 TO $50-1985'
   Y7_1008 = 'BROKEN INTO BUILDING-1984'
   Y7_1009 = 'BROKEN INTO BUILDING-1985'
   Y7_1010 = 'CR CDS W/OUT PERMISSION-1984'
   Y7_1011 = 'CR CDS W/OUT PERMISSION-1985'
   Y7_1012 = 'PICKED SOMEONE''S POCKET-1984'
   Y7_1013 = 'PICKED SOMEONE''S POCKET-1985'
   Y7_1014 = 'EMBEZZLED MONEY/FUNDS-1984'
   Y7_1015 = 'EMBEZZLED MONEY/FUNDS-1985'
   Y7_1016 = 'USED ALCOHOLIC BEVERAGES-1984'
   Y7_1017 = 'USED ALCOHOLIC BEVERAGES-1985'
   Y7_1018 = 'USED MARIJUANA-1984'
   Y7_1019 = 'USED MARIJUANA-1985'
   Y7_1020 = 'USED HALLUCINOGENS-1984'
   Y7_1021 = 'USED HALLUCINOGENS-1985'
   Y7_1022 = 'USED TRANQUILIZERS-1984'
   Y7_1023 = 'USED TRANQUILIZERS-1985'
   Y7_1024 = 'USED AMPHETAMINES-1984'
   Y7_1025 = 'USED AMPHETAMINES-1985'
   Y7_1026 = 'USED BARBITURATES-1984'
   Y7_1027 = 'USED BARBITURATES-1985'
   Y7_1028 = 'USED COCAINE-1984'
   Y7_1029 = 'USED COCAINE-1985'
   Y7_1030 = 'EVER ARRESTED'
   Y7_1031 = 'ARRESTS MOST RECENT-MONTH'
   Y7_1032 = 'ARRESTS MOST RECENT-YEAR'
   Y7_1033 = 'ARST MOST RECENT-1ST THING DOING'
   Y7_1034 = 'ARST MOST RECENT-2ND THING DOING'
   Y7_1035 = 'ARST MOST RECENT-3RD THING DOING'
   Y7_1036 = 'ARRESTS MOST RECENT-1ST CHARGE'
   Y7_1037 = 'ARRESTS MOST RECENT-2ND CHARGE'
   Y7_1038 = 'ARRESTS MOST RECENT-3RD CHARGE'
   Y7_1039 = 'ARSTS MOST RECENT-DO POL CHARGE'
   Y7_1040 = 'ARRESTS 1ST BEFORE-MONTH'
   Y7_1041 = 'ARRESTS 1ST BEFORE-YEAR'
   Y7_1042 = 'ARST 1ST BEFORE-1ST THING DOING'
   Y7_1043 = 'ARST 1ST BEFORE-2ND THING DOING'
   Y7_1044 = 'ARST 1ST BEFORE-3RD THING DOING'
   Y7_1045 = 'ARRESTS 1ST BEFORE-1ST CHARGE'
   Y7_1046 = 'ARRESTS 1ST BEFORE-2ND CHARGE'
   Y7_1047 = 'ARRESTS 1ST BEFORE-3RD CHARGE'
   Y7_1048 = 'ARSTS 1ST BEFORE-DO POL CHARGE'
   Y7_1049 = 'ARRESTS 2ND BEFORE-MONTH'
   Y7_1050 = 'ARRESTS 2ND BEFORE-YEAR'
   Y7_1051 = 'ARRESTS 2ND BEFORE-1ST THING'
   Y7_1052 = 'ARRESTS 2ND BEFORE-2ND THING'
   Y7_1053 = 'ARRESTS 2ND BEFORE-3RD THING'
   Y7_1054 = 'ARRESTS 2ND BEFORE-1ST CHARGE'
   Y7_1055 = 'ARRESTS 2ND BEFORE-2ND CHARGE'
   Y7_1056 = 'ARRESTS 2ND BEFORE-3RD CHARGE'
   Y7_1057 = 'ARRESTS 2ND BEFORE-DO POL CHARGE'
   Y7_1058 = 'SINCE JAN 1984-EVER QUEST BY POL'
   Y7_1059 = 'POLICE Q. MOST RECENT-MO'
   Y7_1060 = 'POLICE Q. MOST RECENT-YR'
   Y7_1061 = 'POL Q. MOST RECENT-ABOUT WHAT'
   Y7_1062 = 'POL Q. MOST RECENT-COMM ANY OFF'
   Y7_1063 = 'POL Q. MOST RECENT-WHAT DO'
   Y7_1064 = 'POL Q. MOST RECENT-WHAT POL DO'
   Y7_1065 = 'POL Q. 2ND MOST RECENT Q.-MO'
   Y7_1066 = 'POL Q. 2ND MOST RECENT Q.-YR'
   Y7_1067 = 'POL Q. 2ND MOST RECENT Q-ABOUT'
   Y7_1068 = 'POL Q 2ND MOST RECENT Q-COMM OFF'
   Y7_1069 = 'POL Q 2ND MOST RECENT Q.-WHAT DO'
   Y7_1070 = '2ND MOST RECENT Q.-WHAT POL DO'
   Y7_1071 = 'POL Q. 3RD MOST RECENT Q.-MO'
   Y7_1072 = 'POL Q. 3RD MOST RECENT Q.-YR'
   Y7_1073 = 'POL Q 3RD MOST RECENT Q-ABOUT'
   Y7_1074 = 'POL Q 3RD MOST RECENT Q-COMM OFF'
   Y7_1075 = 'POL Q 3RD MOST RECENT Q-WHAT DO'
   Y7_1076 = '3RD MOST RECENT Q.-WHAT POL DO'
   Y7_1077 = 'WHAT COURT FOR CRIME'
   Y7_1078 = 'AGE AT 1ST COURT APPEAR'
   Y7_1079 = 'TIMES CONVICTED'
   Y7_1080 = 'CHARGE 1ST CONVICTION'
   Y7_1081 = 'CHARGE 2ND CONVICTION'
   Y7_1082 = 'CHARGE 3RD CONVICTION'
   Y7_1083 = 'EVER SERVE TIME FOR OFF'
   Y7_1084 = 'TIME IN DETEN CTR, 1ST-NO. DAYS'
   Y7_1085 = 'TIME IN DETEN CTR, 1ST-YR BEGUN'
   Y7_1086 = 'TIME SRVD TRAIN SCH, 1ST-NO DAYS'
   Y7_1087 = 'TIME SRVD TRAIN SCH 1ST-YR BEGUN'
   Y7_1088 = 'TIME SERVED JAIL, 1ST-NO. DAYS'
   Y7_1089 = 'TIME SERVED JAIL, 1ST-YR BEGUN'
   Y7_1090 = 'TIME SERVED PRISON, 1ST-NO. DAYS'
   Y7_1091 = 'TIME SERVED PRISON, 1ST-YR BEGUN'
   Y7_1092 = 'CHANCE ARR-EXCD LIMIT 10-20 MPH'
   Y7_1093 = 'CHANCE ARR-STEAL < $5'
   Y7_1094 = 'CHANCE ARR-STEAL > $50'
   Y7_1095 = 'CHANCE ARR-BREAK INTO BUILDING'
   Y7_1096 = 'CHANCE ARR-STRONGARM OTHERS'
   Y7_1097 = 'CHANCE ARR-ATTACK SOMEONE'
   Y7_1098 = 'CHANCE ARR-DELIB INJ SP/PARTN'
   Y7_1099 = 'PUNISHMENT-EXCD LIMIT 10-20 MPH'
   Y7_1100 = 'PUNISHMENT-STEAL < $5'
   Y7_1101 = 'PUNISHMENT-STEAL > $50'
   Y7_1102 = 'PUNISHMENT-BREAK INTO BUILDING'
   Y7_1103 = 'PUNISHMENT-STRONGARM OTHERS'
   Y7_1104 = 'PUNISHMENT-ATTACK SOMEONE'
   Y7_1105 = 'GUILT-EXCEED LIMIT 10-20 MPH'
   Y7_1106 = 'GUILT-STEAL SOMETHING < $5'
   Y7_1107 = 'GUILT-STEAL SOMETHING > $50'
   Y7_1108 = 'GUILT-BREAK INTO BUILDING'
   Y7_1109 = 'GUILT-STRONGARM OTHERS'
   Y7_1110 = 'GUILT-ATTACK SOMEONE'
   Y7_1111 = 'GUILT-EXCD LIMIT 10-20 MPH HELP'
   Y7_1112 = 'GUILT-STEAL < $5 STORE OVERCHRGE'
   Y7_1113 = 'GUILT-STEAL > $50 COVER INSURNCE'
   Y7_1114 = 'GUILT-BREAK INTO BLDG OWN CROOK'
   Y7_1115 = 'GUILT-STRONGARM TO GET CAN''T PAY'
   Y7_1116 = 'GUILT-ATTACK BECAUSE OF ARGUMENT'
   Y7_1117 = 'THINGS TAKEN FROM YOU'
   Y7_1118 = 'BEATEN UP BY PARENT'
   Y7_1119 = 'BEATEN BY PARENT-FORCED SEX'
   Y7_1120 = 'PAR/FORCED SEX-THREAT/INJ WEAPON'
   Y7_1121 = 'PAR/FORCED SEX-SERIOUSLY INJURED'
   Y7_1122 = 'PAR/FORCED SEX-FORCED SEX REL'
   Y7_1123 = 'THREAT/BEATEN UP BY OTHERS'
   Y7_1124 = 'BEATEN UP BY OTHS-NO. TIMES'
   Y7_1125 = 'BEATEN UP BY OTHS-BROTHER'
   Y7_1126 = 'BEATEN UP BY OTHS-SISTER'
   Y7_1127 = 'BEATEN UP BY OTHS-TEACHER'
   Y7_1128 = 'BEATEN UP BY OTHS-SPOUSE'
   Y7_1129 = 'BEATEN UP BY OTHS-STUDENT'
   Y7_1130 = 'BEATEN UP BY OTHS-GANG'
   Y7_1131 = 'BEATEN UP BY OTHS-OTHER ADULT'
   Y7_1132 = 'BEATEN UP BY OTHS-BOY/GIRLFRIEND'
   Y7_1133 = 'BEATEN UP BY OTHS-OTHER YOUTH'
   Y7_1134 = 'BEATEN UP BY OTHS-OTHER'
   Y7_1135 = 'BEATEN UP BY OTHERS-FORCED SEX'
   Y7_1136 = 'BEAT OTHS/FOR SEX-THRT/INJ WEAP'
   Y7_1137 = 'BEAT OTHS/FORCE SEX-SERIOUS INJ'
   Y7_1138 = 'BEAT OTHS/FORCE SEX-FORCED SEX'
   Y7_1139 = 'ATTACKED W/WEAPON'
   Y7_1140 = 'ATTACK W/WEAPON-BROTHER'
   Y7_1141 = 'ATTACK W/WEAPON-SISTER'
   Y7_1142 = 'ATTACK W/WEAPON-TEACHER'
   Y7_1143 = 'ATTACK W/WEAPON-SPOUSE'
   Y7_1144 = 'ATTACK W/WEAPON-STUDENT'
   Y7_1145 = 'ATTACK W/WEAPON-GANG'
   Y7_1146 = 'ATTACK W/WEAPON-OTHER ADULT'
   Y7_1147 = 'ATTACK W/WEAPON-BOY/GIRLFRIEND'
   Y7_1148 = 'ATTACK W/WEAPON-OTHER YOUTH'
   Y7_1149 = 'ATTACK W/WEAPON-OTHER'
   Y7_1150 = 'ATTACK W/WEAPON-FORCED SEX'
   Y7_1151 = 'ATTACK/FORCE SEX-THREAT/INJ WEAP'
   Y7_1152 = 'ATTACK/FORCE SEX-SERIOUS INJURY'
   Y7_1153 = 'ATTACK/FORCE SEX-FORCED SEX'
   Y7_1154 = 'MOTOR VEHICLE OR BIKE STOLEN'
   Y7_1155 = 'THINGS TAKEN FROM CAR'
   Y7_1156 = 'SEXUALLY ATTACKED'
   Y7_1157 = 'SEXUALLY ATTACKED-BROTHER'
   Y7_1158 = 'SEXUALLY ATTACKED-SISTER'
   Y7_1159 = 'SEXUALLY ATTACKED-TEACHER'
   Y7_1160 = 'SEXUALLY ATTACKED-SPOUSE'
   Y7_1161 = 'SEXUALLY ATTACKED-STUDENT'
   Y7_1162 = 'SEXUALLY ATTACKED-GANG'
   Y7_1163 = 'SEXUALLY ATTACKED-OTHER ADULT'
   Y7_1164 = 'SEXUALLY ATTACKED-BOY/GIRLFRIEND'
   Y7_1165 = 'SEXUALLY ATTACKED-OTHER YOUTH'
   Y7_1166 = 'SEXUALLY ATTACKED-OTHER'
   Y7_1167 = 'SEX ATTACK-THREAT/INJURED WEAPON'
   Y7_1168 = 'SEX ATTACK-SERIOUSLY INJURED'
   Y7_1169 = 'SEX ATTACK-FORCED SEX'
   Y7_1170 = 'THINGS DAMAGED'
   Y7_1171 = 'THINGS STOLEN FROM PUBLIC PLACE'
   Y7_1172 = 'SEXUALLY PRESSURED'
   Y7_1173 = 'SEX PRESSURE-THREAT/INJ WEAPON'
   Y7_1174 = 'SEX PRESSURE-SERIOUSLY INJURED'
   Y7_1175 = 'SEX PRESSURE-FORCED SEX'
   Y7_1176 = 'POCKET PICKED'
   Y7_1177 = 'SEX ASSAULT-MORE THAN 1 BOX ITEM'
   Y7_1178 = 'SEX ASSAULTS-NO. NONREDUNDANT'
   Y7_1179 = 'SEX ASSAULT-ITEM NO. MOST RECENT'
   Y7_1180 = 'WHAT IS YOUR CURRENT WEIGHT'
   Y7_1181 = 'WHAT IS YOUR HEIGHT'
   Y7_1182 = 'EAT WELL BALANCED MEALS'
   Y7_1183 = 'EAT FRESH VEG AND FRUIT'
   Y7_1184 = 'EAT TOO MUCH JUNK FOOD'
   Y7_1185 = 'EAT JUNK FOOD INSTEAD OF MEALS'
   Y7_1186 = 'TAKE DAILY VITAMIN SUPPLM'
   Y7_1187 = 'EXERCISE ON A REGULAR BASIS'
   Y7_1188 = 'PHYS PROBLEMS RESTRICT ACTIVITY'
   Y7_1189 = '1ST PHYSICAL PROBLEM'
   Y7_1190 = '2ND PHYSICAL PROBLEM'
   Y7_1191 = '3RD PHYSICAL PROBLEM'
   Y7_1192 = '4TH PHYSICAL PROBLEM'
   Y7_1193 = 'EVER HAD A VENERAL DISEASE'
   Y7_1194 = 'IF YES-WHAT TYPE OF V.D.'
   Y7_1195 = 'PROBLEMS BECAUSE OF V.D.'
   Y7_1197 = 'TESTED FOR AIDS'
   Y7_1198 = 'TEST FOR AIDS-RESULTS'
   Y7_1199 = 'GENERAL PHYSICAL HEALTH'
   Y7_1200 = 'AGE AT 1ST PERIOD'
   Y7_1201 = 'PREGNANT IN 1984,1985, 0R 1986'
   Y7_1202 = 'PREGNANCY 1ST-YEAR'
   Y7_1203 = 'PREGNANCY 1ST-OUTCOME'
   Y7_1204 = 'PREGNANCY 1ST-1ST PROBLEM'
   Y7_1205 = 'PREGNANCY 1ST-2ND PROBLEM'
   Y7_1206 = 'PREGNANCY 1ST-VOLUNTARY ABORTION'
   Y7_1207 = 'PREGNANCY 2ND-YEAR'
   Y7_1208 = 'PREGNANCY 2ND-OUTCOME'
   Y7_1209 = 'PREGNANCY 2ND-1ST PROBLEM'
   Y7_1210 = 'PREGNANCY 2ND-2ND PROBLEM'
   Y7_1211 = 'PREGNANCY 2ND-VOLUNTARY ABORTION'
   Y7_1212 = 'PREGNANCY 3RD-YEAR'
   Y7_1213 = 'PREGNANCY 3RD-OUTCOME'
   Y7_1214 = 'PREGNANCY 3RD-1ST PROBLEM'
   Y7_1215 = 'PREGNANCY 3RD-2ND PROBLEM'
   Y7_1216 = 'PREGNANCY 3RD-VOLUNTARY ABORTION'
   Y7_1217 = 'EFFECTS FROM 1ST EVENT'
   Y7_1218 = 'EFFECTS 1ST EVENT-1ST EFFECT'
   Y7_1219 = 'EFFECTS 1ST EVENT-2ND EFFECT'
   Y7_1220 = 'EFFECTS 1ST EVENT-3RD EFFECT'
   Y7_1221 = 'EFFECTS FROM 2ND EVENT'
   Y7_1222 = 'EFFECTS F/2ND EVENT-1ST EFFECT'
   Y7_1223 = 'EFFECTS F/2ND EVENT-2ND EFFECT'
   Y7_1224 = 'EFFECTS F/2ND EVENT-3RD EFFECT'
   Y7_1225 = 'EFFECTS AT PRESENT FROM EVENTS'
   Y7_1226 = 'PRES EFFECTS FROM EVENTS-1ST EFF'
   Y7_1227 = 'PRES EFFECTS FROM EVENTS-2ND EFF'
   Y7_1228 = 'PRES EFFECTS FROM EVENTS-3RD EFF'
   Y7_1229 = 'DEPRESS > 2 WKS -1984,1985,1986'
   Y7_1230 = 'DEPRESSION-LOSS OF APPETITE'
   Y7_1231 = 'DEPRESSION-LOSS OF WEIGHT'
   Y7_1232 = 'DEPRESSION-WEIGHT GAIN'
   Y7_1233 = 'DEPRESSION-APPETITE SUMMARY'
   Y7_1234 = 'DEPRESSION-INSOMNIA'
   Y7_1235 = 'DEPRESSION-SLEEP TOO MUCH'
   Y7_1236 = 'DEPRESSION-SLEEP SUMMARY'
   Y7_1237 = 'DEPRESSION-TIRED ALL THE TIME'
   Y7_1238 = 'DEPRESSION-TIRED SUMMARY'
   Y7_1239 = 'DEPRESSION-TALK/MOVE SLOWER'
   Y7_1240 = 'DEPRESSION-UNABLE TO BE STILL'
   Y7_1241 = 'DEPRESSION-SLOW/RESTLESS SUMMARY'
   Y7_1242 = 'DEPRESSION-LOST INTEREST IN SEX'
   Y7_1243 = 'DEPRESSION-LOST INTEREST SUMMARY'
   Y7_1244 = 'DEPRESSION-TROUBLE CONCENTRATING'
   Y7_1245 = 'DEPRESSION-THOUGHTS SLOW/MIX UP'
   Y7_1246 = 'DEPRESSION-TROUBLE THINK SUMMARY'
   Y7_1247 = 'DEPRESSION-FELT WORTHLESS/GUILTY'
   Y7_1248 = 'DEPRESSION-WORTHLESS SUMMARY'
   Y7_1249 = 'DEPRESSION-THOUGHT DEATH GENERAL'
   Y7_1250 = 'DEPRESSION-WANTED TO DIE'
   Y7_1251 = 'DEPRESSION-THOUGHT OF SUICIDE'
   Y7_1252 = 'DEPRESSION-ATTEMPTED SUICIDE'
   Y7_1253 = 'DEPRESSION-THOUGHT DEATH SUMMARY'
   Y7_1254 = 'FLAG FOR DEPRESSION'
   Y7_1255 = 'DEPRESS OTH PROBS OCCUR TOGETHER'
   Y7_1256 = 'NOT BLUE PLUS OTHER SYMPTOMS'
   Y7_1257 = 'LONG TIME DEPRESS/OTH SYMP-YRS'
   Y7_1258 = 'LONG TIME DEPRESS/OTH SYMP-MOS'
   Y7_1259 = 'LONG TIME DEPRESS/OTH SYMP-WKS'
   Y7_1260 = 'LONG TIME DEPRESS/OTH SYMP-DYS'
   Y7_1261 = 'NO. EPISODE DEPRESS/OTH SYMPTOMS'
   Y7_1262 = 'SEE DOCTOR ABOUT ANY EPISODES'
   Y7_1263 = 'SEE PROFESSIONAL ABOUT EPISODES'
   Y7_1264 = 'MEDICINE > ONCE FOR FOR EPISODES'
   Y7_1265 = 'EPISODES INTERFERE W/LIFE'
   Y7_1266 = 'EPISODE OCCR AFT DEATH LOVED ONE'
   Y7_1267 = 'ANY EPISODE NOT ASSOC W/DEATH'
   Y7_1268 = 'DEPRESSED PLUS OTHER SYMPTOM NOW'
   Y7_1269 = 'WHEN LAST SUCH EPISODE ENDED'
   Y7_1270 = 'HOW OLD THEN'
   Y7_1271 = 'SEEING PROFESSIONAL FOR EPISODE'
   Y7_1272 = 'UNUSABLE CODE'
   Y7_1273 = 'HELP TO FRIEND/RELATIVE-FREQ'
   Y7_1274 = 'HELP TO FRIEND/RELATIVE-1ST PROB'
   Y7_1275 = 'HELP TO FRIEND/RELATIVE-2ND PROB'
   Y7_1276 = 'HELP TO FRIEND/RELATIVE-3RD PROB'
   Y7_1277 = 'HELP TO FRIEND/RELATIVE-AMT HELP'
   Y7_1278 = 'HELP MINISTER/RABBI-FREQ'
   Y7_1279 = 'HELP MINISTER/RABBI-1ST PROB'
   Y7_1280 = 'HELP MINISTER/RABBI-2ND PROB'
   Y7_1281 = 'HELP MINISTER/RABBI-3RD PROB'
   Y7_1282 = 'HELP MINISTER/RABBI-AMOUNT HELP'
   Y7_1283 = 'HELP PYSCH/COUNSEL-FREQ'
   Y7_1284 = 'HELP PYSCH/COUNSEL-1ST PROB'
   Y7_1285 = 'HELP PYSCH/COUNSEL-2ND PROB'
   Y7_1286 = 'HELP PYSCH/COUNSEL-3RD PROB'
   Y7_1287 = 'HELP PYSCH/COUNSEL-AMOUNT HELP'
   Y7_1288 = 'HELP MEDICAL DR-FREQ'
   Y7_1289 = 'HELP MEDICAL DR-1ST PROB'
   Y7_1290 = 'HELP MEDICAL DR-2ND PROB'
   Y7_1291 = 'HELP MEDICAL DR-3RD PROB'
   Y7_1292 = 'HELP MEDICAL DR-AMOUNT HELP'
   Y7_1293 = 'HELP SPIRIT/HEALER-FREQ'
   Y7_1294 = 'HELP SPIRIT/HEALER-1ST PROB'
   Y7_1295 = 'HELP SPIRIT/HEALER-2ND PROB'
   Y7_1296 = 'HELP SPIRIT/HEALER-3RD PROB'
   Y7_1297 = 'HELP SPIRIT/HEALER-AMOUNT HELP'
   Y7_1298 = 'HELP ANYONE ELSE-FREQ'
   Y7_1299 = 'HELP ANYONE ELSE-1ST PROB'
   Y7_1300 = 'HELP ANYONE ELSE-2ND PROB'
   Y7_1301 = 'HELP ANYONE ELSE-3RD PROB'
   Y7_1302 = 'HELP ANYONE ELSE-AMOUNT HELP'
   Y7_1303 = 'HELP MENTAL HEALTH-FREQ'
   Y7_1304 = 'HELP MENTAL HEALTH-1ST PROB'
   Y7_1305 = 'HELP MENTAL HEALTH-2ND PROB'
   Y7_1306 = 'HELP MENTAL HEALTH-3RD PROB'
   Y7_1307 = 'HELP MENTAL HEALTH-AMOUNT HELP'
   Y7_1308 = 'HELP PSYCH/OUT CLINIC-FREQ'
   Y7_1309 = 'HELP PSYCH/OUT CLINIC-1ST PROB'
   Y7_1310 = 'HELP PSYCH/OUT CLINIC-2ND PROB'
   Y7_1311 = 'HELP PSYCH/OUT CLINIC-3RD PROB'
   Y7_1312 = 'HELP PSYCH/OUT CLINIC-AMOUNT HLP'
   Y7_1313 = 'HELP OUT CLINIC PSYCH-FREQ'
   Y7_1314 = 'HELP OUT CLINIC PSYCH-1ST PROB'
   Y7_1315 = 'HELP OUT CLINIC PSYCH-2ND PROB'
   Y7_1316 = 'HELP OUT CLINIC PSYCH-3RD PROB'
   Y7_1317 = 'HELP OUT CLINIC PSYCH-AMOUNT HLP'
   Y7_1318 = 'HELP DRUG CLINIC-FREQ'
   Y7_1319 = 'HELP DRUG CLINIC-1ST PROB'
   Y7_1320 = 'HELP DRUG CLINIC-2ND PROB'
   Y7_1321 = 'HELP DRUG CLINIC-3RD PROB'
   Y7_1322 = 'HELP DRUG CLINIC-AMOUNT HELP'
   Y7_1323 = 'HELP ALCOHOLIC CLINIC-FREQ'
   Y7_1324 = 'HELP ALCOHOLIC CLINIC-1ST PROB'
   Y7_1325 = 'HELP ALCOHOLIC CLINIC-2ND PROB'
   Y7_1326 = 'HELP ALCOHOLIC CLINIC-3RD PROB'
   Y7_1327 = 'HELP ALCOHOLIC CLINIC-AMOUNT HLP'
   Y7_1328 = 'HELP EMERGENCY ROOM-FREQ'
   Y7_1329 = 'HELP EMERGENCY ROOM-1ST PROB'
   Y7_1330 = 'HELP EMERGENCY ROOM-2ND PROB'
   Y7_1331 = 'HELP EMERGENCY ROOM-3RD PROB'
   Y7_1332 = 'HELP EMERGENCY ROOM-AMOUNT HELP'
   Y7_1333 = 'HELP FAM/SOC AGENCY-FREQ'
   Y7_1334 = 'HELP FAM/SOC AGENCY-1ST PROB'
   Y7_1335 = 'HELP FAM/SOC AGENCY-2ND PROB'
   Y7_1336 = 'HELP FAM/SOC AGENCY-3RD PROB'
   Y7_1337 = 'HELP FAM/SOC AGENCY-AMOUNT HELP'
   Y7_1338 = 'HELP SELF-HELP GROUP-FREQ'
   Y7_1339 = 'HELP SELF-HELP GROUP-1ST PROB'
   Y7_1340 = 'HELP SELF-HELP GROUP-2ND PROB'
   Y7_1341 = 'HELP SELF-HELP GROUP-3RD PROB'
   Y7_1342 = 'HELP SELF-HELP GROUP-AMOUNT HELP'
   Y7_1343 = 'HELP CRISIS/HOTLINE-FREQ'
   Y7_1344 = 'HELP CRISIS/HOTLINE-1ST PROB'
   Y7_1345 = 'HELP CRISIS/HOTLINE-2ND PROB'
   Y7_1346 = 'HELP CRISIS/HOTLINE-3RD PROB'
   Y7_1347 = 'HELP CRISIS/HOTLINE-AMOUNT HELP'
   Y7_1348 = 'HELP OTH AGENCY/PROG-FREQ'
   Y7_1349 = 'HELP OTH AGENCY/PROG-1ST PROB'
   Y7_1350 = 'HELP OTH AGENCY/PROG-2ND PROB'
   Y7_1351 = 'HELP OTH AGENCY/PROG-3RD PROB'
   Y7_1352 = 'HELP OTH AGENCY/PROG-AMOUNT HELP'
   Y7_1353 = 'ADMIT HOSP EMOT/DRUG PROB-FREQ'
   Y7_1354 = 'ADMIT HOSP EMOT/DRUG PROB-1ST'
   Y7_1355 = 'ADMIT HOSP EMOT/DRUG PROB-2ND'
   Y7_1356 = 'ADMIT HOSP EMOT/DRUG PROB-3RD'
   Y7_1357 = 'ADM HOSP EMOT/DRUG PROB-AMT HLP'
   Y7_1358 = 'TIMES YOU-INSULT/SWORE'
   Y7_1359 = 'TIMES YOU-THREAT HIT/THROW'
   Y7_1360 = 'TIMES YOU-THREW SOMETHING'
   Y7_1361 = 'TIMES YOU-PUSHED/GRABBED/SHOVED'
   Y7_1362 = 'TIMES YOU-SLAPPED PARTNER'
   Y7_1363 = 'TIMES YOU-KICKED/BIT/HIT'
   Y7_1364 = 'TIMES YOU-HIT W/SOMETHING'
   Y7_1365 = 'TIMES YOU-BEAT UP PARTNER'
   Y7_1366 = 'TIMES YOU-THREATENED W/A GUN'
   Y7_1367 = 'TIMES YOU-USED KNIFE/FIRED GUN'
   Y7_1368 = 'TIMES PART-INSULT/SWORE'
   Y7_1369 = 'TIMES PART-THREAT HIT/THROW'
   Y7_1370 = 'TIMES PART-THREW SOMETHING'
   Y7_1371 = 'TIMES PART-PUSHED/GRABBED/SHOVED'
   Y7_1372 = 'TIMES PART-SLAPPED PARTNER'
   Y7_1373 = 'TIMES PART-KICKED/BIT/HIT'
   Y7_1374 = 'TIMES PART-HIT W/SOMETHING'
   Y7_1375 = 'TIMES PART-BEAT UP PARTNER'
   Y7_1376 = 'TIMES PART-THREATENED W/A GUN'
   Y7_1377 = 'TIMES PART-USED KNIFE/FIRED GUN'
   Y7_1378 = 'NO. FIGHTS IN PAST YEAR'
   Y7_1379 = 'NO. FIGHTS RESULT-PERS PHYS INJ'
   Y7_1380 = 'NO. TIMES TO DR/HOSP TREATM'
   Y7_1381 = 'NO. FIGHTS RESULT-PARTN PHYS INJ'
   Y7_1382 = 'NO TIMES PARTN TO DR/HOSP TREATM'
   Y7_1383 = 'SEXUAL INTERCOURSE/OPPOSITE SEX'
   Y7_1384 = 'SEX INTER (NOT SPOUSE)-FREQ'
   Y7_1385 = 'SEX INTER (NOT SPOUSE)-RATE'
   Y7_1386 = 'SEX INTERCOURSE (SPOUSE)-FREQ'
   Y7_1387 = 'SEX INTERCOURSE (SPOUSE)-RATE'
   Y7_1388 = 'HOW MANY SEXUAL PARTNERS'
   Y7_1389 = 'PRESSURED SOMEONE SEXUALLY-FREQ'
   Y7_1390 = 'PRESSURED SOMEONE SEXUALLY-RATE'
   Y7_1391 = 'RELATIONSHIP TO PERSON PRESSURED'
   Y7_1392 = 'SEX OF PERSON PRESSURED'
   Y7_1393 = 'KIND OF PRESSURE/FORCE USED'
   Y7_1394 = 'OTHERS INVOLVED W/PRESSURING'
   Y7_1395 = 'WAS THE PERSON INJURED'
   Y7_1396 = 'SUCCEED IN FORCING SEX RELATIONS'
   Y7_1397 = 'EVENT REPORT ANY OTH QUEST ITEM'
   Y7_1398 = 'THREATENED SOMEONE FOR SEX-FREQ'
   Y7_1399 = 'THREATENED SOMEONE FOR SEX-RATE'
   Y7_1400 = 'RELATIONSHIP TO PERS THREATENED'
   Y7_1401 = 'SEX OF PERSON THREATENED'
   Y7_1402 = 'KIND OF PRESSURE/FORCE USED'
   Y7_1403 = 'OTHERS INVOLVED W/THREATENING'
   Y7_1404 = 'WAS THE PERSON INJURED'
   Y7_1405 = 'SUCCEED IN FORCING SEX RELATIONS'
   Y7_1406 = 'EVENT REPORT ANY OTH QUEST ITEM'
   Y7_1407 = 'AGE 1ST SEX INTER W/OPPOSITE SEX'
   Y7_1408 = 'RELATIONSHIP TO THAT PERSON'
   Y7_1409 = '1ST SEXUAL EXPERIENCE VOLUNTARY'
   Y7_1410 = 'FEELINGS ABOUT THAT EXPERIENCE'
   Y7_1411 = 'SEXUAL RELATIONS W/SAME SEX'
   Y7_1412 = 'AGE 1ST TIME SEX REL W/SAME SEX'
   Y7_1413 = '1ST EXPERIENCE VOLUNTARY'
   Y7_1414 = 'FEELINGS ABOUT THAT EXPERIENCE'
   Y7_1415 = 'HOW OFTN SEX REL W/SAME SEX-FREQ'
   Y7_1416 = 'HOW OFTN SEX REL W/SAME SEX-RATE'
   Y7_1417 = 'NO. OF SAME-SEX SEX PART LAST YR'
   Y7_1418 = 'SEXUAL IDENTITY'
   Y7_1419 = 'SATISFIED W/SEX LIFE'
   Y7_1420 = 'AMOUNT OF STRESS/PRESS SEX LIFE'
   Y7_1421 = 'EXP SERIOUS FUNCTIONAL SEX PROB'
   Y7_1422 = 'NO. TIMES SEX BEHAV AFF PAST YR'
   Y7_1423 = 'PEEP OTHS DRESSING/ENGAGED SEX'
   Y7_1424 = 'TRIED ENGAGE CHILD SEX ACTIVITY'
   Y7_1425 = 'SEXUALLY EXPOSED TO STRANGERS'
   Y7_1426 = 'WATCH PORNOGRAHIC MOVIES/OTHER'
   Y7_1427 = 'BEEN CRUEL/HURTFUL TO SEX PART'
   Y7_1428 = 'SOUGHT CRUEL/PAIN FROM SEX PART'
   Y7_1429 = 'FURTHER EXPLANATION OF ANSWERS'
   Y7_1430 = 'UNCOMFORT Q.-DRUGS'
   Y7_1431 = 'UNCOMFORT Q.-SEX'
   Y7_1432 = 'UNCOMFORT Q.-MENTAL HEALTH'
   Y7_1433 = 'UNCOMFORT Q.-CRIMINAL BEHAVIOR'
   Y7_1434 = 'UNCOMFORT Q.-SPOUSE VIOLENCE'
   Y7_1435 = 'UNCOMFORT Q.-SPECIFIC ITEM NO.'
   Y7_1436 = 'UNCOMFORT Q.-SPECIFIC ITEM NO.'
   Y7_1437 = 'DELIB FALSE RESP-EVER'
   Y7_1451 = 'RESP''S ANXIETY BEFORE INTERVIEW'
   Y7_1452 = 'WAS RESPONDENT HOSTILE'
   Y7_1453 = 'RESPONDENT''S INTEREST'
   Y7_1454 = 'PROBS-DIFFICULTY W/LANGUAGE'
   Y7_1455 = 'PROBS-DIFFICULTY W/QUESTIONS'
   Y7_1456 = 'PROBS-INTERRUPTIONS'
   Y7_1457 = 'PROBS-TEMPORARY BREAKOFF'
   Y7_1458 = 'PROBS-BREAKOFF'
   Y7_1459 = 'PROBS-OTHER'
   Y7_1460 = 'RESP''S ANXIETY AFTER INTERVIEW'
   Y7_1461 = 'ADDITIONAL COMMENTS'
   Y7_1466 = 'BEEN IN GANG FIGHTS-1984'
   Y7_1467 = 'BEEN IN GANG FIGHTS-1985'
   Y7_1468 = 'STEAL SOMETHING > $50-1984'
   Y7_1469 = 'STEAL SOMETHING > $50-1985'
   Y7_1470 = 'ATTACK SOMEONE-1984'
   Y7_1471 = 'ATTACK SOMEONE-1985'
   Y7_1472 = 'STEAL MOTOR VEHICLE-1984'
   Y7_1473 = 'STEAL MOTOR VEHICLE-1985'
   Y7_1474 = 'USED FORCE ON ANYONE-1984'
   Y7_1475 = 'USED FORCE ON ANYONE-1985'
   Y7_1476 = 'BREAK INTO BUILDING-1984'
   Y7_1477 = 'BREAK INTO BUILDING-1985'
   Y7_1478 = 'SEX RELATIONS AGAINST WILL-1984'
   Y7_1479 = 'SEX RELATIONS AGAINST WILL-1985'
   Y7_1480 = 'BOUGHT STOLEN GOODS-1984'
   Y7_1481 = 'BOUGHT STOLEN GOODS-1985'
   Y7_1482 = 'USED ALCOHOL > 3 TIMES-1984'
   Y7_1483 = 'USED ALCOHOL > 3 TIMES-1985'
   Y7_1484 = 'USED MARIJUANA > 3 TIMES-1984'
   Y7_1485 = 'USED MARIJUANA > 3 TIMES-1985'
   Y7_1486 = 'ILLICIT DRUGS > 3 TIMES-1984'
   Y7_1487 = 'ILLICIT DRUGS > 3 TIMES-1985'
   Y7_1730 = 'NYS URB SSMPLURB RURAL'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (CASEID = -1) THEN CASEID = .;
   IF (DTSET1 = -1) THEN DTSET1 = .;
   IF (SSMPL1 = -1) THEN SSMPL1 = .;
   IF (HHLD1 = -1) THEN HHLD1 = .;
   IF (RESP1 = -1) THEN RESP1 = .;
   IF (Y7_1 = -1) THEN Y7_1 = .;
   IF (Y7_2 = -1) THEN Y7_2 = .;
   IF (Y7_3 = -1) THEN Y7_3 = .;
   IF (Y7_7 = -1) THEN Y7_7 = .;
   IF (Y7_8 = -1) THEN Y7_8 = .;
   IF (Y7_9 = -1) THEN Y7_9 = .;
   IF (Y7_10 = -1) THEN Y7_10 = .;
   IF (Y7_11 = -1) THEN Y7_11 = .;
   IF (Y7_12 = -1) THEN Y7_12 = .;
   IF (Y7_13 = -1) THEN Y7_13 = .;
   IF (Y7_14 = -1) THEN Y7_14 = .;
   IF (Y7_15 = -1) THEN Y7_15 = .;
   IF (Y7_16 = -1) THEN Y7_16 = .;
   IF (Y7_17 = -1) THEN Y7_17 = .;
   IF (Y7_18 = -1) THEN Y7_18 = .;
   IF (Y7_19 = -1) THEN Y7_19 = .;
   IF (Y7_20 = -1) THEN Y7_20 = .;
   IF (Y7_21 = -1) THEN Y7_21 = .;
   IF (Y7_22 = -1) THEN Y7_22 = .;
   IF (Y7_23 = -1) THEN Y7_23 = .;
   IF (Y7_24 = -1) THEN Y7_24 = .;
   IF (Y7_25 = -1) THEN Y7_25 = .;
   IF (Y7_26 = -1) THEN Y7_26 = .;
   IF (Y7_27 = -1) THEN Y7_27 = .;
   IF (Y7_28 = -1) THEN Y7_28 = .;
   IF (Y7_29 = -1) THEN Y7_29 = .;
   IF (Y7_30 = -1) THEN Y7_30 = .;
   IF (Y7_31 = -1) THEN Y7_31 = .;
   IF (Y7_32 = -1) THEN Y7_32 = .;
   IF (Y7_33 = -1) THEN Y7_33 = .;
   IF (Y7_34 = -1) THEN Y7_34 = .;
   IF (Y7_35 = -1) THEN Y7_35 = .;
   IF (Y7_36 = -1) THEN Y7_36 = .;
   IF (Y7_37 = -1) THEN Y7_37 = .;
   IF (Y7_38 = -1) THEN Y7_38 = .;
   IF (Y7_39 = -1) THEN Y7_39 = .;
   IF (Y7_40 = -1) THEN Y7_40 = .;
   IF (Y7_41 = -1) THEN Y7_41 = .;
   IF (Y7_42 = -1) THEN Y7_42 = .;
   IF (Y7_43 = -1) THEN Y7_43 = .;
   IF (Y7_44 = -1) THEN Y7_44 = .;
   IF (Y7_45 = -1) THEN Y7_45 = .;
   IF (Y7_46 = -1) THEN Y7_46 = .;
   IF (Y7_47 = -1) THEN Y7_47 = .;
   IF (Y7_48 = -1) THEN Y7_48 = .;
   IF (Y7_49 = -1) THEN Y7_49 = .;
   IF (Y7_50 = -1) THEN Y7_50 = .;
   IF (Y7_51 = -1) THEN Y7_51 = .;
   IF (Y7_52 = -1) THEN Y7_52 = .;
   IF (Y7_53 = -1) THEN Y7_53 = .;
   IF (Y7_54 = -1) THEN Y7_54 = .;
   IF (Y7_55 = -1) THEN Y7_55 = .;
   IF (Y7_56 = -1) THEN Y7_56 = .;
   IF (Y7_57 = -1) THEN Y7_57 = .;
   IF (Y7_58 = -1) THEN Y7_58 = .;
   IF (Y7_59 = -1) THEN Y7_59 = .;
   IF (Y7_60 = -1) THEN Y7_60 = .;
   IF (Y7_61 = -1) THEN Y7_61 = .;
   IF (Y7_62 = -1) THEN Y7_62 = .;
   IF (Y7_63 = -1) THEN Y7_63 = .;
   IF (Y7_64 = -1) THEN Y7_64 = .;
   IF (Y7_65 = -1) THEN Y7_65 = .;
   IF (Y7_66 = -1) THEN Y7_66 = .;
   IF (Y7_67 = -1) THEN Y7_67 = .;
   IF (Y7_68 = -1) THEN Y7_68 = .;
   IF (Y7_69 = -1) THEN Y7_69 = .;
   IF (Y7_70 = -1) THEN Y7_70 = .;
   IF (Y7_71 = -1) THEN Y7_71 = .;
   IF (Y7_72 = -1) THEN Y7_72 = .;
   IF (Y7_73 = -1) THEN Y7_73 = .;
   IF (Y7_74 = -1) THEN Y7_74 = .;
   IF (Y7_75 = -1) THEN Y7_75 = .;
   IF (Y7_76 = -1) THEN Y7_76 = .;
   IF (Y7_77 = -1) THEN Y7_77 = .;
   IF (Y7_78 = -1) THEN Y7_78 = .;
   IF (Y7_79 = -1) THEN Y7_79 = .;
   IF (Y7_80 = -1) THEN Y7_80 = .;
   IF (Y7_81 = -1) THEN Y7_81 = .;
   IF (Y7_82 = -1) THEN Y7_82 = .;
   IF (Y7_83 = -1) THEN Y7_83 = .;
   IF (Y7_84 = -1) THEN Y7_84 = .;
   IF (Y7_85 = -1) THEN Y7_85 = .;
   IF (Y7_86 = -1) THEN Y7_86 = .;
   IF (Y7_87 = -1) THEN Y7_87 = .;
   IF (Y7_88 = -1) THEN Y7_88 = .;
   IF (Y7_89 = -1) THEN Y7_89 = .;
   IF (Y7_90 = -1) THEN Y7_90 = .;
   IF (Y7_91 = -1) THEN Y7_91 = .;
   IF (Y7_92 = -1) THEN Y7_92 = .;
   IF (Y7_93 = -1) THEN Y7_93 = .;
   IF (Y7_94 = -1) THEN Y7_94 = .;
   IF (Y7_95 = -1) THEN Y7_95 = .;
   IF (Y7_96 = -1) THEN Y7_96 = .;
   IF (Y7_97 = -1) THEN Y7_97 = .;
   IF (Y7_98 = -1) THEN Y7_98 = .;
   IF (Y7_99 = -1) THEN Y7_99 = .;
   IF (Y7_100 = -1) THEN Y7_100 = .;
   IF (Y7_101 = -1) THEN Y7_101 = .;
   IF (Y7_102 = -1) THEN Y7_102 = .;
   IF (Y7_103 = -1) THEN Y7_103 = .;
   IF (Y7_104 = -1) THEN Y7_104 = .;
   IF (Y7_105 = -1) THEN Y7_105 = .;
   IF (Y7_106 = -1) THEN Y7_106 = .;
   IF (Y7_107 = -1) THEN Y7_107 = .;
   IF (Y7_108 = -1) THEN Y7_108 = .;
   IF (Y7_109 = -1) THEN Y7_109 = .;
   IF (Y7_110 = -1) THEN Y7_110 = .;
   IF (Y7_111 = -1) THEN Y7_111 = .;
   IF (Y7_112 = -1) THEN Y7_112 = .;
   IF (Y7_113 = -1) THEN Y7_113 = .;
   IF (Y7_114 = -1) THEN Y7_114 = .;
   IF (Y7_115 = -1) THEN Y7_115 = .;
   IF (Y7_116 = -1) THEN Y7_116 = .;
   IF (Y7_117 = -1) THEN Y7_117 = .;
   IF (Y7_118 = -1) THEN Y7_118 = .;
   IF (Y7_119 = -1) THEN Y7_119 = .;
   IF (Y7_120 = -1) THEN Y7_120 = .;
   IF (Y7_121 = -1) THEN Y7_121 = .;
   IF (Y7_122 = -1) THEN Y7_122 = .;
   IF (Y7_123 = -1) THEN Y7_123 = .;
   IF (Y7_124 = -1) THEN Y7_124 = .;
   IF (Y7_125 = -1) THEN Y7_125 = .;
   IF (Y7_126 = -1) THEN Y7_126 = .;
   IF (Y7_127 = -1) THEN Y7_127 = .;
   IF (Y7_128 = -1) THEN Y7_128 = .;
   IF (Y7_129 = -1) THEN Y7_129 = .;
   IF (Y7_130 = -1) THEN Y7_130 = .;
   IF (Y7_131 = -1) THEN Y7_131 = .;
   IF (Y7_132 = -1) THEN Y7_132 = .;
   IF (Y7_133 = -1) THEN Y7_133 = .;
   IF (Y7_134 = -1) THEN Y7_134 = .;
   IF (Y7_135 = -1) THEN Y7_135 = .;
   IF (Y7_136 = -1) THEN Y7_136 = .;
   IF (Y7_137 = -1) THEN Y7_137 = .;
   IF (Y7_138 = -1) THEN Y7_138 = .;
   IF (Y7_139 = -1) THEN Y7_139 = .;
   IF (Y7_140 = -1) THEN Y7_140 = .;
   IF (Y7_141 = -1) THEN Y7_141 = .;
   IF (Y7_142 = -1) THEN Y7_142 = .;
   IF (Y7_143 = -1) THEN Y7_143 = .;
   IF (Y7_144 = -1) THEN Y7_144 = .;
   IF (Y7_145 = -1) THEN Y7_145 = .;
   IF (Y7_146 = -1) THEN Y7_146 = .;
   IF (Y7_147 = -1) THEN Y7_147 = .;
   IF (Y7_148 = -1) THEN Y7_148 = .;
   IF (Y7_149 = -1) THEN Y7_149 = .;
   IF (Y7_150 = -1) THEN Y7_150 = .;
   IF (Y7_151 = -1) THEN Y7_151 = .;
   IF (Y7_152 = -1) THEN Y7_152 = .;
   IF (Y7_153 = -1) THEN Y7_153 = .;
   IF (Y7_154 = -1) THEN Y7_154 = .;
   IF (Y7_155 = -1) THEN Y7_155 = .;
   IF (Y7_156 = -1) THEN Y7_156 = .;
   IF (Y7_157 = -1) THEN Y7_157 = .;
   IF (Y7_158 = -1) THEN Y7_158 = .;
   IF (Y7_159 = -1) THEN Y7_159 = .;
   IF (Y7_160 = -1) THEN Y7_160 = .;
   IF (Y7_161 = -1) THEN Y7_161 = .;
   IF (Y7_162 = -1) THEN Y7_162 = .;
   IF (Y7_163 = -1) THEN Y7_163 = .;
   IF (Y7_164 = -1) THEN Y7_164 = .;
   IF (Y7_165 = -1) THEN Y7_165 = .;
   IF (Y7_166 = -1) THEN Y7_166 = .;
   IF (Y7_167 = -1) THEN Y7_167 = .;
   IF (Y7_168 = -1) THEN Y7_168 = .;
   IF (Y7_169 = -1) THEN Y7_169 = .;
   IF (Y7_170 = -1) THEN Y7_170 = .;
   IF (Y7_171 = -1) THEN Y7_171 = .;
   IF (Y7_172 = -1) THEN Y7_172 = .;
   IF (Y7_173 = -1) THEN Y7_173 = .;
   IF (Y7_174 = -1) THEN Y7_174 = .;
   IF (Y7_175 = -1) THEN Y7_175 = .;
   IF (Y7_176 = -1) THEN Y7_176 = .;
   IF (Y7_177 = -1) THEN Y7_177 = .;
   IF (Y7_178 = -1) THEN Y7_178 = .;
   IF (Y7_179 = -1) THEN Y7_179 = .;
   IF (Y7_180 = -1) THEN Y7_180 = .;
   IF (Y7_181 = -1) THEN Y7_181 = .;
   IF (Y7_182 = -1) THEN Y7_182 = .;
   IF (Y7_183 = -1) THEN Y7_183 = .;
   IF (Y7_184 = -1) THEN Y7_184 = .;
   IF (Y7_185 = -1) THEN Y7_185 = .;
   IF (Y7_186 = -1) THEN Y7_186 = .;
   IF (Y7_187 = -1) THEN Y7_187 = .;
   IF (Y7_188 = -1) THEN Y7_188 = .;
   IF (Y7_189 = -1) THEN Y7_189 = .;
   IF (Y7_190 = -1) THEN Y7_190 = .;
   IF (Y7_191 = -1) THEN Y7_191 = .;
   IF (Y7_192 = -1) THEN Y7_192 = .;
   IF (Y7_193 = -1) THEN Y7_193 = .;
   IF (Y7_194 = -1) THEN Y7_194 = .;
   IF (Y7_195 = -1) THEN Y7_195 = .;
   IF (Y7_196 = -1) THEN Y7_196 = .;
   IF (Y7_197 = -1) THEN Y7_197 = .;
   IF (Y7_198 = -1) THEN Y7_198 = .;
   IF (Y7_199 = -1) THEN Y7_199 = .;
   IF (Y7_200 = -1) THEN Y7_200 = .;
   IF (Y7_201 = -1) THEN Y7_201 = .;
   IF (Y7_202 = -1) THEN Y7_202 = .;
   IF (Y7_203 = -1) THEN Y7_203 = .;
   IF (Y7_204 = -1) THEN Y7_204 = .;
   IF (Y7_205 = -1) THEN Y7_205 = .;
   IF (Y7_206 = -1) THEN Y7_206 = .;
   IF (Y7_207 = -1) THEN Y7_207 = .;
   IF (Y7_208 = -1) THEN Y7_208 = .;
   IF (Y7_209 = -1) THEN Y7_209 = .;
   IF (Y7_210 = -1) THEN Y7_210 = .;
   IF (Y7_211 = -1) THEN Y7_211 = .;
   IF (Y7_212 = -1) THEN Y7_212 = .;
   IF (Y7_213 = -1) THEN Y7_213 = .;
   IF (Y7_214 = -1) THEN Y7_214 = .;
   IF (Y7_215 = -1) THEN Y7_215 = .;
   IF (Y7_216 = -1) THEN Y7_216 = .;
   IF (Y7_217 = -1) THEN Y7_217 = .;
   IF (Y7_218 = -1) THEN Y7_218 = .;
   IF (Y7_219 = -1) THEN Y7_219 = .;
   IF (Y7_220 = -1) THEN Y7_220 = .;
   IF (Y7_221 = -1) THEN Y7_221 = .;
   IF (Y7_222 = -1) THEN Y7_222 = .;
   IF (Y7_223 = -1) THEN Y7_223 = .;
   IF (Y7_224 = -1) THEN Y7_224 = .;
   IF (Y7_225 = -1) THEN Y7_225 = .;
   IF (Y7_226 = -1) THEN Y7_226 = .;
   IF (Y7_227 = -1) THEN Y7_227 = .;
   IF (Y7_228 = -1) THEN Y7_228 = .;
   IF (Y7_229 = -1) THEN Y7_229 = .;
   IF (Y7_230 = -1) THEN Y7_230 = .;
   IF (Y7_231 = -1) THEN Y7_231 = .;
   IF (Y7_232 = -1) THEN Y7_232 = .;
   IF (Y7_233 = -1) THEN Y7_233 = .;
   IF (Y7_234 = -1) THEN Y7_234 = .;
   IF (Y7_235 = -1) THEN Y7_235 = .;
   IF (Y7_236 = -1) THEN Y7_236 = .;
   IF (Y7_237 = -1) THEN Y7_237 = .;
   IF (Y7_238 = -1) THEN Y7_238 = .;
   IF (Y7_239 = -1) THEN Y7_239 = .;
   IF (Y7_240 = -1) THEN Y7_240 = .;
   IF (Y7_241 = -1) THEN Y7_241 = .;
   IF (Y7_242 = -1) THEN Y7_242 = .;
   IF (Y7_243 = -1) THEN Y7_243 = .;
   IF (Y7_244 = -1) THEN Y7_244 = .;
   IF (Y7_245 = -1) THEN Y7_245 = .;
   IF (Y7_246 = -1) THEN Y7_246 = .;
   IF (Y7_247 = -1) THEN Y7_247 = .;
   IF (Y7_248 = -1) THEN Y7_248 = .;
   IF (Y7_249 = -1) THEN Y7_249 = .;
   IF (Y7_250 = -1) THEN Y7_250 = .;
   IF (Y7_251 = -1) THEN Y7_251 = .;
   IF (Y7_252 = -1) THEN Y7_252 = .;
   IF (Y7_253 = -1) THEN Y7_253 = .;
   IF (Y7_254 = -1) THEN Y7_254 = .;
   IF (Y7_255 = -1) THEN Y7_255 = .;
   IF (Y7_256 = -1) THEN Y7_256 = .;
   IF (Y7_257 = -1) THEN Y7_257 = .;
   IF (Y7_258 = -1) THEN Y7_258 = .;
   IF (Y7_259 = -1) THEN Y7_259 = .;
   IF (Y7_260 = -1) THEN Y7_260 = .;
   IF (Y7_261 = -1) THEN Y7_261 = .;
   IF (Y7_262 = -1) THEN Y7_262 = .;
   IF (Y7_263 = -1) THEN Y7_263 = .;
   IF (Y7_264 = -1) THEN Y7_264 = .;
   IF (Y7_265 = -1) THEN Y7_265 = .;
   IF (Y7_266 = -1) THEN Y7_266 = .;
   IF (Y7_267 = -1) THEN Y7_267 = .;
   IF (Y7_268 = -1) THEN Y7_268 = .;
   IF (Y7_269 = -1) THEN Y7_269 = .;
   IF (Y7_270 = -1) THEN Y7_270 = .;
   IF (Y7_271 = -1) THEN Y7_271 = .;
   IF (Y7_272 = -1) THEN Y7_272 = .;
   IF (Y7_273 = -1) THEN Y7_273 = .;
   IF (Y7_274 = -1) THEN Y7_274 = .;
   IF (Y7_275 = -1) THEN Y7_275 = .;
   IF (Y7_276 = -1) THEN Y7_276 = .;
   IF (Y7_277 = -1) THEN Y7_277 = .;
   IF (Y7_278 = -1) THEN Y7_278 = .;
   IF (Y7_279 = -1) THEN Y7_279 = .;
   IF (Y7_280 = -1) THEN Y7_280 = .;
   IF (Y7_281 = -1) THEN Y7_281 = .;
   IF (Y7_282 = -1) THEN Y7_282 = .;
   IF (Y7_283 = -1) THEN Y7_283 = .;
   IF (Y7_284 = -1) THEN Y7_284 = .;
   IF (Y7_285 = -1) THEN Y7_285 = .;
   IF (Y7_286 = -1) THEN Y7_286 = .;
   IF (Y7_287 = -1) THEN Y7_287 = .;
   IF (Y7_288 = -1) THEN Y7_288 = .;
   IF (Y7_289 = -1) THEN Y7_289 = .;
   IF (Y7_290 = -1) THEN Y7_290 = .;
   IF (Y7_291 = -1) THEN Y7_291 = .;
   IF (Y7_292 = -1) THEN Y7_292 = .;
   IF (Y7_293 = -1) THEN Y7_293 = .;
   IF (Y7_294 = -1) THEN Y7_294 = .;
   IF (Y7_295 = -1) THEN Y7_295 = .;
   IF (Y7_296 = -1) THEN Y7_296 = .;
   IF (Y7_297 = -1) THEN Y7_297 = .;
   IF (Y7_298 = -1) THEN Y7_298 = .;
   IF (Y7_299 = -1) THEN Y7_299 = .;
   IF (Y7_300 = -1) THEN Y7_300 = .;
   IF (Y7_301 = -1) THEN Y7_301 = .;
   IF (Y7_302 = -1) THEN Y7_302 = .;
   IF (Y7_303 = -1) THEN Y7_303 = .;
   IF (Y7_304 = -1) THEN Y7_304 = .;
   IF (Y7_305 = -1) THEN Y7_305 = .;
   IF (Y7_306 = -1) THEN Y7_306 = .;
   IF (Y7_307 = -1) THEN Y7_307 = .;
   IF (Y7_308 = -1) THEN Y7_308 = .;
   IF (Y7_309 = -1) THEN Y7_309 = .;
   IF (Y7_310 = -1) THEN Y7_310 = .;
   IF (Y7_311 = -1) THEN Y7_311 = .;
   IF (Y7_312 = -1) THEN Y7_312 = .;
   IF (Y7_313 = -1) THEN Y7_313 = .;
   IF (Y7_314 = -1) THEN Y7_314 = .;
   IF (Y7_315 = -1) THEN Y7_315 = .;
   IF (Y7_316 = -1) THEN Y7_316 = .;
   IF (Y7_317 = -1) THEN Y7_317 = .;
   IF (Y7_318 = -1) THEN Y7_318 = .;
   IF (Y7_319 = -1) THEN Y7_319 = .;
   IF (Y7_320 = -1) THEN Y7_320 = .;
   IF (Y7_321 = -1) THEN Y7_321 = .;
   IF (Y7_322 = -1) THEN Y7_322 = .;
   IF (Y7_323 = -1) THEN Y7_323 = .;
   IF (Y7_324 = -1) THEN Y7_324 = .;
   IF (Y7_325 = -1) THEN Y7_325 = .;
   IF (Y7_326 = -1) THEN Y7_326 = .;
   IF (Y7_327 = -1) THEN Y7_327 = .;
   IF (Y7_328 = -1) THEN Y7_328 = .;
   IF (Y7_329 = -1) THEN Y7_329 = .;
   IF (Y7_330 = -1) THEN Y7_330 = .;
   IF (Y7_331 = -1) THEN Y7_331 = .;
   IF (Y7_332 = -1) THEN Y7_332 = .;
   IF (Y7_333 = -1) THEN Y7_333 = .;
   IF (Y7_334 = -1) THEN Y7_334 = .;
   IF (Y7_335 = -1) THEN Y7_335 = .;
   IF (Y7_336 = -1) THEN Y7_336 = .;
   IF (Y7_337 = -1) THEN Y7_337 = .;
   IF (Y7_338 = -1) THEN Y7_338 = .;
   IF (Y7_339 = -1) THEN Y7_339 = .;
   IF (Y7_340 = -1) THEN Y7_340 = .;
   IF (Y7_341 = -1) THEN Y7_341 = .;
   IF (Y7_342 = -1) THEN Y7_342 = .;
   IF (Y7_343 = -1) THEN Y7_343 = .;
   IF (Y7_344 = -1) THEN Y7_344 = .;
   IF (Y7_345 = -1) THEN Y7_345 = .;
   IF (Y7_346 = -1) THEN Y7_346 = .;
   IF (Y7_347 = -1) THEN Y7_347 = .;
   IF (Y7_348 = -1) THEN Y7_348 = .;
   IF (Y7_349 = -1) THEN Y7_349 = .;
   IF (Y7_350 = -1) THEN Y7_350 = .;
   IF (Y7_351 = -1) THEN Y7_351 = .;
   IF (Y7_352 = -1) THEN Y7_352 = .;
   IF (Y7_353 = -1) THEN Y7_353 = .;
   IF (Y7_354 = -1) THEN Y7_354 = .;
   IF (Y7_355 = -1) THEN Y7_355 = .;
   IF (Y7_356 = -1) THEN Y7_356 = .;
   IF (Y7_357 = -1) THEN Y7_357 = .;
   IF (Y7_358 = -1) THEN Y7_358 = .;
   IF (Y7_359 = -1) THEN Y7_359 = .;
   IF (Y7_360 = -1) THEN Y7_360 = .;
   IF (Y7_361 = -1) THEN Y7_361 = .;
   IF (Y7_362 = -1) THEN Y7_362 = .;
   IF (Y7_363 = -1) THEN Y7_363 = .;
   IF (Y7_364 = -1) THEN Y7_364 = .;
   IF (Y7_365 = -1) THEN Y7_365 = .;
   IF (Y7_366 = -1) THEN Y7_366 = .;
   IF (Y7_367 = -1) THEN Y7_367 = .;
   IF (Y7_368 = -1) THEN Y7_368 = .;
   IF (Y7_369 = -1) THEN Y7_369 = .;
   IF (Y7_370 = -1) THEN Y7_370 = .;
   IF (Y7_371 = -1) THEN Y7_371 = .;
   IF (Y7_372 = -1) THEN Y7_372 = .;
   IF (Y7_373 = -1) THEN Y7_373 = .;
   IF (Y7_374 = -1) THEN Y7_374 = .;
   IF (Y7_375 = -1) THEN Y7_375 = .;
   IF (Y7_376 = -1) THEN Y7_376 = .;
   IF (Y7_377 = -1) THEN Y7_377 = .;
   IF (Y7_378 = -1) THEN Y7_378 = .;
   IF (Y7_379 = -1) THEN Y7_379 = .;
   IF (Y7_380 = -1) THEN Y7_380 = .;
   IF (Y7_381 = -1) THEN Y7_381 = .;
   IF (Y7_382 = -1) THEN Y7_382 = .;
   IF (Y7_383 = -1) THEN Y7_383 = .;
   IF (Y7_384 = -1) THEN Y7_384 = .;
   IF (Y7_385 = -1) THEN Y7_385 = .;
   IF (Y7_386 = -1) THEN Y7_386 = .;
   IF (Y7_387 = -1) THEN Y7_387 = .;
   IF (Y7_388 = -1) THEN Y7_388 = .;
   IF (Y7_389 = -1) THEN Y7_389 = .;
   IF (Y7_390 = -1) THEN Y7_390 = .;
   IF (Y7_391 = -1) THEN Y7_391 = .;
   IF (Y7_392 = -1) THEN Y7_392 = .;
   IF (Y7_393 = -1) THEN Y7_393 = .;
   IF (Y7_394 = -1) THEN Y7_394 = .;
   IF (Y7_395 = -1) THEN Y7_395 = .;
   IF (Y7_396 = -1) THEN Y7_396 = .;
   IF (Y7_397 = -1) THEN Y7_397 = .;
   IF (Y7_398 = -1) THEN Y7_398 = .;
   IF (Y7_399 = -1) THEN Y7_399 = .;
   IF (Y7_400 = -1) THEN Y7_400 = .;
   IF (Y7_401 = -1) THEN Y7_401 = .;
   IF (Y7_402 = -1) THEN Y7_402 = .;
   IF (Y7_403 = -1) THEN Y7_403 = .;
   IF (Y7_404 = -1) THEN Y7_404 = .;
   IF (Y7_405 = -1) THEN Y7_405 = .;
   IF (Y7_406 = -1) THEN Y7_406 = .;
   IF (Y7_407 = -1) THEN Y7_407 = .;
   IF (Y7_408 = -1) THEN Y7_408 = .;
   IF (Y7_409 = -1) THEN Y7_409 = .;
   IF (Y7_410 = -1) THEN Y7_410 = .;
   IF (Y7_411 = -1) THEN Y7_411 = .;
   IF (Y7_412 = -1) THEN Y7_412 = .;
   IF (Y7_413 = -1) THEN Y7_413 = .;
   IF (Y7_414 = -1) THEN Y7_414 = .;
   IF (Y7_415 = -1) THEN Y7_415 = .;
   IF (Y7_416 = -1) THEN Y7_416 = .;
   IF (Y7_417 = -1) THEN Y7_417 = .;
   IF (Y7_418 = -1) THEN Y7_418 = .;
   IF (Y7_419 = -1) THEN Y7_419 = .;
   IF (Y7_420 = -1) THEN Y7_420 = .;
   IF (Y7_421 = -1) THEN Y7_421 = .;
   IF (Y7_422 = -1) THEN Y7_422 = .;
   IF (Y7_423 = -1) THEN Y7_423 = .;
   IF (Y7_424 = -1) THEN Y7_424 = .;
   IF (Y7_425 = -1) THEN Y7_425 = .;
   IF (Y7_426 = -1) THEN Y7_426 = .;
   IF (Y7_427 = -1) THEN Y7_427 = .;
   IF (Y7_428 = -1) THEN Y7_428 = .;
   IF (Y7_429 = -1) THEN Y7_429 = .;
   IF (Y7_430 = -1) THEN Y7_430 = .;
   IF (Y7_431 = -1) THEN Y7_431 = .;
   IF (Y7_432 = -1) THEN Y7_432 = .;
   IF (Y7_433 = -1) THEN Y7_433 = .;
   IF (Y7_434 = -1) THEN Y7_434 = .;
   IF (Y7_435 = -1) THEN Y7_435 = .;
   IF (Y7_436 = -1) THEN Y7_436 = .;
   IF (Y7_437 = -1) THEN Y7_437 = .;
   IF (Y7_438 = -1) THEN Y7_438 = .;
   IF (Y7_439 = -1) THEN Y7_439 = .;
   IF (Y7_440 = -1) THEN Y7_440 = .;
   IF (Y7_441 = -1) THEN Y7_441 = .;
   IF (Y7_442 = -1) THEN Y7_442 = .;
   IF (Y7_443 = -1) THEN Y7_443 = .;
   IF (Y7_444 = -1) THEN Y7_444 = .;
   IF (Y7_445 = -1) THEN Y7_445 = .;
   IF (Y7_446 = -1) THEN Y7_446 = .;
   IF (Y7_447 = -1) THEN Y7_447 = .;
   IF (Y7_448 = -1) THEN Y7_448 = .;
   IF (Y7_449 = -1) THEN Y7_449 = .;
   IF (Y7_450 = -1) THEN Y7_450 = .;
   IF (Y7_451 = -1) THEN Y7_451 = .;
   IF (Y7_452 = -1) THEN Y7_452 = .;
   IF (Y7_453 = -1) THEN Y7_453 = .;
   IF (Y7_454 = -1) THEN Y7_454 = .;
   IF (Y7_455 = -1) THEN Y7_455 = .;
   IF (Y7_456 = -1) THEN Y7_456 = .;
   IF (Y7_457 = -1) THEN Y7_457 = .;
   IF (Y7_458 = -1) THEN Y7_458 = .;
   IF (Y7_459 = -1) THEN Y7_459 = .;
   IF (Y7_460 = -1) THEN Y7_460 = .;
   IF (Y7_461 = -1) THEN Y7_461 = .;
   IF (Y7_462 = -1) THEN Y7_462 = .;
   IF (Y7_463 = -1) THEN Y7_463 = .;
   IF (Y7_464 = -1) THEN Y7_464 = .;
   IF (Y7_465 = -1) THEN Y7_465 = .;
   IF (Y7_466 = -1) THEN Y7_466 = .;
   IF (Y7_467 = -1) THEN Y7_467 = .;
   IF (Y7_468 = -1) THEN Y7_468 = .;
   IF (Y7_469 = -1) THEN Y7_469 = .;
   IF (Y7_470 = -1) THEN Y7_470 = .;
   IF (Y7_471 = -1) THEN Y7_471 = .;
   IF (Y7_472 = -1) THEN Y7_472 = .;
   IF (Y7_473 = -1) THEN Y7_473 = .;
   IF (Y7_474 = -1) THEN Y7_474 = .;
   IF (Y7_475 = -1) THEN Y7_475 = .;
   IF (Y7_476 = -1) THEN Y7_476 = .;
   IF (Y7_477 = -1) THEN Y7_477 = .;
   IF (Y7_478 = -1) THEN Y7_478 = .;
   IF (Y7_479 = -1) THEN Y7_479 = .;
   IF (Y7_480 = -1) THEN Y7_480 = .;
   IF (Y7_481 = -1) THEN Y7_481 = .;
   IF (Y7_482 = -1) THEN Y7_482 = .;
   IF (Y7_483 = -1) THEN Y7_483 = .;
   IF (Y7_484 = -1) THEN Y7_484 = .;
   IF (Y7_485 = -1) THEN Y7_485 = .;
   IF (Y7_486 = -1) THEN Y7_486 = .;
   IF (Y7_487 = -1) THEN Y7_487 = .;
   IF (Y7_488 = -1) THEN Y7_488 = .;
   IF (Y7_489 = -1) THEN Y7_489 = .;
   IF (Y7_490 = -1) THEN Y7_490 = .;
   IF (Y7_491 = -1) THEN Y7_491 = .;
   IF (Y7_492 = -1) THEN Y7_492 = .;
   IF (Y7_493 = -1) THEN Y7_493 = .;
   IF (Y7_494 = -1) THEN Y7_494 = .;
   IF (Y7_495 = -1) THEN Y7_495 = .;
   IF (Y7_496 = -1) THEN Y7_496 = .;
   IF (Y7_497 = -1) THEN Y7_497 = .;
   IF (Y7_498 = -1) THEN Y7_498 = .;
   IF (Y7_499 = -1) THEN Y7_499 = .;
   IF (Y7_500 = -1) THEN Y7_500 = .;
   IF (Y7_501 = -1) THEN Y7_501 = .;
   IF (Y7_502 = -1) THEN Y7_502 = .;
   IF (Y7_503 = -1) THEN Y7_503 = .;
   IF (Y7_504 = -1) THEN Y7_504 = .;
   IF (Y7_505 = -1) THEN Y7_505 = .;
   IF (Y7_506 = -1) THEN Y7_506 = .;
   IF (Y7_507 = -1) THEN Y7_507 = .;
   IF (Y7_508 = -1) THEN Y7_508 = .;
   IF (Y7_509 = -1) THEN Y7_509 = .;
   IF (Y7_510 = -1) THEN Y7_510 = .;
   IF (Y7_511 = -1) THEN Y7_511 = .;
   IF (Y7_512 = -1) THEN Y7_512 = .;
   IF (Y7_513 = -1) THEN Y7_513 = .;
   IF (Y7_514 = -1) THEN Y7_514 = .;
   IF (Y7_515 = -1) THEN Y7_515 = .;
   IF (Y7_516 = -1) THEN Y7_516 = .;
   IF (Y7_517 = -1) THEN Y7_517 = .;
   IF (Y7_518 = -1) THEN Y7_518 = .;
   IF (Y7_519 = -1) THEN Y7_519 = .;
   IF (Y7_520 = -1) THEN Y7_520 = .;
   IF (Y7_521 = -1) THEN Y7_521 = .;
   IF (Y7_522 = -1) THEN Y7_522 = .;
   IF (Y7_523 = -1) THEN Y7_523 = .;
   IF (Y7_524 = -1) THEN Y7_524 = .;
   IF (Y7_525 = -1) THEN Y7_525 = .;
   IF (Y7_526 = -1) THEN Y7_526 = .;
   IF (Y7_527 = -1) THEN Y7_527 = .;
   IF (Y7_528 = -1) THEN Y7_528 = .;
   IF (Y7_529 = -1) THEN Y7_529 = .;
   IF (Y7_530 = -1) THEN Y7_530 = .;
   IF (Y7_531 = -1) THEN Y7_531 = .;
   IF (Y7_532 = -1) THEN Y7_532 = .;
   IF (Y7_533 = -1) THEN Y7_533 = .;
   IF (Y7_534 = -1) THEN Y7_534 = .;
   IF (Y7_535 = -1) THEN Y7_535 = .;
   IF (Y7_536 = -1) THEN Y7_536 = .;
   IF (Y7_537 = -1) THEN Y7_537 = .;
   IF (Y7_538 = -1) THEN Y7_538 = .;
   IF (Y7_539 = -1) THEN Y7_539 = .;
   IF (Y7_540 = -1) THEN Y7_540 = .;
   IF (Y7_541 = -1) THEN Y7_541 = .;
   IF (Y7_542 = -1) THEN Y7_542 = .;
   IF (Y7_543 = -1) THEN Y7_543 = .;
   IF (Y7_544 = -1) THEN Y7_544 = .;
   IF (Y7_545 = -1) THEN Y7_545 = .;
   IF (Y7_546 = -1) THEN Y7_546 = .;
   IF (Y7_547 = -1) THEN Y7_547 = .;
   IF (Y7_548 = -1) THEN Y7_548 = .;
   IF (Y7_549 = -1) THEN Y7_549 = .;
   IF (Y7_550 = -1) THEN Y7_550 = .;
   IF (Y7_551 = -1) THEN Y7_551 = .;
   IF (Y7_552 = -1) THEN Y7_552 = .;
   IF (Y7_553 = -1) THEN Y7_553 = .;
   IF (Y7_554 = -1) THEN Y7_554 = .;
   IF (Y7_555 = -1) THEN Y7_555 = .;
   IF (Y7_556 = -1) THEN Y7_556 = .;
   IF (Y7_557 = -1) THEN Y7_557 = .;
   IF (Y7_558 = -1) THEN Y7_558 = .;
   IF (Y7_559 = -1) THEN Y7_559 = .;
   IF (Y7_560 = -1) THEN Y7_560 = .;
   IF (Y7_561 = -1) THEN Y7_561 = .;
   IF (Y7_562 = -1) THEN Y7_562 = .;
   IF (Y7_563 = -1) THEN Y7_563 = .;
   IF (Y7_564 = -1) THEN Y7_564 = .;
   IF (Y7_565 = -1) THEN Y7_565 = .;
   IF (Y7_566 = -1) THEN Y7_566 = .;
   IF (Y7_567 = -1) THEN Y7_567 = .;
   IF (Y7_568 = -1) THEN Y7_568 = .;
   IF (Y7_569 = -1) THEN Y7_569 = .;
   IF (Y7_570 = -1) THEN Y7_570 = .;
   IF (Y7_571 = -1) THEN Y7_571 = .;
   IF (Y7_572 = -1) THEN Y7_572 = .;
   IF (Y7_573 = -1) THEN Y7_573 = .;
   IF (Y7_574 = -1) THEN Y7_574 = .;
   IF (Y7_575 = -1) THEN Y7_575 = .;
   IF (Y7_576 = -1) THEN Y7_576 = .;
   IF (Y7_577 = -1) THEN Y7_577 = .;
   IF (Y7_578 = -1) THEN Y7_578 = .;
   IF (Y7_579 = -1) THEN Y7_579 = .;
   IF (Y7_580 = -1) THEN Y7_580 = .;
   IF (Y7_581 = -1) THEN Y7_581 = .;
   IF (Y7_582 = -1) THEN Y7_582 = .;
   IF (Y7_583 = -1) THEN Y7_583 = .;
   IF (Y7_584 = -1) THEN Y7_584 = .;
   IF (Y7_585 = -1) THEN Y7_585 = .;
   IF (Y7_586 = -1) THEN Y7_586 = .;
   IF (Y7_587 = -1) THEN Y7_587 = .;
   IF (Y7_588 = -1) THEN Y7_588 = .;
   IF (Y7_589 = -1) THEN Y7_589 = .;
   IF (Y7_590 = -1) THEN Y7_590 = .;
   IF (Y7_591 = -1) THEN Y7_591 = .;
   IF (Y7_592 = -1) THEN Y7_592 = .;
   IF (Y7_593 = -1) THEN Y7_593 = .;
   IF (Y7_594 = -1) THEN Y7_594 = .;
   IF (Y7_595 = -1) THEN Y7_595 = .;
   IF (Y7_596 = -1) THEN Y7_596 = .;
   IF (Y7_597 = -1) THEN Y7_597 = .;
   IF (Y7_598 = -1) THEN Y7_598 = .;
   IF (Y7_599 = -1) THEN Y7_599 = .;
   IF (Y7_600 = -1) THEN Y7_600 = .;
   IF (Y7_601 = -1) THEN Y7_601 = .;
   IF (Y7_602 = -1) THEN Y7_602 = .;
   IF (Y7_603 = -1) THEN Y7_603 = .;
   IF (Y7_604 = -1) THEN Y7_604 = .;
   IF (Y7_605 = -1) THEN Y7_605 = .;
   IF (Y7_606 = -1) THEN Y7_606 = .;
   IF (Y7_607 = -1) THEN Y7_607 = .;
   IF (Y7_608 = -1) THEN Y7_608 = .;
   IF (Y7_609 = -1) THEN Y7_609 = .;
   IF (Y7_610 = -1) THEN Y7_610 = .;
   IF (Y7_611 = -1) THEN Y7_611 = .;
   IF (Y7_612 = -1) THEN Y7_612 = .;
   IF (Y7_613 = -1) THEN Y7_613 = .;
   IF (Y7_614 = -1) THEN Y7_614 = .;
   IF (Y7_615 = -1) THEN Y7_615 = .;
   IF (Y7_616 = -1) THEN Y7_616 = .;
   IF (Y7_617 = -1) THEN Y7_617 = .;
   IF (Y7_618 = -1) THEN Y7_618 = .;
   IF (Y7_619 = -1) THEN Y7_619 = .;
   IF (Y7_620 = -1) THEN Y7_620 = .;
   IF (Y7_621 = -1) THEN Y7_621 = .;
   IF (Y7_622 = -1) THEN Y7_622 = .;
   IF (Y7_623 = -1) THEN Y7_623 = .;
   IF (Y7_624 = -1) THEN Y7_624 = .;
   IF (Y7_625 = -1) THEN Y7_625 = .;
   IF (Y7_626 = -1) THEN Y7_626 = .;
   IF (Y7_627 = -1) THEN Y7_627 = .;
   IF (Y7_628 = -1) THEN Y7_628 = .;
   IF (Y7_629 = -1) THEN Y7_629 = .;
   IF (Y7_630 = -1) THEN Y7_630 = .;
   IF (Y7_631 = -1) THEN Y7_631 = .;
   IF (Y7_632 = -1) THEN Y7_632 = .;
   IF (Y7_633 = -1) THEN Y7_633 = .;
   IF (Y7_634 = -1) THEN Y7_634 = .;
   IF (Y7_635 = -1) THEN Y7_635 = .;
   IF (Y7_636 = -1) THEN Y7_636 = .;
   IF (Y7_637 = -1) THEN Y7_637 = .;
   IF (Y7_638 = -1) THEN Y7_638 = .;
   IF (Y7_639 = -1) THEN Y7_639 = .;
   IF (Y7_640 = -1) THEN Y7_640 = .;
   IF (Y7_641 = -1) THEN Y7_641 = .;
   IF (Y7_642 = -1) THEN Y7_642 = .;
   IF (Y7_643 = -1) THEN Y7_643 = .;
   IF (Y7_644 = -1) THEN Y7_644 = .;
   IF (Y7_645 = -1) THEN Y7_645 = .;
   IF (Y7_646 = -1) THEN Y7_646 = .;
   IF (Y7_647 = -1) THEN Y7_647 = .;
   IF (Y7_648 = -1) THEN Y7_648 = .;
   IF (Y7_649 = -1) THEN Y7_649 = .;
   IF (Y7_650 = -1) THEN Y7_650 = .;
   IF (Y7_651 = -1) THEN Y7_651 = .;
   IF (Y7_652 = -1) THEN Y7_652 = .;
   IF (Y7_653 = -1) THEN Y7_653 = .;
   IF (Y7_654 = -1) THEN Y7_654 = .;
   IF (Y7_655 = -1) THEN Y7_655 = .;
   IF (Y7_656 = -1) THEN Y7_656 = .;
   IF (Y7_657 = -1) THEN Y7_657 = .;
   IF (Y7_658 = -1) THEN Y7_658 = .;
   IF (Y7_659 = -1) THEN Y7_659 = .;
   IF (Y7_660 = -1) THEN Y7_660 = .;
   IF (Y7_661 = -1) THEN Y7_661 = .;
   IF (Y7_662 = -1) THEN Y7_662 = .;
   IF (Y7_663 = -1) THEN Y7_663 = .;
   IF (Y7_664 = -1) THEN Y7_664 = .;
   IF (Y7_665 = -1) THEN Y7_665 = .;
   IF (Y7_666 = -1) THEN Y7_666 = .;
   IF (Y7_667 = -1) THEN Y7_667 = .;
   IF (Y7_668 = -1) THEN Y7_668 = .;
   IF (Y7_669 = -1) THEN Y7_669 = .;
   IF (Y7_670 = -1) THEN Y7_670 = .;
   IF (Y7_671 = -1) THEN Y7_671 = .;
   IF (Y7_672 = -1) THEN Y7_672 = .;
   IF (Y7_673 = -1) THEN Y7_673 = .;
   IF (Y7_674 = -1) THEN Y7_674 = .;
   IF (Y7_675 = -1) THEN Y7_675 = .;
   IF (Y7_676 = -1) THEN Y7_676 = .;
   IF (Y7_677 = -1) THEN Y7_677 = .;
   IF (Y7_678 = -1) THEN Y7_678 = .;
   IF (Y7_679 = -1) THEN Y7_679 = .;
   IF (Y7_680 = -1) THEN Y7_680 = .;
   IF (Y7_681 = -1) THEN Y7_681 = .;
   IF (Y7_682 = -1) THEN Y7_682 = .;
   IF (Y7_683 = -1) THEN Y7_683 = .;
   IF (Y7_684 = -1) THEN Y7_684 = .;
   IF (Y7_685 = -1) THEN Y7_685 = .;
   IF (Y7_686 = -1) THEN Y7_686 = .;
   IF (Y7_687 = -1) THEN Y7_687 = .;
   IF (Y7_688 = -1) THEN Y7_688 = .;
   IF (Y7_689 = -1) THEN Y7_689 = .;
   IF (Y7_690 = -1) THEN Y7_690 = .;
   IF (Y7_691 = -1) THEN Y7_691 = .;
   IF (Y7_692 = -1) THEN Y7_692 = .;
   IF (Y7_693 = -1) THEN Y7_693 = .;
   IF (Y7_694 = -1) THEN Y7_694 = .;
   IF (Y7_695 = -1) THEN Y7_695 = .;
   IF (Y7_696 = -1) THEN Y7_696 = .;
   IF (Y7_697 = -1) THEN Y7_697 = .;
   IF (Y7_698 = -1) THEN Y7_698 = .;
   IF (Y7_699 = -1) THEN Y7_699 = .;
   IF (Y7_700 = -1) THEN Y7_700 = .;
   IF (Y7_701 = -1) THEN Y7_701 = .;
   IF (Y7_702 = -1) THEN Y7_702 = .;
   IF (Y7_703 = -1) THEN Y7_703 = .;
   IF (Y7_704 = -1) THEN Y7_704 = .;
   IF (Y7_705 = -1) THEN Y7_705 = .;
   IF (Y7_706 = -1) THEN Y7_706 = .;
   IF (Y7_707 = -1) THEN Y7_707 = .;
   IF (Y7_708 = -1) THEN Y7_708 = .;
   IF (Y7_709 = -1) THEN Y7_709 = .;
   IF (Y7_710 = -1) THEN Y7_710 = .;
   IF (Y7_711 = -1) THEN Y7_711 = .;
   IF (Y7_712 = -1) THEN Y7_712 = .;
   IF (Y7_713 = -1) THEN Y7_713 = .;
   IF (Y7_714 = -1) THEN Y7_714 = .;
   IF (Y7_715 = -1) THEN Y7_715 = .;
   IF (Y7_716 = -1) THEN Y7_716 = .;
   IF (Y7_717 = -1) THEN Y7_717 = .;
   IF (Y7_718 = -1) THEN Y7_718 = .;
   IF (Y7_719 = -1) THEN Y7_719 = .;
   IF (Y7_720 = -1) THEN Y7_720 = .;
   IF (Y7_721 = -1) THEN Y7_721 = .;
   IF (Y7_722 = -1) THEN Y7_722 = .;
   IF (Y7_723 = -1) THEN Y7_723 = .;
   IF (Y7_724 = -1) THEN Y7_724 = .;
   IF (Y7_725 = -1) THEN Y7_725 = .;
   IF (Y7_726 = -1) THEN Y7_726 = .;
   IF (Y7_727 = -1) THEN Y7_727 = .;
   IF (Y7_728 = -1) THEN Y7_728 = .;
   IF (Y7_729 = -1) THEN Y7_729 = .;
   IF (Y7_730 = -1) THEN Y7_730 = .;
   IF (Y7_731 = -1) THEN Y7_731 = .;
   IF (Y7_732 = -1) THEN Y7_732 = .;
   IF (Y7_733 = -1) THEN Y7_733 = .;
   IF (Y7_734 = -1) THEN Y7_734 = .;
   IF (Y7_735 = -1) THEN Y7_735 = .;
   IF (Y7_736 = -1) THEN Y7_736 = .;
   IF (Y7_737 = -1) THEN Y7_737 = .;
   IF (Y7_738 = -1) THEN Y7_738 = .;
   IF (Y7_739 = -1) THEN Y7_739 = .;
   IF (Y7_740 = -1) THEN Y7_740 = .;
   IF (Y7_741 = -1) THEN Y7_741 = .;
   IF (Y7_742 = -1) THEN Y7_742 = .;
   IF (Y7_743 = -1) THEN Y7_743 = .;
   IF (Y7_744 = -1) THEN Y7_744 = .;
   IF (Y7_745 = -1) THEN Y7_745 = .;
   IF (Y7_746 = -1) THEN Y7_746 = .;
   IF (Y7_747 = -1) THEN Y7_747 = .;
   IF (Y7_748 = -1) THEN Y7_748 = .;
   IF (Y7_749 = -1) THEN Y7_749 = .;
   IF (Y7_750 = -1) THEN Y7_750 = .;
   IF (Y7_751 = -1) THEN Y7_751 = .;
   IF (Y7_752 = -1) THEN Y7_752 = .;
   IF (Y7_753 = -1) THEN Y7_753 = .;
   IF (Y7_754 = -1) THEN Y7_754 = .;
   IF (Y7_755 = -1) THEN Y7_755 = .;
   IF (Y7_756 = -1) THEN Y7_756 = .;
   IF (Y7_757 = -1) THEN Y7_757 = .;
   IF (Y7_758 = -1) THEN Y7_758 = .;
   IF (Y7_759 = -1) THEN Y7_759 = .;
   IF (Y7_760 = -1) THEN Y7_760 = .;
   IF (Y7_761 = -1) THEN Y7_761 = .;
   IF (Y7_762 = -1) THEN Y7_762 = .;
   IF (Y7_763 = -1) THEN Y7_763 = .;
   IF (Y7_764 = -1) THEN Y7_764 = .;
   IF (Y7_765 = -1) THEN Y7_765 = .;
   IF (Y7_766 = -1) THEN Y7_766 = .;
   IF (Y7_767 = -1) THEN Y7_767 = .;
   IF (Y7_768 = -1) THEN Y7_768 = .;
   IF (Y7_769 = -1) THEN Y7_769 = .;
   IF (Y7_770 = -1) THEN Y7_770 = .;
   IF (Y7_771 = -1) THEN Y7_771 = .;
   IF (Y7_772 = -1) THEN Y7_772 = .;
   IF (Y7_773 = -1) THEN Y7_773 = .;
   IF (Y7_774 = -1) THEN Y7_774 = .;
   IF (Y7_775 = -1) THEN Y7_775 = .;
   IF (Y7_776 = -1) THEN Y7_776 = .;
   IF (Y7_777 = -1) THEN Y7_777 = .;
   IF (Y7_778 = -1) THEN Y7_778 = .;
   IF (Y7_779 = -1) THEN Y7_779 = .;
   IF (Y7_780 = -1) THEN Y7_780 = .;
   IF (Y7_781 = -1) THEN Y7_781 = .;
   IF (Y7_782 = -1) THEN Y7_782 = .;
   IF (Y7_783 = -1) THEN Y7_783 = .;
   IF (Y7_784 = -1) THEN Y7_784 = .;
   IF (Y7_785 = -1) THEN Y7_785 = .;
   IF (Y7_786 = -1) THEN Y7_786 = .;
   IF (Y7_787 = -1) THEN Y7_787 = .;
   IF (Y7_788 = -1) THEN Y7_788 = .;
   IF (Y7_789 = -1) THEN Y7_789 = .;
   IF (Y7_790 = -1) THEN Y7_790 = .;
   IF (Y7_791 = -1) THEN Y7_791 = .;
   IF (Y7_792 = -1) THEN Y7_792 = .;
   IF (Y7_793 = -1) THEN Y7_793 = .;
   IF (Y7_794 = -1) THEN Y7_794 = .;
   IF (Y7_795 = -1) THEN Y7_795 = .;
   IF (Y7_796 = -1) THEN Y7_796 = .;
   IF (Y7_797 = -1) THEN Y7_797 = .;
   IF (Y7_798 = -1) THEN Y7_798 = .;
   IF (Y7_799 = -1) THEN Y7_799 = .;
   IF (Y7_800 = -1) THEN Y7_800 = .;
   IF (Y7_801 = -1) THEN Y7_801 = .;
   IF (Y7_802 = -1) THEN Y7_802 = .;
   IF (Y7_803 = -1) THEN Y7_803 = .;
   IF (Y7_804 = -1) THEN Y7_804 = .;
   IF (Y7_805 = -1) THEN Y7_805 = .;
   IF (Y7_806 = -1) THEN Y7_806 = .;
   IF (Y7_807 = -1) THEN Y7_807 = .;
   IF (Y7_808 = -1) THEN Y7_808 = .;
   IF (Y7_809 = -1) THEN Y7_809 = .;
   IF (Y7_810 = -1) THEN Y7_810 = .;
   IF (Y7_811 = -1) THEN Y7_811 = .;
   IF (Y7_812 = -1) THEN Y7_812 = .;
   IF (Y7_813 = -1) THEN Y7_813 = .;
   IF (Y7_814 = -1) THEN Y7_814 = .;
   IF (Y7_815 = -1) THEN Y7_815 = .;
   IF (Y7_816 = -1) THEN Y7_816 = .;
   IF (Y7_817 = -1) THEN Y7_817 = .;
   IF (Y7_818 = -1) THEN Y7_818 = .;
   IF (Y7_819 = -1) THEN Y7_819 = .;
   IF (Y7_820 = -1) THEN Y7_820 = .;
   IF (Y7_821 = -1) THEN Y7_821 = .;
   IF (Y7_822 = -1) THEN Y7_822 = .;
   IF (Y7_823 = -1) THEN Y7_823 = .;
   IF (Y7_824 = -1) THEN Y7_824 = .;
   IF (Y7_825 = -1) THEN Y7_825 = .;
   IF (Y7_826 = -1) THEN Y7_826 = .;
   IF (Y7_827 = -1) THEN Y7_827 = .;
   IF (Y7_828 = -1) THEN Y7_828 = .;
   IF (Y7_829 = -1) THEN Y7_829 = .;
   IF (Y7_830 = -1) THEN Y7_830 = .;
   IF (Y7_831 = -1) THEN Y7_831 = .;
   IF (Y7_832 = -1) THEN Y7_832 = .;
   IF (Y7_833 = -1) THEN Y7_833 = .;
   IF (Y7_834 = -1) THEN Y7_834 = .;
   IF (Y7_835 = -1) THEN Y7_835 = .;
   IF (Y7_836 = -1) THEN Y7_836 = .;
   IF (Y7_837 = -1) THEN Y7_837 = .;
   IF (Y7_838 = -1) THEN Y7_838 = .;
   IF (Y7_839 = -1) THEN Y7_839 = .;
   IF (Y7_840 = -1) THEN Y7_840 = .;
   IF (Y7_841 = -1) THEN Y7_841 = .;
   IF (Y7_842 = -1) THEN Y7_842 = .;
   IF (Y7_843 = -1) THEN Y7_843 = .;
   IF (Y7_844 = -1) THEN Y7_844 = .;
   IF (Y7_845 = -1) THEN Y7_845 = .;
   IF (Y7_846 = -1) THEN Y7_846 = .;
   IF (Y7_847 = -1) THEN Y7_847 = .;
   IF (Y7_848 = -1) THEN Y7_848 = .;
   IF (Y7_849 = -1) THEN Y7_849 = .;
   IF (Y7_850 = -1) THEN Y7_850 = .;
   IF (Y7_851 = -1) THEN Y7_851 = .;
   IF (Y7_852 = -1) THEN Y7_852 = .;
   IF (Y7_853 = -1) THEN Y7_853 = .;
   IF (Y7_854 = -1) THEN Y7_854 = .;
   IF (Y7_855 = -1) THEN Y7_855 = .;
   IF (Y7_856 = -1) THEN Y7_856 = .;
   IF (Y7_857 = -1) THEN Y7_857 = .;
   IF (Y7_858 = -1) THEN Y7_858 = .;
   IF (Y7_859 = -1) THEN Y7_859 = .;
   IF (Y7_860 = -1) THEN Y7_860 = .;
   IF (Y7_861 = -1) THEN Y7_861 = .;
   IF (Y7_862 = -1) THEN Y7_862 = .;
   IF (Y7_863 = -1) THEN Y7_863 = .;
   IF (Y7_864 = -1) THEN Y7_864 = .;
   IF (Y7_865 = -1) THEN Y7_865 = .;
   IF (Y7_866 = -1) THEN Y7_866 = .;
   IF (Y7_867 = -1) THEN Y7_867 = .;
   IF (Y7_868 = -1) THEN Y7_868 = .;
   IF (Y7_869 = -1) THEN Y7_869 = .;
   IF (Y7_870 = -1) THEN Y7_870 = .;
   IF (Y7_871 = -1) THEN Y7_871 = .;
   IF (Y7_872 = -1) THEN Y7_872 = .;
   IF (Y7_873 = -1) THEN Y7_873 = .;
   IF (Y7_874 = -1) THEN Y7_874 = .;
   IF (Y7_875 = -1) THEN Y7_875 = .;
   IF (Y7_876 = -1) THEN Y7_876 = .;
   IF (Y7_877 = -1) THEN Y7_877 = .;
   IF (Y7_878 = -1) THEN Y7_878 = .;
   IF (Y7_879 = -1) THEN Y7_879 = .;
   IF (Y7_880 = -1) THEN Y7_880 = .;
   IF (Y7_881 = -1) THEN Y7_881 = .;
   IF (Y7_882 = -1) THEN Y7_882 = .;
   IF (Y7_883 = -1) THEN Y7_883 = .;
   IF (Y7_884 = -1) THEN Y7_884 = .;
   IF (Y7_885 = -1) THEN Y7_885 = .;
   IF (Y7_886 = -1) THEN Y7_886 = .;
   IF (Y7_887 = -1) THEN Y7_887 = .;
   IF (Y7_888 = -1) THEN Y7_888 = .;
   IF (Y7_889 = -1) THEN Y7_889 = .;
   IF (Y7_890 = -1) THEN Y7_890 = .;
   IF (Y7_891 = -1) THEN Y7_891 = .;
   IF (Y7_892 = -1) THEN Y7_892 = .;
   IF (Y7_893 = -1) THEN Y7_893 = .;
   IF (Y7_894 = -1) THEN Y7_894 = .;
   IF (Y7_895 = -1) THEN Y7_895 = .;
   IF (Y7_896 = -1) THEN Y7_896 = .;
   IF (Y7_897 = -1) THEN Y7_897 = .;
   IF (Y7_898 = -1) THEN Y7_898 = .;
   IF (Y7_899 = -1) THEN Y7_899 = .;
   IF (Y7_900 = -1) THEN Y7_900 = .;
   IF (Y7_901 = -1) THEN Y7_901 = .;
   IF (Y7_902 = -1) THEN Y7_902 = .;
   IF (Y7_903 = -1) THEN Y7_903 = .;
   IF (Y7_904 = -1) THEN Y7_904 = .;
   IF (Y7_905 = -1) THEN Y7_905 = .;
   IF (Y7_906 = -1) THEN Y7_906 = .;
   IF (Y7_907 = -1) THEN Y7_907 = .;
   IF (Y7_908 = -1) THEN Y7_908 = .;
   IF (Y7_909 = -1) THEN Y7_909 = .;
   IF (Y7_910 = -1) THEN Y7_910 = .;
   IF (Y7_911 = -1) THEN Y7_911 = .;
   IF (Y7_912 = -1) THEN Y7_912 = .;
   IF (Y7_913 = -1) THEN Y7_913 = .;
   IF (Y7_914 = -1) THEN Y7_914 = .;
   IF (Y7_915 = -1) THEN Y7_915 = .;
   IF (Y7_916 = -1) THEN Y7_916 = .;
   IF (Y7_917 = -1) THEN Y7_917 = .;
   IF (Y7_918 = -1) THEN Y7_918 = .;
   IF (Y7_919 = -1) THEN Y7_919 = .;
   IF (Y7_920 = -1) THEN Y7_920 = .;
   IF (Y7_921 = -1) THEN Y7_921 = .;
   IF (Y7_922 = -1) THEN Y7_922 = .;
   IF (Y7_923 = -1) THEN Y7_923 = .;
   IF (Y7_924 = -1) THEN Y7_924 = .;
   IF (Y7_925 = -1) THEN Y7_925 = .;
   IF (Y7_926 = -1) THEN Y7_926 = .;
   IF (Y7_927 = -1) THEN Y7_927 = .;
   IF (Y7_928 = -1) THEN Y7_928 = .;
   IF (Y7_929 = -1) THEN Y7_929 = .;
   IF (Y7_930 = -1) THEN Y7_930 = .;
   IF (Y7_931 = -1) THEN Y7_931 = .;
   IF (Y7_932 = -1) THEN Y7_932 = .;
   IF (Y7_933 = -1) THEN Y7_933 = .;
   IF (Y7_934 = -1) THEN Y7_934 = .;
   IF (Y7_935 = -1) THEN Y7_935 = .;
   IF (Y7_936 = -1) THEN Y7_936 = .;
   IF (Y7_937 = -1) THEN Y7_937 = .;
   IF (Y7_938 = -1) THEN Y7_938 = .;
   IF (Y7_939 = -1) THEN Y7_939 = .;
   IF (Y7_940 = -1) THEN Y7_940 = .;
   IF (Y7_941 = -1) THEN Y7_941 = .;
   IF (Y7_942 = -1) THEN Y7_942 = .;
   IF (Y7_943 = -1) THEN Y7_943 = .;
   IF (Y7_944 = -1) THEN Y7_944 = .;
   IF (Y7_945 = -1) THEN Y7_945 = .;
   IF (Y7_946 = -1) THEN Y7_946 = .;
   IF (Y7_947 = -1) THEN Y7_947 = .;
   IF (Y7_948 = -1) THEN Y7_948 = .;
   IF (Y7_949 = -1) THEN Y7_949 = .;
   IF (Y7_950 = -1) THEN Y7_950 = .;
   IF (Y7_951 = -1) THEN Y7_951 = .;
   IF (Y7_952 = -1) THEN Y7_952 = .;
   IF (Y7_953 = -1) THEN Y7_953 = .;
   IF (Y7_954 = -1) THEN Y7_954 = .;
   IF (Y7_955 = -1) THEN Y7_955 = .;
   IF (Y7_956 = -1) THEN Y7_956 = .;
   IF (Y7_957 = -1) THEN Y7_957 = .;
   IF (Y7_958 = -1) THEN Y7_958 = .;
   IF (Y7_959 = -1) THEN Y7_959 = .;
   IF (Y7_960 = -1) THEN Y7_960 = .;
   IF (Y7_961 = -1) THEN Y7_961 = .;
   IF (Y7_962 = -1) THEN Y7_962 = .;
   IF (Y7_963 = -1) THEN Y7_963 = .;
   IF (Y7_964 = -1) THEN Y7_964 = .;
   IF (Y7_965 = -1) THEN Y7_965 = .;
   IF (Y7_966 = -1) THEN Y7_966 = .;
   IF (Y7_967 = -1) THEN Y7_967 = .;
   IF (Y7_968 = -1) THEN Y7_968 = .;
   IF (Y7_969 = -1) THEN Y7_969 = .;
   IF (Y7_970 = -1) THEN Y7_970 = .;
   IF (Y7_971 = -1) THEN Y7_971 = .;
   IF (Y7_972 = -1) THEN Y7_972 = .;
   IF (Y7_973 = -1) THEN Y7_973 = .;
   IF (Y7_974 = -1) THEN Y7_974 = .;
   IF (Y7_975 = -1) THEN Y7_975 = .;
   IF (Y7_976 = -1) THEN Y7_976 = .;
   IF (Y7_977 = -1) THEN Y7_977 = .;
   IF (Y7_978 = -1) THEN Y7_978 = .;
   IF (Y7_979 = -1) THEN Y7_979 = .;
   IF (Y7_980 = -1) THEN Y7_980 = .;
   IF (Y7_981 = -1) THEN Y7_981 = .;
   IF (Y7_982 = -1) THEN Y7_982 = .;
   IF (Y7_983 = -1) THEN Y7_983 = .;
   IF (Y7_984 = -1) THEN Y7_984 = .;
   IF (Y7_985 = -1) THEN Y7_985 = .;
   IF (Y7_986 = -1) THEN Y7_986 = .;
   IF (Y7_987 = -1) THEN Y7_987 = .;
   IF (Y7_988 = -1) THEN Y7_988 = .;
   IF (Y7_989 = -1) THEN Y7_989 = .;
   IF (Y7_990 = -1) THEN Y7_990 = .;
   IF (Y7_991 = -1) THEN Y7_991 = .;
   IF (Y7_992 = -1) THEN Y7_992 = .;
   IF (Y7_993 = -1) THEN Y7_993 = .;
   IF (Y7_994 = -1) THEN Y7_994 = .;
   IF (Y7_995 = -1) THEN Y7_995 = .;
   IF (Y7_996 = -1) THEN Y7_996 = .;
   IF (Y7_997 = -1) THEN Y7_997 = .;
   IF (Y7_998 = -1) THEN Y7_998 = .;
   IF (Y7_999 = -1) THEN Y7_999 = .;
   IF (Y7_1000 = -1) THEN Y7_1000 = .;
   IF (Y7_1001 = -1) THEN Y7_1001 = .;
   IF (Y7_1002 = -1) THEN Y7_1002 = .;
   IF (Y7_1003 = -1) THEN Y7_1003 = .;
   IF (Y7_1004 = -1) THEN Y7_1004 = .;
   IF (Y7_1005 = -1) THEN Y7_1005 = .;
   IF (Y7_1006 = -1) THEN Y7_1006 = .;
   IF (Y7_1007 = -1) THEN Y7_1007 = .;
   IF (Y7_1008 = -1) THEN Y7_1008 = .;
   IF (Y7_1009 = -1) THEN Y7_1009 = .;
   IF (Y7_1010 = -1) THEN Y7_1010 = .;
   IF (Y7_1011 = -1) THEN Y7_1011 = .;
   IF (Y7_1012 = -1) THEN Y7_1012 = .;
   IF (Y7_1013 = -1) THEN Y7_1013 = .;
   IF (Y7_1014 = -1) THEN Y7_1014 = .;
   IF (Y7_1015 = -1) THEN Y7_1015 = .;
   IF (Y7_1016 = -1) THEN Y7_1016 = .;
   IF (Y7_1017 = -1) THEN Y7_1017 = .;
   IF (Y7_1018 = -1) THEN Y7_1018 = .;
   IF (Y7_1019 = -1) THEN Y7_1019 = .;
   IF (Y7_1020 = -1) THEN Y7_1020 = .;
   IF (Y7_1021 = -1) THEN Y7_1021 = .;
   IF (Y7_1022 = -1) THEN Y7_1022 = .;
   IF (Y7_1023 = -1) THEN Y7_1023 = .;
   IF (Y7_1024 = -1) THEN Y7_1024 = .;
   IF (Y7_1025 = -1) THEN Y7_1025 = .;
   IF (Y7_1026 = -1) THEN Y7_1026 = .;
   IF (Y7_1027 = -1) THEN Y7_1027 = .;
   IF (Y7_1028 = -1) THEN Y7_1028 = .;
   IF (Y7_1029 = -1) THEN Y7_1029 = .;
   IF (Y7_1030 = -1) THEN Y7_1030 = .;
   IF (Y7_1031 = -1) THEN Y7_1031 = .;
   IF (Y7_1032 = -1) THEN Y7_1032 = .;
   IF (Y7_1033 = -1) THEN Y7_1033 = .;
   IF (Y7_1034 = -1) THEN Y7_1034 = .;
   IF (Y7_1035 = -1) THEN Y7_1035 = .;
   IF (Y7_1036 = -1) THEN Y7_1036 = .;
   IF (Y7_1037 = -1) THEN Y7_1037 = .;
   IF (Y7_1038 = -1) THEN Y7_1038 = .;
   IF (Y7_1039 = -1) THEN Y7_1039 = .;
   IF (Y7_1040 = -1) THEN Y7_1040 = .;
   IF (Y7_1041 = -1) THEN Y7_1041 = .;
   IF (Y7_1042 = -1) THEN Y7_1042 = .;
   IF (Y7_1043 = -1) THEN Y7_1043 = .;
   IF (Y7_1044 = -1) THEN Y7_1044 = .;
   IF (Y7_1045 = -1) THEN Y7_1045 = .;
   IF (Y7_1046 = -1) THEN Y7_1046 = .;
   IF (Y7_1047 = -1) THEN Y7_1047 = .;
   IF (Y7_1048 = -1) THEN Y7_1048 = .;
   IF (Y7_1049 = -1) THEN Y7_1049 = .;
   IF (Y7_1050 = -1) THEN Y7_1050 = .;
   IF (Y7_1051 = -1) THEN Y7_1051 = .;
   IF (Y7_1052 = -1) THEN Y7_1052 = .;
   IF (Y7_1053 = -1) THEN Y7_1053 = .;
   IF (Y7_1054 = -1) THEN Y7_1054 = .;
   IF (Y7_1055 = -1) THEN Y7_1055 = .;
   IF (Y7_1056 = -1) THEN Y7_1056 = .;
   IF (Y7_1057 = -1) THEN Y7_1057 = .;
   IF (Y7_1058 = -1) THEN Y7_1058 = .;
   IF (Y7_1059 = -1) THEN Y7_1059 = .;
   IF (Y7_1060 = -1) THEN Y7_1060 = .;
   IF (Y7_1061 = -1) THEN Y7_1061 = .;
   IF (Y7_1062 = -1) THEN Y7_1062 = .;
   IF (Y7_1063 = -1) THEN Y7_1063 = .;
   IF (Y7_1064 = -1) THEN Y7_1064 = .;
   IF (Y7_1065 = -1) THEN Y7_1065 = .;
   IF (Y7_1066 = -1) THEN Y7_1066 = .;
   IF (Y7_1067 = -1) THEN Y7_1067 = .;
   IF (Y7_1068 = -1) THEN Y7_1068 = .;
   IF (Y7_1069 = -1) THEN Y7_1069 = .;
   IF (Y7_1070 = -1) THEN Y7_1070 = .;
   IF (Y7_1071 = -1) THEN Y7_1071 = .;
   IF (Y7_1072 = -1) THEN Y7_1072 = .;
   IF (Y7_1073 = -1) THEN Y7_1073 = .;
   IF (Y7_1074 = -1) THEN Y7_1074 = .;
   IF (Y7_1075 = -1) THEN Y7_1075 = .;
   IF (Y7_1076 = -1) THEN Y7_1076 = .;
   IF (Y7_1077 = -1) THEN Y7_1077 = .;
   IF (Y7_1078 = -1) THEN Y7_1078 = .;
   IF (Y7_1079 = -1) THEN Y7_1079 = .;
   IF (Y7_1080 = -1) THEN Y7_1080 = .;
   IF (Y7_1081 = -1) THEN Y7_1081 = .;
   IF (Y7_1082 = -1) THEN Y7_1082 = .;
   IF (Y7_1083 = -1) THEN Y7_1083 = .;
   IF (Y7_1084 = -1) THEN Y7_1084 = .;
   IF (Y7_1085 = -1) THEN Y7_1085 = .;
   IF (Y7_1086 = -1) THEN Y7_1086 = .;
   IF (Y7_1087 = -1) THEN Y7_1087 = .;
   IF (Y7_1088 = -1) THEN Y7_1088 = .;
   IF (Y7_1089 = -1) THEN Y7_1089 = .;
   IF (Y7_1090 = -1) THEN Y7_1090 = .;
   IF (Y7_1091 = -1) THEN Y7_1091 = .;
   IF (Y7_1092 = -1) THEN Y7_1092 = .;
   IF (Y7_1093 = -1) THEN Y7_1093 = .;
   IF (Y7_1094 = -1) THEN Y7_1094 = .;
   IF (Y7_1095 = -1) THEN Y7_1095 = .;
   IF (Y7_1096 = -1) THEN Y7_1096 = .;
   IF (Y7_1097 = -1) THEN Y7_1097 = .;
   IF (Y7_1098 = -1) THEN Y7_1098 = .;
   IF (Y7_1099 = -1) THEN Y7_1099 = .;
   IF (Y7_1100 = -1) THEN Y7_1100 = .;
   IF (Y7_1101 = -1) THEN Y7_1101 = .;
   IF (Y7_1102 = -1) THEN Y7_1102 = .;
   IF (Y7_1103 = -1) THEN Y7_1103 = .;
   IF (Y7_1104 = -1) THEN Y7_1104 = .;
   IF (Y7_1105 = -1) THEN Y7_1105 = .;
   IF (Y7_1106 = -1) THEN Y7_1106 = .;
   IF (Y7_1107 = -1) THEN Y7_1107 = .;
   IF (Y7_1108 = -1) THEN Y7_1108 = .;
   IF (Y7_1109 = -1) THEN Y7_1109 = .;
   IF (Y7_1110 = -1) THEN Y7_1110 = .;
   IF (Y7_1111 = -1) THEN Y7_1111 = .;
   IF (Y7_1112 = -1) THEN Y7_1112 = .;
   IF (Y7_1113 = -1) THEN Y7_1113 = .;
   IF (Y7_1114 = -1) THEN Y7_1114 = .;
   IF (Y7_1115 = -1) THEN Y7_1115 = .;
   IF (Y7_1116 = -1) THEN Y7_1116 = .;
   IF (Y7_1117 = -1) THEN Y7_1117 = .;
   IF (Y7_1118 = -1) THEN Y7_1118 = .;
   IF (Y7_1119 = -1) THEN Y7_1119 = .;
   IF (Y7_1120 = -1) THEN Y7_1120 = .;
   IF (Y7_1121 = -1) THEN Y7_1121 = .;
   IF (Y7_1122 = -1) THEN Y7_1122 = .;
   IF (Y7_1123 = -1) THEN Y7_1123 = .;
   IF (Y7_1124 = -1) THEN Y7_1124 = .;
   IF (Y7_1125 = -1) THEN Y7_1125 = .;
   IF (Y7_1126 = -1) THEN Y7_1126 = .;
   IF (Y7_1127 = -1) THEN Y7_1127 = .;
   IF (Y7_1128 = -1) THEN Y7_1128 = .;
   IF (Y7_1129 = -1) THEN Y7_1129 = .;
   IF (Y7_1130 = -1) THEN Y7_1130 = .;
   IF (Y7_1131 = -1) THEN Y7_1131 = .;
   IF (Y7_1132 = -1) THEN Y7_1132 = .;
   IF (Y7_1133 = -1) THEN Y7_1133 = .;
   IF (Y7_1134 = -1) THEN Y7_1134 = .;
   IF (Y7_1135 = -1) THEN Y7_1135 = .;
   IF (Y7_1136 = -1) THEN Y7_1136 = .;
   IF (Y7_1137 = -1) THEN Y7_1137 = .;
   IF (Y7_1138 = -1) THEN Y7_1138 = .;
   IF (Y7_1139 = -1) THEN Y7_1139 = .;
   IF (Y7_1140 = -1) THEN Y7_1140 = .;
   IF (Y7_1141 = -1) THEN Y7_1141 = .;
   IF (Y7_1142 = -1) THEN Y7_1142 = .;
   IF (Y7_1143 = -1) THEN Y7_1143 = .;
   IF (Y7_1144 = -1) THEN Y7_1144 = .;
   IF (Y7_1145 = -1) THEN Y7_1145 = .;
   IF (Y7_1146 = -1) THEN Y7_1146 = .;
   IF (Y7_1147 = -1) THEN Y7_1147 = .;
   IF (Y7_1148 = -1) THEN Y7_1148 = .;
   IF (Y7_1149 = -1) THEN Y7_1149 = .;
   IF (Y7_1150 = -1) THEN Y7_1150 = .;
   IF (Y7_1151 = -1) THEN Y7_1151 = .;
   IF (Y7_1152 = -1) THEN Y7_1152 = .;
   IF (Y7_1153 = -1) THEN Y7_1153 = .;
   IF (Y7_1154 = -1) THEN Y7_1154 = .;
   IF (Y7_1155 = -1) THEN Y7_1155 = .;
   IF (Y7_1156 = -1) THEN Y7_1156 = .;
   IF (Y7_1157 = -1) THEN Y7_1157 = .;
   IF (Y7_1158 = -1) THEN Y7_1158 = .;
   IF (Y7_1159 = -1) THEN Y7_1159 = .;
   IF (Y7_1160 = -1) THEN Y7_1160 = .;
   IF (Y7_1161 = -1) THEN Y7_1161 = .;
   IF (Y7_1162 = -1) THEN Y7_1162 = .;
   IF (Y7_1163 = -1) THEN Y7_1163 = .;
   IF (Y7_1164 = -1) THEN Y7_1164 = .;
   IF (Y7_1165 = -1) THEN Y7_1165 = .;
   IF (Y7_1166 = -1) THEN Y7_1166 = .;
   IF (Y7_1167 = -1) THEN Y7_1167 = .;
   IF (Y7_1168 = -1) THEN Y7_1168 = .;
   IF (Y7_1169 = -1) THEN Y7_1169 = .;
   IF (Y7_1170 = -1) THEN Y7_1170 = .;
   IF (Y7_1171 = -1) THEN Y7_1171 = .;
   IF (Y7_1172 = -1) THEN Y7_1172 = .;
   IF (Y7_1173 = -1) THEN Y7_1173 = .;
   IF (Y7_1174 = -1) THEN Y7_1174 = .;
   IF (Y7_1175 = -1) THEN Y7_1175 = .;
   IF (Y7_1176 = -1) THEN Y7_1176 = .;
   IF (Y7_1177 = -1) THEN Y7_1177 = .;
   IF (Y7_1178 = -1) THEN Y7_1178 = .;
   IF (Y7_1179 = -1) THEN Y7_1179 = .;
   IF (Y7_1180 = -1) THEN Y7_1180 = .;
   IF (Y7_1181 = -1) THEN Y7_1181 = .;
   IF (Y7_1182 = -1) THEN Y7_1182 = .;
   IF (Y7_1183 = -1) THEN Y7_1183 = .;
   IF (Y7_1184 = -1) THEN Y7_1184 = .;
   IF (Y7_1185 = -1) THEN Y7_1185 = .;
   IF (Y7_1186 = -1) THEN Y7_1186 = .;
   IF (Y7_1187 = -1) THEN Y7_1187 = .;
   IF (Y7_1188 = -1) THEN Y7_1188 = .;
   IF (Y7_1189 = -1) THEN Y7_1189 = .;
   IF (Y7_1190 = -1) THEN Y7_1190 = .;
   IF (Y7_1191 = -1) THEN Y7_1191 = .;
   IF (Y7_1192 = -1) THEN Y7_1192 = .;
   IF (Y7_1193 = -1) THEN Y7_1193 = .;
   IF (Y7_1194 = -1) THEN Y7_1194 = .;
   IF (Y7_1195 = -1) THEN Y7_1195 = .;
   IF (Y7_1197 = -1) THEN Y7_1197 = .;
   IF (Y7_1198 = -1) THEN Y7_1198 = .;
   IF (Y7_1199 = -1) THEN Y7_1199 = .;
   IF (Y7_1200 = -1) THEN Y7_1200 = .;
   IF (Y7_1201 = -1) THEN Y7_1201 = .;
   IF (Y7_1202 = -1) THEN Y7_1202 = .;
   IF (Y7_1203 = -1) THEN Y7_1203 = .;
   IF (Y7_1204 = -1) THEN Y7_1204 = .;
   IF (Y7_1205 = -1) THEN Y7_1205 = .;
   IF (Y7_1206 = -1) THEN Y7_1206 = .;
   IF (Y7_1207 = -1) THEN Y7_1207 = .;
   IF (Y7_1208 = -1) THEN Y7_1208 = .;
   IF (Y7_1209 = -1) THEN Y7_1209 = .;
   IF (Y7_1210 = -1) THEN Y7_1210 = .;
   IF (Y7_1211 = -1) THEN Y7_1211 = .;
   IF (Y7_1212 = -1) THEN Y7_1212 = .;
   IF (Y7_1213 = -1) THEN Y7_1213 = .;
   IF (Y7_1214 = -1) THEN Y7_1214 = .;
   IF (Y7_1215 = -1) THEN Y7_1215 = .;
   IF (Y7_1216 = -1) THEN Y7_1216 = .;
   IF (Y7_1217 = -1) THEN Y7_1217 = .;
   IF (Y7_1218 = -1) THEN Y7_1218 = .;
   IF (Y7_1219 = -1) THEN Y7_1219 = .;
   IF (Y7_1220 = -1) THEN Y7_1220 = .;
   IF (Y7_1221 = -1) THEN Y7_1221 = .;
   IF (Y7_1222 = -1) THEN Y7_1222 = .;
   IF (Y7_1223 = -1) THEN Y7_1223 = .;
   IF (Y7_1224 = -1) THEN Y7_1224 = .;
   IF (Y7_1225 = -1) THEN Y7_1225 = .;
   IF (Y7_1226 = -1) THEN Y7_1226 = .;
   IF (Y7_1227 = -1) THEN Y7_1227 = .;
   IF (Y7_1228 = -1) THEN Y7_1228 = .;
   IF (Y7_1229 = -1) THEN Y7_1229 = .;
   IF (Y7_1230 = -1) THEN Y7_1230 = .;
   IF (Y7_1231 = -1) THEN Y7_1231 = .;
   IF (Y7_1232 = -1) THEN Y7_1232 = .;
   IF (Y7_1233 = -1) THEN Y7_1233 = .;
   IF (Y7_1234 = -1) THEN Y7_1234 = .;
   IF (Y7_1235 = -1) THEN Y7_1235 = .;
   IF (Y7_1236 = -1) THEN Y7_1236 = .;
   IF (Y7_1237 = -1) THEN Y7_1237 = .;
   IF (Y7_1238 = -1) THEN Y7_1238 = .;
   IF (Y7_1239 = -1) THEN Y7_1239 = .;
   IF (Y7_1240 = -1) THEN Y7_1240 = .;
   IF (Y7_1241 = -1) THEN Y7_1241 = .;
   IF (Y7_1242 = -1) THEN Y7_1242 = .;
   IF (Y7_1243 = -1) THEN Y7_1243 = .;
   IF (Y7_1244 = -1) THEN Y7_1244 = .;
   IF (Y7_1245 = -1) THEN Y7_1245 = .;
   IF (Y7_1246 = -1) THEN Y7_1246 = .;
   IF (Y7_1247 = -1) THEN Y7_1247 = .;
   IF (Y7_1248 = -1) THEN Y7_1248 = .;
   IF (Y7_1249 = -1) THEN Y7_1249 = .;
   IF (Y7_1250 = -1) THEN Y7_1250 = .;
   IF (Y7_1251 = -1) THEN Y7_1251 = .;
   IF (Y7_1252 = -1) THEN Y7_1252 = .;
   IF (Y7_1253 = -1) THEN Y7_1253 = .;
   IF (Y7_1254 = -1) THEN Y7_1254 = .;
   IF (Y7_1255 = -1) THEN Y7_1255 = .;
   IF (Y7_1256 = -1) THEN Y7_1256 = .;
   IF (Y7_1257 = -1) THEN Y7_1257 = .;
   IF (Y7_1258 = -1) THEN Y7_1258 = .;
   IF (Y7_1259 = -1) THEN Y7_1259 = .;
   IF (Y7_1260 = -1) THEN Y7_1260 = .;
   IF (Y7_1261 = -1) THEN Y7_1261 = .;
   IF (Y7_1262 = -1) THEN Y7_1262 = .;
   IF (Y7_1263 = -1) THEN Y7_1263 = .;
   IF (Y7_1264 = -1) THEN Y7_1264 = .;
   IF (Y7_1265 = -1) THEN Y7_1265 = .;
   IF (Y7_1266 = -1) THEN Y7_1266 = .;
   IF (Y7_1267 = -1) THEN Y7_1267 = .;
   IF (Y7_1268 = -1) THEN Y7_1268 = .;
   IF (Y7_1269 = -1) THEN Y7_1269 = .;
   IF (Y7_1270 = -1) THEN Y7_1270 = .;
   IF (Y7_1271 = -1) THEN Y7_1271 = .;
   IF (Y7_1272 = -1) THEN Y7_1272 = .;
   IF (Y7_1273 = -1) THEN Y7_1273 = .;
   IF (Y7_1274 = -1) THEN Y7_1274 = .;
   IF (Y7_1275 = -1) THEN Y7_1275 = .;
   IF (Y7_1276 = -1) THEN Y7_1276 = .;
   IF (Y7_1277 = -1) THEN Y7_1277 = .;
   IF (Y7_1278 = -1) THEN Y7_1278 = .;
   IF (Y7_1279 = -1) THEN Y7_1279 = .;
   IF (Y7_1280 = -1) THEN Y7_1280 = .;
   IF (Y7_1281 = -1) THEN Y7_1281 = .;
   IF (Y7_1282 = -1) THEN Y7_1282 = .;
   IF (Y7_1283 = -1) THEN Y7_1283 = .;
   IF (Y7_1284 = -1) THEN Y7_1284 = .;
   IF (Y7_1285 = -1) THEN Y7_1285 = .;
   IF (Y7_1286 = -1) THEN Y7_1286 = .;
   IF (Y7_1287 = -1) THEN Y7_1287 = .;
   IF (Y7_1288 = -1) THEN Y7_1288 = .;
   IF (Y7_1289 = -1) THEN Y7_1289 = .;
   IF (Y7_1290 = -1) THEN Y7_1290 = .;
   IF (Y7_1291 = -1) THEN Y7_1291 = .;
   IF (Y7_1292 = -1) THEN Y7_1292 = .;
   IF (Y7_1293 = -1) THEN Y7_1293 = .;
   IF (Y7_1294 = -1) THEN Y7_1294 = .;
   IF (Y7_1295 = -1) THEN Y7_1295 = .;
   IF (Y7_1296 = -1) THEN Y7_1296 = .;
   IF (Y7_1297 = -1) THEN Y7_1297 = .;
   IF (Y7_1298 = -1) THEN Y7_1298 = .;
   IF (Y7_1299 = -1) THEN Y7_1299 = .;
   IF (Y7_1300 = -1) THEN Y7_1300 = .;
   IF (Y7_1301 = -1) THEN Y7_1301 = .;
   IF (Y7_1302 = -1) THEN Y7_1302 = .;
   IF (Y7_1303 = -1) THEN Y7_1303 = .;
   IF (Y7_1304 = -1) THEN Y7_1304 = .;
   IF (Y7_1305 = -1) THEN Y7_1305 = .;
   IF (Y7_1306 = -1) THEN Y7_1306 = .;
   IF (Y7_1307 = -1) THEN Y7_1307 = .;
   IF (Y7_1308 = -1) THEN Y7_1308 = .;
   IF (Y7_1309 = -1) THEN Y7_1309 = .;
   IF (Y7_1310 = -1) THEN Y7_1310 = .;
   IF (Y7_1311 = -1) THEN Y7_1311 = .;
   IF (Y7_1312 = -1) THEN Y7_1312 = .;
   IF (Y7_1313 = -1) THEN Y7_1313 = .;
   IF (Y7_1314 = -1) THEN Y7_1314 = .;
   IF (Y7_1315 = -1) THEN Y7_1315 = .;
   IF (Y7_1316 = -1) THEN Y7_1316 = .;
   IF (Y7_1317 = -1) THEN Y7_1317 = .;
   IF (Y7_1318 = -1) THEN Y7_1318 = .;
   IF (Y7_1319 = -1) THEN Y7_1319 = .;
   IF (Y7_1320 = -1) THEN Y7_1320 = .;
   IF (Y7_1321 = -1) THEN Y7_1321 = .;
   IF (Y7_1322 = -1) THEN Y7_1322 = .;
   IF (Y7_1323 = -1) THEN Y7_1323 = .;
   IF (Y7_1324 = -1) THEN Y7_1324 = .;
   IF (Y7_1325 = -1) THEN Y7_1325 = .;
   IF (Y7_1326 = -1) THEN Y7_1326 = .;
   IF (Y7_1327 = -1) THEN Y7_1327 = .;
   IF (Y7_1328 = -1) THEN Y7_1328 = .;
   IF (Y7_1329 = -1) THEN Y7_1329 = .;
   IF (Y7_1330 = -1) THEN Y7_1330 = .;
   IF (Y7_1331 = -1) THEN Y7_1331 = .;
   IF (Y7_1332 = -1) THEN Y7_1332 = .;
   IF (Y7_1333 = -1) THEN Y7_1333 = .;
   IF (Y7_1334 = -1) THEN Y7_1334 = .;
   IF (Y7_1335 = -1) THEN Y7_1335 = .;
   IF (Y7_1336 = -1) THEN Y7_1336 = .;
   IF (Y7_1337 = -1) THEN Y7_1337 = .;
   IF (Y7_1338 = -1) THEN Y7_1338 = .;
   IF (Y7_1339 = -1) THEN Y7_1339 = .;
   IF (Y7_1340 = -1) THEN Y7_1340 = .;
   IF (Y7_1341 = -1) THEN Y7_1341 = .;
   IF (Y7_1342 = -1) THEN Y7_1342 = .;
   IF (Y7_1343 = -1) THEN Y7_1343 = .;
   IF (Y7_1344 = -1) THEN Y7_1344 = .;
   IF (Y7_1345 = -1) THEN Y7_1345 = .;
   IF (Y7_1346 = -1) THEN Y7_1346 = .;
   IF (Y7_1347 = -1) THEN Y7_1347 = .;
   IF (Y7_1348 = -1) THEN Y7_1348 = .;
   IF (Y7_1349 = -1) THEN Y7_1349 = .;
   IF (Y7_1350 = -1) THEN Y7_1350 = .;
   IF (Y7_1351 = -1) THEN Y7_1351 = .;
   IF (Y7_1352 = -1) THEN Y7_1352 = .;
   IF (Y7_1353 = -1) THEN Y7_1353 = .;
   IF (Y7_1354 = -1) THEN Y7_1354 = .;
   IF (Y7_1355 = -1) THEN Y7_1355 = .;
   IF (Y7_1356 = -1) THEN Y7_1356 = .;
   IF (Y7_1357 = -1) THEN Y7_1357 = .;
   IF (Y7_1358 = -1) THEN Y7_1358 = .;
   IF (Y7_1359 = -1) THEN Y7_1359 = .;
   IF (Y7_1360 = -1) THEN Y7_1360 = .;
   IF (Y7_1361 = -1) THEN Y7_1361 = .;
   IF (Y7_1362 = -1) THEN Y7_1362 = .;
   IF (Y7_1363 = -1) THEN Y7_1363 = .;
   IF (Y7_1364 = -1) THEN Y7_1364 = .;
   IF (Y7_1365 = -1) THEN Y7_1365 = .;
   IF (Y7_1366 = -1) THEN Y7_1366 = .;
   IF (Y7_1367 = -1) THEN Y7_1367 = .;
   IF (Y7_1368 = -1) THEN Y7_1368 = .;
   IF (Y7_1369 = -1) THEN Y7_1369 = .;
   IF (Y7_1370 = -1) THEN Y7_1370 = .;
   IF (Y7_1371 = -1) THEN Y7_1371 = .;
   IF (Y7_1372 = -1) THEN Y7_1372 = .;
   IF (Y7_1373 = -1) THEN Y7_1373 = .;
   IF (Y7_1374 = -1) THEN Y7_1374 = .;
   IF (Y7_1375 = -1) THEN Y7_1375 = .;
   IF (Y7_1376 = -1) THEN Y7_1376 = .;
   IF (Y7_1377 = -1) THEN Y7_1377 = .;
   IF (Y7_1378 = -1) THEN Y7_1378 = .;
   IF (Y7_1379 = -1) THEN Y7_1379 = .;
   IF (Y7_1380 = -1) THEN Y7_1380 = .;
   IF (Y7_1381 = -1) THEN Y7_1381 = .;
   IF (Y7_1382 = -1) THEN Y7_1382 = .;
   IF (Y7_1383 = -1) THEN Y7_1383 = .;
   IF (Y7_1384 = -1) THEN Y7_1384 = .;
   IF (Y7_1385 = -1) THEN Y7_1385 = .;
   IF (Y7_1386 = -1) THEN Y7_1386 = .;
   IF (Y7_1387 = -1) THEN Y7_1387 = .;
   IF (Y7_1388 = -1) THEN Y7_1388 = .;
   IF (Y7_1389 = -1) THEN Y7_1389 = .;
   IF (Y7_1390 = -1) THEN Y7_1390 = .;
   IF (Y7_1391 = -1) THEN Y7_1391 = .;
   IF (Y7_1392 = -1) THEN Y7_1392 = .;
   IF (Y7_1393 = -1) THEN Y7_1393 = .;
   IF (Y7_1394 = -1) THEN Y7_1394 = .;
   IF (Y7_1395 = -1) THEN Y7_1395 = .;
   IF (Y7_1396 = -1) THEN Y7_1396 = .;
   IF (Y7_1397 = -1) THEN Y7_1397 = .;
   IF (Y7_1398 = -1) THEN Y7_1398 = .;
   IF (Y7_1399 = -1) THEN Y7_1399 = .;
   IF (Y7_1400 = -1) THEN Y7_1400 = .;
   IF (Y7_1401 = -1) THEN Y7_1401 = .;
   IF (Y7_1402 = -1) THEN Y7_1402 = .;
   IF (Y7_1403 = -1) THEN Y7_1403 = .;
   IF (Y7_1404 = -1) THEN Y7_1404 = .;
   IF (Y7_1405 = -1) THEN Y7_1405 = .;
   IF (Y7_1406 = -1) THEN Y7_1406 = .;
   IF (Y7_1407 = -1) THEN Y7_1407 = .;
   IF (Y7_1408 = -1) THEN Y7_1408 = .;
   IF (Y7_1409 = -1) THEN Y7_1409 = .;
   IF (Y7_1410 = -1) THEN Y7_1410 = .;
   IF (Y7_1411 = -1) THEN Y7_1411 = .;
   IF (Y7_1412 = -1) THEN Y7_1412 = .;
   IF (Y7_1413 = -1) THEN Y7_1413 = .;
   IF (Y7_1414 = -1) THEN Y7_1414 = .;
   IF (Y7_1415 = -1) THEN Y7_1415 = .;
   IF (Y7_1416 = -1) THEN Y7_1416 = .;
   IF (Y7_1417 = -1) THEN Y7_1417 = .;
   IF (Y7_1418 = -1) THEN Y7_1418 = .;
   IF (Y7_1419 = -1) THEN Y7_1419 = .;
   IF (Y7_1420 = -1) THEN Y7_1420 = .;
   IF (Y7_1421 = -1) THEN Y7_1421 = .;
   IF (Y7_1422 = -1) THEN Y7_1422 = .;
   IF (Y7_1423 = -1) THEN Y7_1423 = .;
   IF (Y7_1424 = -1) THEN Y7_1424 = .;
   IF (Y7_1425 = -1) THEN Y7_1425 = .;
   IF (Y7_1426 = -1) THEN Y7_1426 = .;
   IF (Y7_1427 = -1) THEN Y7_1427 = .;
   IF (Y7_1428 = -1) THEN Y7_1428 = .;
   IF (Y7_1429 = -1) THEN Y7_1429 = .;
   IF (Y7_1430 = -1) THEN Y7_1430 = .;
   IF (Y7_1431 = -1) THEN Y7_1431 = .;
   IF (Y7_1432 = -1) THEN Y7_1432 = .;
   IF (Y7_1433 = -1) THEN Y7_1433 = .;
   IF (Y7_1434 = -1) THEN Y7_1434 = .;
   IF (Y7_1435 = -1) THEN Y7_1435 = .;
   IF (Y7_1436 = -1) THEN Y7_1436 = .;
   IF (Y7_1437 = -1) THEN Y7_1437 = .;
   IF (Y7_1451 = -1) THEN Y7_1451 = .;
   IF (Y7_1452 = -1) THEN Y7_1452 = .;
   IF (Y7_1453 = -1) THEN Y7_1453 = .;
   IF (Y7_1454 = -1) THEN Y7_1454 = .;
   IF (Y7_1455 = -1) THEN Y7_1455 = .;
   IF (Y7_1456 = -1) THEN Y7_1456 = .;
   IF (Y7_1457 = -1) THEN Y7_1457 = .;
   IF (Y7_1458 = -1) THEN Y7_1458 = .;
   IF (Y7_1459 = -1) THEN Y7_1459 = .;
   IF (Y7_1460 = -1) THEN Y7_1460 = .;
   IF (Y7_1461 = -1) THEN Y7_1461 = .;
   IF (Y7_1466 = -1) THEN Y7_1466 = .;
   IF (Y7_1467 = -1) THEN Y7_1467 = .;
   IF (Y7_1468 = -1) THEN Y7_1468 = .;
   IF (Y7_1469 = -1) THEN Y7_1469 = .;
   IF (Y7_1470 = -1) THEN Y7_1470 = .;
   IF (Y7_1471 = -1) THEN Y7_1471 = .;
   IF (Y7_1472 = -1) THEN Y7_1472 = .;
   IF (Y7_1473 = -1) THEN Y7_1473 = .;
   IF (Y7_1474 = -1) THEN Y7_1474 = .;
   IF (Y7_1475 = -1) THEN Y7_1475 = .;
   IF (Y7_1476 = -1) THEN Y7_1476 = .;
   IF (Y7_1477 = -1) THEN Y7_1477 = .;
   IF (Y7_1478 = -1) THEN Y7_1478 = .;
   IF (Y7_1479 = -1) THEN Y7_1479 = .;
   IF (Y7_1480 = -1) THEN Y7_1480 = .;
   IF (Y7_1481 = -1) THEN Y7_1481 = .;
   IF (Y7_1482 = -1) THEN Y7_1482 = .;
   IF (Y7_1483 = -1) THEN Y7_1483 = .;
   IF (Y7_1484 = -1) THEN Y7_1484 = .;
   IF (Y7_1485 = -1) THEN Y7_1485 = .;
   IF (Y7_1486 = -1) THEN Y7_1486 = .;
   IF (Y7_1487 = -1) THEN Y7_1487 = .;
   IF (Y7_1730 = -1) THEN Y7_1730 = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT Y7_1 y7_1ffff. Y7_2 y7_2ffff. Y7_3 y7_3ffff.
         Y7_8 y7_8ffff. Y7_9 y7_9ffff. Y7_10 y7_10fff.
         Y7_11 y7_11fff. Y7_12 y7_12fff. Y7_13 y7_13fff.
         Y7_14 y7_14fff. Y7_15 y7_15fff. Y7_16 y7_16fff.
         Y7_17 y7_17fff. Y7_18 y7_18fff. Y7_19 y7_19fff.
         Y7_20 y7_20fff. Y7_21 y7_21fff. Y7_22 y7_22fff.
         Y7_23 y7_23fff. Y7_24 y7_24fff. Y7_25 y7_25fff.
         Y7_26 y7_26fff. Y7_27 y7_27fff. Y7_28 y7_28fff.
         Y7_29 y7_29fff. Y7_30 y7_30fff. Y7_31 y7_31fff.
         Y7_32 y7_32fff. Y7_33 y7_33fff. Y7_34 y7_34fff.
         Y7_35 y7_35fff. Y7_36 y7_36fff. Y7_37 y7_37fff.
         Y7_38 y7_38fff. Y7_39 y7_39fff. Y7_40 y7_40fff.
         Y7_41 y7_41fff. Y7_42 y7_42fff. Y7_43 y7_43fff.
         Y7_44 y7_44fff. Y7_45 y7_45fff. Y7_46 y7_46fff.
         Y7_47 y7_47fff. Y7_48 y7_48fff. Y7_49 y7_49fff.
         Y7_50 y7_50fff. Y7_51 y7_51fff. Y7_52 y7_52fff.
         Y7_53 y7_53fff. Y7_54 y7_54fff. Y7_55 y7_55fff.
         Y7_56 y7_56fff. Y7_57 y7_57fff. Y7_58 y7_58fff.
         Y7_59 y7_59fff. Y7_60 y7_60fff. Y7_61 y7_61fff.
         Y7_62 y7_62fff. Y7_63 y7_63fff. Y7_64 y7_64fff.
         Y7_65 y7_65fff. Y7_66 y7_66fff. Y7_67 y7_67fff.
         Y7_68 y7_68fff. Y7_69 y7_69fff. Y7_70 y7_70fff.
         Y7_71 y7_71fff. Y7_72 y7_72fff. Y7_73 y7_73fff.
         Y7_74 y7_74fff. Y7_75 y7_75fff. Y7_76 y7_76fff.
         Y7_77 y7_77fff. Y7_78 y7_78fff. Y7_79 y7_79fff.
         Y7_80 y7_80fff. Y7_81 y7_81fff. Y7_83 y7_83fff.
         Y7_84 y7_84fff. Y7_85 y7_85fff. Y7_86 y7_86fff.
         Y7_87 y7_87fff. Y7_88 y7_88fff. Y7_89 y7_89fff.
         Y7_90 y7_90fff. Y7_91 y7_91fff. Y7_92 y7_92fff.
         Y7_93 y7_93fff. Y7_94 y7_94fff. Y7_95 y7_95fff.
         Y7_96 y7_96fff. Y7_97 y7_97fff. Y7_98 y7_98fff.
         Y7_99 y7_99fff. Y7_100 y7_100ff. Y7_101 y7_101ff.
         Y7_102 y7_102ff. Y7_103 y7_103ff. Y7_104 y7_104ff.
         Y7_105 y7_105ff. Y7_106 y7_106ff. Y7_107 y7_107ff.
         Y7_108 y7_108ff. Y7_109 y7_109ff. Y7_110 y7_110ff.
         Y7_111 y7_111ff. Y7_112 y7_112ff. Y7_113 y7_113ff.
         Y7_114 y7_114ff. Y7_115 y7_115ff. Y7_116 y7_116ff.
         Y7_117 y7_117ff. Y7_118 y7_118ff. Y7_119 y7_119ff.
         Y7_121 y7_121ff. Y7_122 y7_122ff. Y7_123 y7_123ff.
         Y7_124 y7_124ff. Y7_149 y7_149ff. Y7_150 y7_150ff.
         Y7_151 y7_151ff. Y7_152 y7_152ff. Y7_153 y7_153ff.
         Y7_154 y7_154ff. Y7_155 y7_155ff. Y7_156 y7_156ff.
         Y7_157 y7_157ff. Y7_158 y7_158ff. Y7_159 y7_159ff.
         Y7_160 y7_160ff. Y7_161 y7_161ff. Y7_162 y7_162ff.
         Y7_163 y7_163ff. Y7_165 y7_165ff. Y7_166 y7_166ff.
         Y7_167 y7_167ff. Y7_168 y7_168ff. Y7_169 y7_169ff.
         Y7_170 y7_170ff. Y7_171 y7_171ff. Y7_172 y7_172ff.
         Y7_173 y7_173ff. Y7_174 y7_174ff. Y7_175 y7_175ff.
         Y7_176 y7_176ff. Y7_177 y7_177ff. Y7_178 y7_178ff.
         Y7_179 y7_179ff. Y7_180 y7_180ff. Y7_181 y7_181ff.
         Y7_182 y7_182ff. Y7_183 y7_183ff. Y7_184 y7_184ff.
         Y7_185 y7_185ff. Y7_187 y7_187ff. Y7_188 y7_188ff.
         Y7_210 y7_210ff. Y7_211 y7_211ff. Y7_233 y7_233ff.
         Y7_234 y7_234ff. Y7_235 y7_235ff. Y7_236 y7_236ff.
         Y7_237 y7_237ff. Y7_238 y7_238ff. Y7_239 y7_239ff.
         Y7_240 y7_240ff. Y7_241 y7_241ff. Y7_242 y7_242ff.
         Y7_243 y7_243ff. Y7_244 y7_244ff. Y7_245 y7_245ff.
         Y7_246 y7_246ff. Y7_247 y7_247ff. Y7_261 y7_261ff.
         Y7_263 y7_263ff. Y7_264 y7_264ff. Y7_265 y7_265ff.
         Y7_266 y7_266ff. Y7_267 y7_267ff. Y7_268 y7_268ff.
         Y7_269 y7_269ff. Y7_270 y7_270ff. Y7_271 y7_271ff.
         Y7_272 y7_272ff. Y7_273 y7_273ff. Y7_274 y7_274ff.
         Y7_275 y7_275ff. Y7_276 y7_276ff. Y7_277 y7_277ff.
         Y7_278 y7_278ff. Y7_279 y7_279ff. Y7_280 y7_280ff.
         Y7_281 y7_281ff. Y7_282 y7_282ff. Y7_283 y7_283ff.
         Y7_284 y7_284ff. Y7_285 y7_285ff. Y7_286 y7_286ff.
         Y7_287 y7_287ff. Y7_288 y7_288ff. Y7_289 y7_289ff.
         Y7_290 y7_290ff. Y7_291 y7_291ff. Y7_292 y7_292ff.
         Y7_293 y7_293ff. Y7_294 y7_294ff. Y7_295 y7_295ff.
         Y7_296 y7_296ff. Y7_297 y7_297ff. Y7_298 y7_298ff.
         Y7_299 y7_299ff. Y7_300 y7_300ff. Y7_301 y7_301ff.
         Y7_302 y7_302ff. Y7_303 y7_303ff. Y7_304 y7_304ff.
         Y7_305 y7_305ff. Y7_306 y7_306ff. Y7_307 y7_307ff.
         Y7_308 y7_308ff. Y7_309 y7_309ff. Y7_310 y7_310ff.
         Y7_311 y7_311ff. Y7_312 y7_312ff. Y7_313 y7_313ff.
         Y7_314 y7_314ff. Y7_315 y7_315ff. Y7_316 y7_316ff.
         Y7_317 y7_317ff. Y7_318 y7_318ff. Y7_319 y7_319ff.
         Y7_320 y7_320ff. Y7_322 y7_322ff. Y7_323 y7_323ff.
         Y7_324 y7_324ff. Y7_325 y7_325ff. Y7_326 y7_326ff.
         Y7_327 y7_327ff. Y7_328 y7_328ff. Y7_329 y7_329ff.
         Y7_330 y7_330ff. Y7_331 y7_331ff. Y7_332 y7_332ff.
         Y7_333 y7_333ff. Y7_334 y7_334ff. Y7_335 y7_335ff.
         Y7_336 y7_336ff. Y7_337 y7_337ff. Y7_338 y7_338ff.
         Y7_339 y7_339ff. Y7_340 y7_340ff. Y7_341 y7_341ff.
         Y7_342 y7_342ff. Y7_343 y7_343ff. Y7_344 y7_344ff.
         Y7_345 y7_345ff. Y7_346 y7_346ff. Y7_347 y7_347ff.
         Y7_348 y7_348ff. Y7_349 y7_349ff. Y7_350 y7_350ff.
         Y7_351 y7_351ff. Y7_352 y7_352ff. Y7_353 y7_353ff.
         Y7_354 y7_354ff. Y7_355 y7_355ff. Y7_356 y7_356ff.
         Y7_357 y7_357ff. Y7_358 y7_358ff. Y7_359 y7_359ff.
         Y7_360 y7_360ff. Y7_361 y7_361ff. Y7_362 y7_362ff.
         Y7_363 y7_363ff. Y7_364 y7_364ff. Y7_365 y7_365ff.
         Y7_366 y7_366ff. Y7_367 y7_367ff. Y7_368 y7_368ff.
         Y7_369 y7_369ff. Y7_370 y7_370ff. Y7_371 y7_371ff.
         Y7_372 y7_372ff. Y7_373 y7_373ff. Y7_374 y7_374ff.
         Y7_375 y7_375ff. Y7_376 y7_376ff. Y7_377 y7_377ff.
         Y7_378 y7_378ff. Y7_379 y7_379ff. Y7_380 y7_380ff.
         Y7_381 y7_381ff. Y7_382 y7_382ff. Y7_383 y7_383ff.
         Y7_384 y7_384ff. Y7_385 y7_385ff. Y7_386 y7_386ff.
         Y7_387 y7_387ff. Y7_388 y7_388ff. Y7_389 y7_389ff.
         Y7_390 y7_390ff. Y7_391 y7_391ff. Y7_392 y7_392ff.
         Y7_393 y7_393ff. Y7_394 y7_394ff. Y7_395 y7_395ff.
         Y7_396 y7_396ff. Y7_397 y7_397ff. Y7_398 y7_398ff.
         Y7_399 y7_399ff. Y7_400 y7_400ff. Y7_401 y7_401ff.
         Y7_402 y7_402ff. Y7_403 y7_403ff. Y7_404 y7_404ff.
         Y7_405 y7_405ff. Y7_406 y7_406ff. Y7_407 y7_407ff.
         Y7_408 y7_408ff. Y7_409 y7_409ff. Y7_410 y7_410ff.
         Y7_411 y7_411ff. Y7_412 y7_412ff. Y7_413 y7_413ff.
         Y7_414 y7_414ff. Y7_415 y7_415ff. Y7_416 y7_416ff.
         Y7_417 y7_417ff. Y7_418 y7_418ff. Y7_419 y7_419ff.
         Y7_420 y7_420ff. Y7_421 y7_421ff. Y7_422 y7_422ff.
         Y7_423 y7_423ff. Y7_424 y7_424ff. Y7_425 y7_425ff.
         Y7_426 y7_426ff. Y7_427 y7_427ff. Y7_428 y7_428ff.
         Y7_429 y7_429ff. Y7_430 y7_430ff. Y7_431 y7_431ff.
         Y7_432 y7_432ff. Y7_433 y7_433ff. Y7_434 y7_434ff.
         Y7_435 y7_435ff. Y7_436 y7_436ff. Y7_437 y7_437ff.
         Y7_438 y7_438ff. Y7_439 y7_439ff. Y7_440 y7_440ff.
         Y7_441 y7_441ff. Y7_442 y7_442ff. Y7_443 y7_443ff.
         Y7_444 y7_444ff. Y7_445 y7_445ff. Y7_446 y7_446ff.
         Y7_447 y7_447ff. Y7_448 y7_448ff. Y7_449 y7_449ff.
         Y7_451 y7_451ff. Y7_453 y7_453ff. Y7_455 y7_455ff.
         Y7_457 y7_457ff. Y7_459 y7_459ff. Y7_461 y7_461ff.
         Y7_463 y7_463ff. Y7_465 y7_465ff. Y7_467 y7_467ff.
         Y7_469 y7_469ff. Y7_471 y7_471ff. Y7_473 y7_473ff.
         Y7_475 y7_475ff. Y7_477 y7_477ff. Y7_479 y7_479ff.
         Y7_481 y7_481ff. Y7_483 y7_483ff. Y7_485 y7_485ff.
         Y7_487 y7_487ff. Y7_489 y7_489ff. Y7_491 y7_491ff.
         Y7_493 y7_493ff. Y7_495 y7_495ff. Y7_497 y7_497ff.
         Y7_499 y7_499ff. Y7_501 y7_501ff. Y7_503 y7_503ff.
         Y7_505 y7_505ff. Y7_507 y7_507ff. Y7_509 y7_509ff.
         Y7_511 y7_511ff. Y7_513 y7_513ff. Y7_515 y7_515ff.
         Y7_517 y7_517ff. Y7_519 y7_519ff. Y7_521 y7_521ff.
         Y7_523 y7_523ff. Y7_525 y7_525ff. Y7_526 y7_526ff.
         Y7_527 y7_527ff. Y7_528 y7_528ff. Y7_529 y7_529ff.
         Y7_530 y7_530ff. Y7_531 y7_531ff. Y7_532 y7_532ff.
         Y7_533 y7_533ff. Y7_534 y7_534ff. Y7_535 y7_535ff.
         Y7_536 y7_536ff. Y7_537 y7_537ff. Y7_538 y7_538ff.
         Y7_539 y7_539ff. Y7_540 y7_540ff. Y7_541 y7_541ff.
         Y7_542 y7_542ff. Y7_543 y7_543ff. Y7_544 y7_544ff.
         Y7_545 y7_545ff. Y7_546 y7_546ff. Y7_547 y7_547ff.
         Y7_548 y7_548ff. Y7_549 y7_549ff. Y7_550 y7_550ff.
         Y7_551 y7_551ff. Y7_552 y7_552ff. Y7_553 y7_553ff.
         Y7_554 y7_554ff. Y7_555 y7_555ff. Y7_556 y7_556ff.
         Y7_557 y7_557ff. Y7_558 y7_558ff. Y7_559 y7_559ff.
         Y7_560 y7_560ff. Y7_561 y7_561ff. Y7_562 y7_562ff.
         Y7_563 y7_563ff. Y7_564 y7_564ff. Y7_565 y7_565ff.
         Y7_566 y7_566ff. Y7_567 y7_567ff. Y7_569 y7_569ff.
         Y7_570 y7_570ff. Y7_571 y7_571ff. Y7_573 y7_573ff.
         Y7_578 y7_578ff. Y7_579 y7_579ff. Y7_580 y7_580ff.
         Y7_581 y7_581ff. Y7_582 y7_582ff. Y7_583 y7_583ff.
         Y7_584 y7_584ff. Y7_585 y7_585ff. Y7_586 y7_586ff.
         Y7_587 y7_587ff. Y7_588 y7_588ff. Y7_589 y7_589ff.
         Y7_590 y7_590ff. Y7_591 y7_591ff. Y7_592 y7_592ff.
         Y7_593 y7_593ff. Y7_594 y7_594ff. Y7_595 y7_595ff.
         Y7_596 y7_596ff. Y7_597 y7_597ff. Y7_598 y7_598ff.
         Y7_599 y7_599ff. Y7_600 y7_600ff. Y7_601 y7_601ff.
         Y7_602 y7_602ff. Y7_603 y7_603ff. Y7_604 y7_604ff.
         Y7_605 y7_605ff. Y7_606 y7_606ff. Y7_608 y7_608ff.
         Y7_609 y7_609ff. Y7_610 y7_610ff. Y7_611 y7_611ff.
         Y7_612 y7_612ff. Y7_613 y7_613ff. Y7_615 y7_615ff.
         Y7_616 y7_616ff. Y7_617 y7_617ff. Y7_618 y7_618ff.
         Y7_619 y7_619ff. Y7_620 y7_620ff. Y7_622 y7_622ff.
         Y7_623 y7_623ff. Y7_624 y7_624ff. Y7_625 y7_625ff.
         Y7_626 y7_626ff. Y7_627 y7_627ff. Y7_628 y7_628ff.
         Y7_630 y7_630ff. Y7_631 y7_631ff. Y7_632 y7_632ff.
         Y7_633 y7_633ff. Y7_634 y7_634ff. Y7_635 y7_635ff.
         Y7_636 y7_636ff. Y7_637 y7_637ff. Y7_638 y7_638ff.
         Y7_639 y7_639ff. Y7_640 y7_640ff. Y7_641 y7_641ff.
         Y7_642 y7_642ff. Y7_643 y7_643ff. Y7_644 y7_644ff.
         Y7_645 y7_645ff. Y7_646 y7_646ff. Y7_647 y7_647ff.
         Y7_648 y7_648ff. Y7_649 y7_649ff. Y7_650 y7_650ff.
         Y7_651 y7_651ff. Y7_652 y7_652ff. Y7_653 y7_653ff.
         Y7_654 y7_654ff. Y7_655 y7_655ff. Y7_656 y7_656ff.
         Y7_657 y7_657ff. Y7_658 y7_658ff. Y7_659 y7_659ff.
         Y7_660 y7_660ff. Y7_661 y7_661ff. Y7_662 y7_662ff.
         Y7_663 y7_663ff. Y7_664 y7_664ff. Y7_665 y7_665ff.
         Y7_666 y7_666ff. Y7_667 y7_667ff. Y7_668 y7_668ff.
         Y7_669 y7_669ff. Y7_670 y7_670ff. Y7_671 y7_671ff.
         Y7_672 y7_672ff. Y7_673 y7_673ff. Y7_674 y7_674ff.
         Y7_675 y7_675ff. Y7_676 y7_676ff. Y7_677 y7_677ff.
         Y7_678 y7_678ff. Y7_679 y7_679ff. Y7_680 y7_680ff.
         Y7_681 y7_681ff. Y7_682 y7_682ff. Y7_683 y7_683ff.
         Y7_684 y7_684ff. Y7_685 y7_685ff. Y7_686 y7_686ff.
         Y7_687 y7_687ff. Y7_689 y7_689ff. Y7_690 y7_690ff.
         Y7_691 y7_691ff. Y7_694 y7_694ff. Y7_695 y7_695ff.
         Y7_696 y7_696ff. Y7_697 y7_697ff. Y7_700 y7_700ff.
         Y7_701 y7_701ff. Y7_702 y7_702ff. Y7_703 y7_703ff.
         Y7_704 y7_704ff. Y7_705 y7_705ff. Y7_708 y7_708ff.
         Y7_709 y7_709ff. Y7_710 y7_710ff. Y7_711 y7_711ff.
         Y7_712 y7_712ff. Y7_713 y7_713ff. Y7_714 y7_714ff.
         Y7_715 y7_715ff. Y7_716 y7_716ff. Y7_717 y7_717ff.
         Y7_718 y7_718ff. Y7_719 y7_719ff. Y7_720 y7_720ff.
         Y7_721 y7_721ff. Y7_722 y7_722ff. Y7_723 y7_723ff.
         Y7_724 y7_724ff. Y7_725 y7_725ff. Y7_726 y7_726ff.
         Y7_727 y7_727ff. Y7_728 y7_728ff. Y7_729 y7_729ff.
         Y7_730 y7_730ff. Y7_731 y7_731ff. Y7_732 y7_732ff.
         Y7_733 y7_733ff. Y7_734 y7_734ff. Y7_735 y7_735ff.
         Y7_736 y7_736ff. Y7_737 y7_737ff. Y7_738 y7_738ff.
         Y7_739 y7_739ff. Y7_740 y7_740ff. Y7_741 y7_741ff.
         Y7_742 y7_742ff. Y7_743 y7_743ff. Y7_744 y7_744ff.
         Y7_745 y7_745ff. Y7_746 y7_746ff. Y7_747 y7_747ff.
         Y7_748 y7_748ff. Y7_749 y7_749ff. Y7_750 y7_750ff.
         Y7_751 y7_751ff. Y7_752 y7_752ff. Y7_753 y7_753ff.
         Y7_754 y7_754ff. Y7_756 y7_756ff. Y7_757 y7_757ff.
         Y7_758 y7_758ff. Y7_759 y7_759ff. Y7_762 y7_762ff.
         Y7_763 y7_763ff. Y7_764 y7_764ff. Y7_765 y7_765ff.
         Y7_766 y7_766ff. Y7_767 y7_767ff. Y7_768 y7_768ff.
         Y7_769 y7_769ff. Y7_770 y7_770ff. Y7_771 y7_771ff.
         Y7_772 y7_772ff. Y7_773 y7_773ff. Y7_774 y7_774ff.
         Y7_775 y7_775ff. Y7_776 y7_776ff. Y7_777 y7_777ff.
         Y7_778 y7_778ff. Y7_779 y7_779ff. Y7_780 y7_780ff.
         Y7_781 y7_781ff. Y7_782 y7_782ff. Y7_783 y7_783ff.
         Y7_784 y7_784ff. Y7_785 y7_785ff. Y7_786 y7_786ff.
         Y7_787 y7_787ff. Y7_788 y7_788ff. Y7_789 y7_789ff.
         Y7_790 y7_790ff. Y7_791 y7_791ff. Y7_792 y7_792ff.
         Y7_793 y7_793ff. Y7_794 y7_794ff. Y7_795 y7_795ff.
         Y7_796 y7_796ff. Y7_798 y7_798ff. Y7_799 y7_799ff.
         Y7_800 y7_800ff. Y7_801 y7_801ff. Y7_802 y7_802ff.
         Y7_803 y7_803ff. Y7_804 y7_804ff. Y7_805 y7_805ff.
         Y7_806 y7_806ff. Y7_807 y7_807ff. Y7_808 y7_808ff.
         Y7_809 y7_809ff. Y7_810 y7_810ff. Y7_811 y7_811ff.
         Y7_812 y7_812ff. Y7_813 y7_813ff. Y7_814 y7_814ff.
         Y7_815 y7_815ff. Y7_816 y7_816ff. Y7_817 y7_817ff.
         Y7_818 y7_818ff. Y7_819 y7_819ff. Y7_820 y7_820ff.
         Y7_821 y7_821ff. Y7_822 y7_822ff. Y7_823 y7_823ff.
         Y7_824 y7_824ff. Y7_825 y7_825ff. Y7_827 y7_827ff.
         Y7_828 y7_828ff. Y7_829 y7_829ff. Y7_830 y7_830ff.
         Y7_831 y7_831ff. Y7_832 y7_832ff. Y7_833 y7_833ff.
         Y7_834 y7_834ff. Y7_835 y7_835ff. Y7_836 y7_836ff.
         Y7_837 y7_837ff. Y7_838 y7_838ff. Y7_840 y7_840ff.
         Y7_841 y7_841ff. Y7_843 y7_843ff. Y7_844 y7_844ff.
         Y7_845 y7_845ff. Y7_846 y7_846ff. Y7_851 y7_851ff.
         Y7_852 y7_852ff. Y7_854 y7_854ff. Y7_855 y7_855ff.
         Y7_857 y7_857ff. Y7_858 y7_858ff. Y7_861 y7_861ff.
         Y7_862 y7_862ff. Y7_865 y7_865ff. Y7_866 y7_866ff.
         Y7_869 y7_869ff. Y7_870 y7_870ff. Y7_873 y7_873ff.
         Y7_874 y7_874ff. Y7_876 y7_876ff. Y7_877 y7_877ff.
         Y7_879 y7_879ff. Y7_880 y7_880ff. Y7_882 y7_882ff.
         Y7_883 y7_883ff. Y7_885 y7_885ff. Y7_886 y7_886ff.
         Y7_887 y7_887ff. Y7_889 y7_889ff. Y7_890 y7_890ff.
         Y7_892 y7_892ff. Y7_893 y7_893ff. Y7_894 y7_894ff.
         Y7_895 y7_895ff. Y7_896 y7_896ff. Y7_897 y7_897ff.
         Y7_898 y7_898ff. Y7_899 y7_899ff. Y7_900 y7_900ff.
         Y7_901 y7_901ff. Y7_902 y7_902ff. Y7_903 y7_903ff.
         Y7_904 y7_904ff. Y7_905 y7_905ff. Y7_906 y7_906ff.
         Y7_907 y7_907ff. Y7_908 y7_908ff. Y7_909 y7_909ff.
         Y7_910 y7_910ff. Y7_911 y7_911ff. Y7_912 y7_912ff.
         Y7_913 y7_913ff. Y7_914 y7_914ff. Y7_915 y7_915ff.
         Y7_916 y7_916ff. Y7_917 y7_917ff. Y7_918 y7_918ff.
         Y7_919 y7_919ff. Y7_920 y7_920ff. Y7_921 y7_921ff.
         Y7_922 y7_922ff. Y7_923 y7_923ff. Y7_924 y7_924ff.
         Y7_925 y7_925ff. Y7_926 y7_926ff. Y7_927 y7_927ff.
         Y7_928 y7_928ff. Y7_929 y7_929ff. Y7_930 y7_930ff.
         Y7_931 y7_931ff. Y7_932 y7_932ff. Y7_933 y7_933ff.
         Y7_934 y7_934ff. Y7_944 y7_944ff. Y7_945 y7_945ff.
         Y7_946 y7_946ff. Y7_947 y7_947ff. Y7_948 y7_948ff.
         Y7_949 y7_949ff. Y7_950 y7_950ff. Y7_951 y7_951ff.
         Y7_952 y7_952ff. Y7_953 y7_953ff. Y7_954 y7_954ff.
         Y7_955 y7_955ff. Y7_956 y7_956ff. Y7_957 y7_957ff.
         Y7_958 y7_958ff. Y7_959 y7_959ff. Y7_960 y7_960ff.
         Y7_961 y7_961ff. Y7_962 y7_962ff. Y7_963 y7_963ff.
         Y7_964 y7_964ff. Y7_965 y7_965ff. Y7_966 y7_966ff.
         Y7_967 y7_967ff. Y7_968 y7_968ff. Y7_969 y7_969ff.
         Y7_970 y7_970ff. Y7_971 y7_971ff. Y7_972 y7_972ff.
         Y7_973 y7_973ff. Y7_974 y7_974ff. Y7_975 y7_975ff.
         Y7_976 y7_976ff. Y7_977 y7_977ff. Y7_978 y7_978ff.
         Y7_979 y7_979ff. Y7_980 y7_980ff. Y7_981 y7_981ff.
         Y7_982 y7_982ff. Y7_983 y7_983ff. Y7_984 y7_984ff.
         Y7_985 y7_985ff. Y7_986 y7_986ff. Y7_987 y7_987ff.
         Y7_988 y7_988ff. Y7_989 y7_989ff. Y7_990 y7_990ff.
         Y7_991 y7_991ff. Y7_992 y7_992ff. Y7_993 y7_993ff.
         Y7_994 y7_994ff. Y7_995 y7_995ff. Y7_996 y7_996ff.
         Y7_997 y7_997ff. Y7_998 y7_998ff. Y7_999 y7_999ff.
         Y7_1000 y7_1000f. Y7_1001 y7_1001f. Y7_1002 y7_1002f.
         Y7_1003 y7_1003f. Y7_1004 y7_1004f. Y7_1005 y7_1005f.
         Y7_1006 y7_1006f. Y7_1007 y7_1007f. Y7_1008 y7_1008f.
         Y7_1009 y7_1009f. Y7_1010 y7_1010f. Y7_1011 y7_1011f.
         Y7_1012 y7_1012f. Y7_1013 y7_1013f. Y7_1014 y7_1014f.
         Y7_1015 y7_1015f. Y7_1016 y7_1016f. Y7_1017 y7_1017f.
         Y7_1018 y7_1018f. Y7_1019 y7_1019f. Y7_1020 y7_1020f.
         Y7_1021 y7_1021f. Y7_1022 y7_1022f. Y7_1023 y7_1023f.
         Y7_1024 y7_1024f. Y7_1025 y7_1025f. Y7_1026 y7_1026f.
         Y7_1027 y7_1027f. Y7_1028 y7_1028f. Y7_1029 y7_1029f.
         Y7_1030 y7_1030f. Y7_1031 y7_1031f. Y7_1032 y7_1032f.
         Y7_1039 y7_1039f. Y7_1040 y7_1040f. Y7_1041 y7_1041f.
         Y7_1048 y7_1048f. Y7_1049 y7_1049f. Y7_1050 y7_1050f.
         Y7_1057 y7_1057f. Y7_1058 y7_1058f. Y7_1059 y7_1059f.
         Y7_1060 y7_1060f. Y7_1062 y7_1062f. Y7_1064 y7_1064f.
         Y7_1065 y7_1065f. Y7_1066 y7_1066f. Y7_1068 y7_1068f.
         Y7_1071 y7_1071f. Y7_1072 y7_1072f. Y7_1074 y7_1074f.
         Y7_1076 y7_1076f. Y7_1077 y7_1077f. Y7_1079 y7_1079f.
         Y7_1083 y7_1083f. Y7_1092 y7_1092f. Y7_1093 y7_1093f.
         Y7_1094 y7_1094f. Y7_1095 y7_1095f. Y7_1096 y7_1096f.
         Y7_1097 y7_1097f. Y7_1098 y7_1098f. Y7_1099 y7_1099f.
         Y7_1100 y7_1100f. Y7_1101 y7_1101f. Y7_1102 y7_1102f.
         Y7_1103 y7_1103f. Y7_1104 y7_1104f. Y7_1105 y7_1105f.
         Y7_1106 y7_1106f. Y7_1107 y7_1107f. Y7_1108 y7_1108f.
         Y7_1109 y7_1109f. Y7_1110 y7_1110f. Y7_1111 y7_1111f.
         Y7_1112 y7_1112f. Y7_1113 y7_1113f. Y7_1114 y7_1114f.
         Y7_1115 y7_1115f. Y7_1116 y7_1116f. Y7_1119 y7_1119f.
         Y7_1120 y7_1120f. Y7_1121 y7_1121f. Y7_1122 y7_1122f.
         Y7_1125 y7_1125f. Y7_1126 y7_1126f. Y7_1127 y7_1127f.
         Y7_1128 y7_1128f. Y7_1129 y7_1129f. Y7_1130 y7_1130f.
         Y7_1131 y7_1131f. Y7_1132 y7_1132f. Y7_1133 y7_1133f.
         Y7_1134 y7_1134f. Y7_1135 y7_1135f. Y7_1136 y7_1136f.
         Y7_1137 y7_1137f. Y7_1138 y7_1138f. Y7_1140 y7_1140f.
         Y7_1141 y7_1141f. Y7_1142 y7_1142f. Y7_1143 y7_1143f.
         Y7_1144 y7_1144f. Y7_1145 y7_1145f. Y7_1146 y7_1146f.
         Y7_1147 y7_1147f. Y7_1148 y7_1148f. Y7_1149 y7_1149f.
         Y7_1150 y7_1150f. Y7_1151 y7_1151f. Y7_1152 y7_1152f.
         Y7_1153 y7_1153f. Y7_1157 y7_1157f. Y7_1158 y7_1158f.
         Y7_1159 y7_1159f. Y7_1160 y7_1160f. Y7_1161 y7_1161f.
         Y7_1162 y7_1162f. Y7_1163 y7_1163f. Y7_1164 y7_1164f.
         Y7_1165 y7_1165f. Y7_1166 y7_1166f. Y7_1167 y7_1167f.
         Y7_1168 y7_1168f. Y7_1169 y7_1169f. Y7_1173 y7_1173f.
         Y7_1174 y7_1174f. Y7_1175 y7_1175f. Y7_1177 y7_1177f.
         Y7_1182 y7_1182f. Y7_1183 y7_1183f. Y7_1184 y7_1184f.
         Y7_1185 y7_1185f. Y7_1186 y7_1186f. Y7_1187 y7_1187f.
         Y7_1188 y7_1188f. Y7_1189 y7_1189f. Y7_1190 y7_1190f.
         Y7_1191 y7_1191f. Y7_1192 y7_1192f. Y7_1193 y7_1193f.
         Y7_1194 y7_1194f. Y7_1195 y7_1195f. Y7_1197 y7_1197f.
         Y7_1198 y7_1198f. Y7_1199 y7_1199f. Y7_1200 y7_1200f.
         Y7_1201 y7_1201f. Y7_1202 y7_1202f. Y7_1203 y7_1203f.
         Y7_1204 y7_1204f. Y7_1205 y7_1205f. Y7_1206 y7_1206f.
         Y7_1207 y7_1207f. Y7_1208 y7_1208f. Y7_1209 y7_1209f.
         Y7_1210 y7_1210f. Y7_1211 y7_1211f. Y7_1212 y7_1212f.
         Y7_1213 y7_1213f. Y7_1214 y7_1214f. Y7_1215 y7_1215f.
         Y7_1216 y7_1216f. Y7_1217 y7_1217f. Y7_1218 y7_1218f.
         Y7_1219 y7_1219f. Y7_1220 y7_1220f. Y7_1221 y7_1221f.
         Y7_1222 y7_1222f. Y7_1223 y7_1223f. Y7_1224 y7_1224f.
         Y7_1225 y7_1225f. Y7_1226 y7_1226f. Y7_1227 y7_1227f.
         Y7_1228 y7_1228f. Y7_1229 y7_1229f. Y7_1230 y7_1230f.
         Y7_1231 y7_1231f. Y7_1232 y7_1232f. Y7_1233 y7_1233f.
         Y7_1234 y7_1234f. Y7_1235 y7_1235f. Y7_1236 y7_1236f.
         Y7_1237 y7_1237f. Y7_1238 y7_1238f. Y7_1239 y7_1239f.
         Y7_1240 y7_1240f. Y7_1241 y7_1241f. Y7_1242 y7_1242f.
         Y7_1243 y7_1243f. Y7_1244 y7_1244f. Y7_1245 y7_1245f.
         Y7_1246 y7_1246f. Y7_1247 y7_1247f. Y7_1248 y7_1248f.
         Y7_1249 y7_1249f. Y7_1250 y7_1250f. Y7_1251 y7_1251f.
         Y7_1252 y7_1252f. Y7_1253 y7_1253f. Y7_1254 y7_1254f.
         Y7_1255 y7_1255f. Y7_1256 y7_1256f. Y7_1262 y7_1262f.
         Y7_1263 y7_1263f. Y7_1264 y7_1264f. Y7_1265 y7_1265f.
         Y7_1266 y7_1266f. Y7_1267 y7_1267f. Y7_1268 y7_1268f.
         Y7_1269 y7_1269f. Y7_1271 y7_1271f. Y7_1274 y7_1274f.
         Y7_1275 y7_1275f. Y7_1276 y7_1276f. Y7_1277 y7_1277f.
         Y7_1279 y7_1279f. Y7_1280 y7_1280f. Y7_1281 y7_1281f.
         Y7_1282 y7_1282f. Y7_1284 y7_1284f. Y7_1285 y7_1285f.
         Y7_1286 y7_1286f. Y7_1287 y7_1287f. Y7_1289 y7_1289f.
         Y7_1290 y7_1290f. Y7_1291 y7_1291f. Y7_1292 y7_1292f.
         Y7_1294 y7_1294f. Y7_1295 y7_1295f. Y7_1296 y7_1296f.
         Y7_1297 y7_1297f. Y7_1299 y7_1299f. Y7_1300 y7_1300f.
         Y7_1301 y7_1301f. Y7_1302 y7_1302f. Y7_1304 y7_1304f.
         Y7_1305 y7_1305f. Y7_1306 y7_1306f. Y7_1307 y7_1307f.
         Y7_1309 y7_1309f. Y7_1310 y7_1310f. Y7_1311 y7_1311f.
         Y7_1312 y7_1312f. Y7_1314 y7_1314f. Y7_1315 y7_1315f.
         Y7_1316 y7_1316f. Y7_1317 y7_1317f. Y7_1319 y7_1319f.
         Y7_1320 y7_1320f. Y7_1321 y7_1321f. Y7_1322 y7_1322f.
         Y7_1324 y7_1324f. Y7_1325 y7_1325f. Y7_1326 y7_1326f.
         Y7_1327 y7_1327f. Y7_1329 y7_1329f. Y7_1330 y7_1330f.
         Y7_1331 y7_1331f. Y7_1332 y7_1332f. Y7_1334 y7_1334f.
         Y7_1335 y7_1335f. Y7_1336 y7_1336f. Y7_1337 y7_1337f.
         Y7_1339 y7_1339f. Y7_1340 y7_1340f. Y7_1341 y7_1341f.
         Y7_1342 y7_1342f. Y7_1344 y7_1344f. Y7_1345 y7_1345f.
         Y7_1346 y7_1346f. Y7_1347 y7_1347f. Y7_1349 y7_1349f.
         Y7_1350 y7_1350f. Y7_1351 y7_1351f. Y7_1352 y7_1352f.
         Y7_1354 y7_1354f. Y7_1355 y7_1355f. Y7_1356 y7_1356f.
         Y7_1357 y7_1357f. Y7_1358 y7_1358f. Y7_1359 y7_1359f.
         Y7_1360 y7_1360f. Y7_1361 y7_1361f. Y7_1362 y7_1362f.
         Y7_1363 y7_1363f. Y7_1364 y7_1364f. Y7_1365 y7_1365f.
         Y7_1366 y7_1366f. Y7_1367 y7_1367f. Y7_1368 y7_1368f.
         Y7_1369 y7_1369f. Y7_1370 y7_1370f. Y7_1371 y7_1371f.
         Y7_1372 y7_1372f. Y7_1373 y7_1373f. Y7_1374 y7_1374f.
         Y7_1375 y7_1375f. Y7_1376 y7_1376f. Y7_1377 y7_1377f.
         Y7_1383 y7_1383f. Y7_1385 y7_1385f. Y7_1387 y7_1387f.
         Y7_1390 y7_1390f. Y7_1391 y7_1391f. Y7_1392 y7_1392f.
         Y7_1393 y7_1393f. Y7_1394 y7_1394f. Y7_1395 y7_1395f.
         Y7_1396 y7_1396f. Y7_1397 y7_1397f. Y7_1399 y7_1399f.
         Y7_1400 y7_1400f. Y7_1401 y7_1401f. Y7_1402 y7_1402f.
         Y7_1403 y7_1403f. Y7_1404 y7_1404f. Y7_1405 y7_1405f.
         Y7_1406 y7_1406f. Y7_1408 y7_1408f. Y7_1409 y7_1409f.
         Y7_1410 y7_1410f. Y7_1411 y7_1411f. Y7_1413 y7_1413f.
         Y7_1414 y7_1414f. Y7_1416 y7_1416f. Y7_1418 y7_1418f.
         Y7_1419 y7_1419f. Y7_1420 y7_1420f. Y7_1421 y7_1421f.
         Y7_1423 y7_1423f. Y7_1424 y7_1424f. Y7_1425 y7_1425f.
         Y7_1426 y7_1426f. Y7_1427 y7_1427f. Y7_1428 y7_1428f.
         Y7_1429 y7_1429f. Y7_1430 y7_1430f. Y7_1431 y7_1431f.
         Y7_1432 y7_1432f. Y7_1433 y7_1433f. Y7_1434 y7_1434f.
         Y7_1437 y7_1437f. Y7_1451 y7_1451f. Y7_1452 y7_1452f.
         Y7_1453 y7_1453f. Y7_1454 y7_1454f. Y7_1455 y7_1455f.
         Y7_1456 y7_1456f. Y7_1457 y7_1457f. Y7_1458 y7_1458f.
         Y7_1459 y7_1459f. Y7_1460 y7_1460f. Y7_1461 y7_1461f.
         Y7_1466 y7_1466f. Y7_1467 y7_1467f. Y7_1468 y7_1468f.
         Y7_1469 y7_1469f. Y7_1470 y7_1470f. Y7_1471 y7_1471f.
         Y7_1472 y7_1472f. Y7_1473 y7_1473f. Y7_1474 y7_1474f.
         Y7_1475 y7_1475f. Y7_1476 y7_1476f. Y7_1477 y7_1477f.
         Y7_1478 y7_1478f. Y7_1479 y7_1479f. Y7_1480 y7_1480f.
         Y7_1481 y7_1481f. Y7_1482 y7_1482f. Y7_1483 y7_1483f.
         Y7_1484 y7_1484f. Y7_1485 y7_1485f. Y7_1486 y7_1486f.
         Y7_1487 y7_1487f. Y7_1730 y7_1730f.  ;
*/

RUN ;
